@@ -11,7 +11,6 @@
 
 namespace Symfony\Bridge\Doctrine\IdGenerator;
 
-use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Id\AbstractIdGenerator;
 use Symfony\Component\Uid\Factory\UlidFactory;
@@ -24,14 +23,6 @@ final class UlidGenerator extends AbstractIdGenerator
     ) {
     }
 
-    /**
-     * doctrine/orm < 2.11 BC layer.
-     */
-    public function generate(EntityManager $em, $entity): Ulid
-    {
-        return $this->generateId($em, $entity);
-    }
-
     public function generateId(EntityManagerInterface $em, $entity): Ulid
     {
         if ($this->factory) {
