@@ -12,10 +12,8 @@
 namespace Symfony\Bridge\Doctrine\Tests\Middleware\Debug;
 
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Driver\Middleware as MiddlewareInterface;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\ParameterType;
-use Doctrine\DBAL\Query\QueryBuilder;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Schema\DefaultSchemaManagerFactory;
 use Doctrine\DBAL\Statement;
@@ -38,10 +36,6 @@ class MiddlewareTest extends TestCase
 
     protected function setUp(): void
     {
-        if (!interface_exists(MiddlewareInterface::class)) {
-            $this->markTestSkipped(\sprintf('%s needed to run this test', MiddlewareInterface::class));
-        }
-
         ClockMock::withClockMock(false);
     }
 
@@ -51,7 +45,7 @@ class MiddlewareTest extends TestCase
 
         $config = ORMSetup::createConfiguration(true);
         $config->setSchemaManagerFactory(new DefaultSchemaManagerFactory());
-        $config->setLazyGhostObjectEnabled(true);
+        $config->enableNativeLazyObjects(true);
         $this->debugDataHolder = new DebugDataHolder();
         $config->setMiddlewares([new Middleware($this->debugDataHolder, $this->stopwatch)]);
 
@@ -178,10 +172,6 @@ class MiddlewareTest extends TestCase
     {
         $this->init();
 
-        if (\defined('Doctrine\DBAL\Connection::PARAM_STR_ARRAY')) {
-            // DBAL < 4
-            $this->conn->setNestTransactionsWithSavepoints(true);
-        }
         $this->conn->beginTransaction();
         $this->conn->beginTransaction();
         $this->conn->executeStatement('INSERT INTO products(name, price, stock) VALUES ("product1", 12.5, 5)');
@@ -195,11 +185,11 @@ class MiddlewareTest extends TestCase
         $this->assertCount(9, $debug);
         $this->assertSame('"START TRANSACTION"', $debug[1]['sql']);
         $this->assertGreaterThan(0, $debug[1]['executionMS']);
-        $this->assertSame(method_exists(QueryBuilder::class, 'resetOrderBy') ? 'SAVEPOINT DOCTRINE_2' : 'SAVEPOINT DOCTRINE2_SAVEPOINT_2', $debug[2]['sql']);
+        $this->assertSame('SAVEPOINT DOCTRINE_2', $debug[2]['sql']);
         $this->assertGreaterThan(0, $debug[2]['executionMS']);
         $this->assertSame('INSERT INTO products(name, price, stock) VALUES ("product1", 12.5, 5)', $debug[3]['sql']);
         $this->assertGreaterThan(0, $debug[3]['executionMS']);
-        $this->assertSame(('"ROLLBACK"' === $expectedEndTransactionDebug ? 'ROLLBACK TO' : 'RELEASE').' '.(method_exists(QueryBuilder::class, 'resetOrderBy') ? 'SAVEPOINT DOCTRINE_2' : 'SAVEPOINT DOCTRINE2_SAVEPOINT_2'), $debug[4]['sql']);
+        $this->assertSame(('"ROLLBACK"' === $expectedEndTransactionDebug ? 'ROLLBACK TO' : 'RELEASE').' SAVEPOINT DOCTRINE_2', $debug[4]['sql']);
         $this->assertGreaterThan(0, $debug[4]['executionMS']);
         $this->assertSame($expectedEndTransactionDebug, $debug[5]['sql']);
         $this->assertGreaterThan(0, $debug[5]['executionMS']);
