@@ -11,7 +11,6 @@
 
 namespace Symfony\Bridge\Doctrine\Tests\Types;
 
-use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
@@ -94,25 +93,25 @@ final class UuidTypeTest extends TestCase
     {
         $this->expectException(ConversionException::class);
 
-        $this->type->convertToDatabaseValue(new \stdClass(), self::getSqlitePlatform());
+        $this->type->convertToDatabaseValue(new \stdClass(), new SQLitePlatform());
     }
 
     public function testNullConversionForDatabaseValue()
     {
-        $this->assertNull($this->type->convertToDatabaseValue(null, self::getSqlitePlatform()));
+        $this->assertNull($this->type->convertToDatabaseValue(null, new SQLitePlatform()));
     }
 
     public function testUuidInterfaceConvertsToPHPValue()
     {
         $uuid = $this->createMock(AbstractUid::class);
-        $actual = $this->type->convertToPHPValue($uuid, self::getSqlitePlatform());
+        $actual = $this->type->convertToPHPValue($uuid, new SQLitePlatform());
 
         $this->assertSame($uuid, $actual);
     }
 
     public function testUuidConvertsToPHPValue()
     {
-        $uuid = $this->type->convertToPHPValue(self::DUMMY_UUID, self::getSqlitePlatform());
+        $uuid = $this->type->convertToPHPValue(self::DUMMY_UUID, new SQLitePlatform());
 
         $this->assertInstanceOf(Uuid::class, $uuid);
         $this->assertEquals(self::DUMMY_UUID, $uuid->__toString());
@@ -122,19 +121,19 @@ final class UuidTypeTest extends TestCase
     {
         $this->expectException(ConversionException::class);
 
-        $this->type->convertToPHPValue('abcdefg', self::getSqlitePlatform());
+        $this->type->convertToPHPValue('abcdefg', new SQLitePlatform());
     }
 
     public function testNullConversionForPHPValue()
     {
-        $this->assertNull($this->type->convertToPHPValue(null, self::getSqlitePlatform()));
+        $this->assertNull($this->type->convertToPHPValue(null, new SQLitePlatform()));
     }
 
     public function testReturnValueIfUuidForPHPValue()
     {
         $uuid = Uuid::v4();
 
-        $this->assertSame($uuid, $this->type->convertToPHPValue($uuid, self::getSqlitePlatform()));
+        $this->assertSame($uuid, $this->type->convertToPHPValue($uuid, new SQLitePlatform()));
     }
 
     public function testGetName()
@@ -151,23 +150,13 @@ final class UuidTypeTest extends TestCase
     public static function provideSqlDeclarations(): \Generator
     {
         yield [new PostgreSQLPlatform(), 'UUID'];
-        yield [self::getSqlitePlatform(), 'BLOB'];
+        yield [new SQLitePlatform(), 'BLOB'];
         yield [new MySQLPlatform(), 'BINARY(16)'];
         yield [new MariaDBPlatform(), 'BINARY(16)'];
     }
 
     public function testRequiresSQLCommentHint()
     {
-        $this->assertTrue($this->type->requiresSQLCommentHint(self::getSqlitePlatform()));
-    }
-
-    private static function getSqlitePlatform(): AbstractPlatform
-    {
-        if (interface_exists(Exception::class)) {
-            // DBAL 4+
-            return new \Doctrine\DBAL\Platforms\SQLitePlatform();
-        }
-
-        return new \Doctrine\DBAL\Platforms\SqlitePlatform();
+        $this->assertTrue($this->type->requiresSQLCommentHint(new SQLitePlatform()));
     }
 }
