@@ -13,6 +13,8 @@ namespace Symfony\Bridge\Doctrine\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\ConversionException;
+use Doctrine\DBAL\Types\Exception\InvalidType;
+use Doctrine\DBAL\Types\Exception\ValueNotConvertible;
 use Doctrine\DBAL\Types\Type;
 use Symfony\Component\Uid\AbstractUid;
 
@@ -23,9 +25,6 @@ abstract class AbstractUidType extends Type
      */
     abstract protected function getUidClass(): string;
 
-    /**
-     * {@inheritdoc}
-     */
     public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
     {
         if ($this->hasNativeGuidType($platform)) {
@@ -33,36 +32,32 @@ abstract class AbstractUidType extends Type
         }
 
         return $platform->getBinaryTypeDeclarationSQL([
-            'length' => '16',
+            'length' => 16,
             'fixed' => true,
         ]);
     }
 
     /**
-     * {@inheritdoc}
-     *
      * @throws ConversionException
      */
-    public function convertToPHPValue($value, AbstractPlatform $platform): ?AbstractUid
+    public function convertToPHPValue(mixed $value, AbstractPlatform $platform): ?AbstractUid
     {
         if ($value instanceof AbstractUid || null === $value) {
             return $value;
         }
 
         if (!\is_string($value)) {
-            throw ConversionException::conversionFailedInvalidType($value, $this->getName(), ['null', 'string', AbstractUid::class]);
+            $this->throwInvalidType($value);
         }
 
         try {
             return $this->getUidClass()::fromString($value);
         } catch (\InvalidArgumentException $e) {
-            throw ConversionException::conversionFailed($value, $this->getName(), $e);
+            $this->throwValueNotConvertible($value, $e);
         }
     }
 
     /**
-     * {@inheritdoc}
-     *
      * @throws ConversionException
      */
     public function convertToDatabaseValue($value, AbstractPlatform $platform): ?string
@@ -78,19 +73,16 @@ abstract class AbstractUidType extends Type
         }
 
         if (!\is_string($value)) {
-            throw ConversionException::conversionFailedInvalidType($value, $this->getName(), ['null', 'string', AbstractUid::class]);
+            $this->throwInvalidType($value);
         }
 
         try {
             return $this->getUidClass()::fromString($value)->$toString();
         } catch (\InvalidArgumentException $e) {
-            throw ConversionException::conversionFailed($value, $this->getName());
+            $this->throwValueNotConvertible($value, $e);
         }
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function requiresSQLCommentHint(AbstractPlatform $platform): bool
     {
         return true;
@@ -98,11 +90,16 @@ abstract class AbstractUidType extends Type
 
     private function hasNativeGuidType(AbstractPlatform $platform): bool
     {
-        // Compatibility with DBAL < 3.4
-        $method = method_exists($platform, 'getStringTypeDeclarationSQL')
-            ? 'getStringTypeDeclarationSQL'
-            : 'getVarcharTypeDeclarationSQL';
+        return $platform->getGuidTypeDeclarationSQL([]) !== $platform->getStringTypeDeclarationSQL(['fixed' => true, 'length' => 36]);
+    }
 
-        return $platform->getGuidTypeDeclarationSQL([]) !== $platform->$method(['fixed' => true, 'length' => 36]);
+    private function throwInvalidType(mixed $value): never
+    {
+        throw InvalidType::new($value, $this->getName(), ['null', 'string', AbstractUid::class]);
+    }
+
+    private function throwValueNotConvertible(mixed $value, \Throwable $previous): never
+    {
+        throw ValueNotConvertible::new($value, $this->getName(), null, $previous);
     }
 }
