@@ -22,18 +22,8 @@ use Twig\Node\Node;
 #[YieldReady]
 final class FormThemeNode extends Node
 {
-    /**
-     * @param bool $only
-     */
-    public function __construct(Node $form, Node $resources, int $lineno, $only = false)
+    public function __construct(Node $form, Node $resources, int $lineno, bool $only = false)
     {
-        if (null === $only || \is_string($only)) {
-            trigger_deprecation('symfony/twig-bridge', '7.2', 'Passing a tag to %s() is deprecated.', __METHOD__);
-            $only = \func_num_args() > 4 ? func_get_arg(4) : true;
-        } elseif (!\is_bool($only)) {
-            throw new \TypeError(\sprintf('Argument 4 passed to "%s()" must be a boolean, "%s" given.', __METHOD__, get_debug_type($only)));
-        }
-
         parent::__construct(['form' => $form, 'resources' => $resources], ['only' => $only], $lineno);
     }
 
