@@ -19,7 +19,6 @@ use Symfony\Component\Security\Acl\Voter\FieldVote;
 use Symfony\Component\Security\Core\Authorization\AccessDecision;
 use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;
 use Symfony\Component\Security\Core\Authorization\UserAuthorizationCheckerInterface;
-use Symfony\Component\Security\Core\User\InMemoryUser;
 use Symfony\Component\Security\Core\User\UserInterface;
 
 class SecurityExtensionTest extends TestCase
@@ -54,12 +53,14 @@ class SecurityExtensionTest extends TestCase
             $this->markTestSkipped('This test requires symfony/security-core 7.3 or superior.');
         }
 
+        $securityChecker = $this->createMock(AuthorizationCheckerInterface::class);
+
         ClassExistsMock::withMockedClasses([FieldVote::class => false]);
 
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Passing a $field to the "is_granted()" function requires symfony/acl.');
 
-        $securityExtension = new SecurityExtension($this->createStub(AuthorizationCheckerInterface::class));
+        $securityExtension = new SecurityExtension($securityChecker);
         $securityExtension->isGranted('ROLE', 'object', 'bar');
     }
 
@@ -70,7 +71,7 @@ class SecurityExtensionTest extends TestCase
             $this->markTestSkipped('This test requires symfony/security-core 7.3 or superior.');
         }
 
-        $user = new InMemoryUser('john', 'password');
+        $user = $this->createMock(UserInterface::class);
         $securityChecker = $this->createMockAuthorizationChecker();
 
         $securityExtension = new SecurityExtension($securityChecker);
@@ -111,7 +112,7 @@ class SecurityExtensionTest extends TestCase
         $this->expectExceptionMessage('Passing a $field to the "is_granted_for_user()" function requires symfony/acl.');
 
         $securityExtension = new SecurityExtension($securityChecker);
-        $securityExtension->isGrantedForUser(new InMemoryUser('john', 'password'), 'ROLE', 'object', 'bar');
+        $securityExtension->isGrantedForUser($this->createMock(UserInterface::class), 'ROLE', 'object', 'bar');
     }
 
     public function testAccessDecision()
@@ -166,10 +167,12 @@ class SecurityExtensionTest extends TestCase
     {
         ClassExistsMock::withMockedClasses([AccessDecision::class => false]);
 
+        $securityChecker = $this->createMock(AuthorizationCheckerInterface::class);
+
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Using the "access_decision()" function requires symfony/security-core >= 7.3. Try running "composer update symfony/security-core".');
 
-        $securityExtension = new SecurityExtension($this->createStub(AuthorizationCheckerInterface::class));
+        $securityExtension = new SecurityExtension($securityChecker);
         $securityExtension->getAccessDecision('ROLE', 'object');
     }
 
@@ -179,7 +182,7 @@ class SecurityExtensionTest extends TestCase
             $this->markTestSkipped('This test requires symfony/security-core 7.3 or superior.');
         }
 
-        $user = new InMemoryUser('john', 'password');
+        $user = $this->createMock(UserInterface::class);
         $securityChecker = $this->createMockAuthorizationChecker();
 
         $securityExtension = new SecurityExtension($securityChecker);
@@ -198,7 +201,7 @@ class SecurityExtensionTest extends TestCase
             $this->markTestSkipped('This test requires symfony/security-core 7.3 or superior.');
         }
 
-        $user = new InMemoryUser('john', 'password');
+        $user = $this->createMock(UserInterface::class);
         $securityChecker = $this->createMockAuthorizationChecker();
 
         $securityExtension = new SecurityExtension($securityChecker);
@@ -225,7 +228,7 @@ class SecurityExtensionTest extends TestCase
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Using the "access_decision_for_user()" function requires symfony/security-core >= 7.3. Try running "composer update symfony/security-core".');
 
-        $securityExtension->getAccessDecisionForUser(new InMemoryUser('john', 'password'), 'ROLE', 'object');
+        $securityExtension->getAccessDecisionForUser($this->createMock(UserInterface::class), 'ROLE', 'object');
     }
 
     private function createMockAuthorizationChecker(): AuthorizationCheckerInterface&UserAuthorizationCheckerInterface
