@@ -30,14 +30,13 @@ use Symfony\Contracts\Service\ServiceProviderInterface;
 #[AsCommand(name: 'cache:pool:invalidate-tags', description: 'Invalidate cache tags for all or a specific pool')]
 final class CachePoolInvalidateTagsCommand extends Command
 {
-    private ServiceProviderInterface $pools;
     private array $poolNames;
 
-    public function __construct(ServiceProviderInterface $pools)
-    {
+    public function __construct(
+        private ServiceProviderInterface $pools,
+    ) {
         parent::__construct();
 
-        $this->pools = $pools;
         $this->poolNames = array_keys($pools->getProvidedServices());
     }
 
