@@ -50,21 +50,14 @@ final class CachePoolPruneCommand extends Command
     protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $io = new SymfonyStyle($input, $output);
-        $exitCode = Command::SUCCESS;
 
         foreach ($this->pools as $name => $pool) {
             $io->comment(\sprintf('Pruning cache pool: <info>%s</info>', $name));
-
-            if (!$pool->prune()) {
-                $io->error(\sprintf('Cache pool "%s" could not be pruned.', $name));
-                $exitCode = Command::FAILURE;
-            }
+            $pool->prune();
         }
 
-        if (Command::SUCCESS === $exitCode) {
-            $io->success('Successfully pruned cache pool(s).');
-        }
+        $io->success('Successfully pruned cache pool(s).');
 
-        return $exitCode;
+        return 0;
     }
 }
