@@ -1,11 +1,10 @@
 <?php
 
 $container->loadFromExtension('framework', [
-    'form' => [
-        'legacy_error_messages' => false,
-    ],
     'session' => [
         'storage_factory_id' => 'session.storage.factory.native',
         'handler_id' => null,
+        'cookie_secure' => 'auto',
+        'cookie_samesite' => 'lax',
     ],
 ]);
