@@ -1,10 +1,6 @@
 <?php
 
 $container->loadFromExtension('framework', [
-    'annotations' => false,
-    'http_method_override' => false,
-    'handle_all_throwables' => true,
-    'php_errors' => ['log' => true],
     'mailer' => [
         'dsn' => 'smtp://example.com',
         'envelope' => [
