@@ -21,7 +21,7 @@ class VoteListenerTest extends TestCase
 {
     public function testOnVoterVote()
     {
-        $voter = $this->createStub(VoterInterface::class);
+        $voter = $this->createMock(VoterInterface::class);
 
         $traceableAccessDecisionManager = $this
             ->getMockBuilder(TraceableAccessDecisionManager::class)
