@@ -12,7 +12,6 @@
 namespace Symfony\Bundle\TwigBundle\Tests\Functional;
 
 use Symfony\Bundle\FrameworkBundle\FrameworkBundle;
-use Symfony\Bundle\FrameworkBundle\Test\HttpClientAssertionsTrait;
 use Symfony\Bundle\TwigBundle\Tests\TestCase;
 use Symfony\Bundle\TwigBundle\TwigBundle;
 use Symfony\Component\Config\Loader\LoaderInterface;
@@ -64,16 +63,10 @@ class NoTemplatingEntryKernel extends Kernel
     {
         $loader->load(function (ContainerBuilder $container) {
             $config = [
-                'http_method_override' => false,
-                'php_errors' => ['log' => true],
                 'secret' => '$ecret',
                 'form' => ['enabled' => false],
             ];
 
-            if (trait_exists(HttpClientAssertionsTrait::class)) {
-                $config['handle_all_throwables'] = true;
-            }
-
             $container
                 ->loadFromExtension('framework', $config)
                 ->loadFromExtension('twig', [
