@@ -10,19 +10,8 @@
  */
 
 use Symfony\Component\Routing\Loader\Configurator\RoutingConfigurator;
-use Symfony\Component\Routing\Loader\XmlFileLoader;
 
 return function (RoutingConfigurator $routes): void {
-    foreach (debug_backtrace(\DEBUG_BACKTRACE_PROVIDE_OBJECT) as $trace) {
-        if (isset($trace['object']) && $trace['object'] instanceof XmlFileLoader && 'doImport' === $trace['function']) {
-            if (__DIR__ === dirname(realpath($trace['args'][3]))) {
-                trigger_deprecation('symfony/routing', '7.3', 'The "profiler.xml" routing configuration file is deprecated, import "profiler.php" instead.');
-
-                break;
-            }
-        }
-    }
-
     $routes->add('_profiler_home', '/')
         ->controller('web_profiler.controller.profiler::homeAction')
     ;
