@@ -11,6 +11,7 @@
 
 namespace Symfony\Component\Asset\Tests;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Asset\Context\ContextInterface;
 use Symfony\Component\Asset\Exception\InvalidArgumentException;
@@ -22,16 +23,14 @@ use Symfony\Component\Asset\VersionStrategy\VersionStrategyInterface;
 
 class UrlPackageTest extends TestCase
 {
-    /**
-     * @dataProvider getConfigs
-     */
-    public function testGetUrl($baseUrls, $format, $path, $expected)
+    #[DataProvider('getConfigs')]
+    public function testGetUrl($baseUrls, string $format, string $path, string $expected)
     {
         $package = new UrlPackage($baseUrls, new StaticVersionStrategy('v1', $format));
         $this->assertSame($expected, $package->getUrl($path));
     }
 
-    public static function getConfigs()
+    public static function getConfigs(): array
     {
         return [
             ['http://example.net', '', 'http://example.com/foo', 'http://example.com/foo'],
@@ -48,10 +47,10 @@ class UrlPackageTest extends TestCase
             ['file:///example/com/foo/', '', 'foo', 'file:///example/com/foo/foo?v1'],
 
             [['http://example.com'], '', '/foo', 'http://example.com/foo?v1'],
-            [['http://example.com', 'http://example.net'], '', '/foo', 'http://example.com/foo?v1'],
-            [['http://example.com', 'http://example.net'], '', '/fooa', 'http://example.net/fooa?v1'],
-            [['file:///example/com', 'file:///example/net'], '', '/foo', 'file:///example/com/foo?v1'],
-            [['ftp://example.com', 'ftp://example.net'], '', '/fooa', 'ftp://example.net/fooa?v1'],
+            [['http://example.com', 'http://example.net'], '', '/foo', 'http://example.net/foo?v1'],
+            [['http://example.com', 'http://example.net'], '', '/fooa', 'http://example.com/fooa?v1'],
+            [['file:///example/com', 'file:///example/net'], '', '/foo', 'file:///example/net/foo?v1'],
+            [['ftp://example.com', 'ftp://example.net'], '', '/fooa', 'ftp://example.com/fooa?v1'],
 
             ['http://example.com', 'version-%2$s/%1$s', '/foo', 'http://example.com/version-v1/foo'],
             ['http://example.com', 'version-%2$s/%1$s', 'foo', 'http://example.com/version-v1/foo'],
@@ -62,29 +61,29 @@ class UrlPackageTest extends TestCase
         ];
     }
 
-    /**
-     * @dataProvider getContextConfigs
-     */
-    public function testGetUrlWithContext($secure, $baseUrls, $format, $path, $expected)
+    #[DataProvider('getContextConfigs')]
+    public function testGetUrlWithContext(bool $secure, $baseUrls, string $format, string $path, string $expected)
     {
         $package = new UrlPackage($baseUrls, new StaticVersionStrategy('v1', $format), $this->getContext($secure));
 
         $this->assertSame($expected, $package->getUrl($path));
     }
 
-    public static function getContextConfigs()
+    public static function getContextConfigs(): array
     {
         return [
             [false, 'http://example.com', '', 'foo', 'http://example.com/foo?v1'],
             [false, ['http://example.com'], '', 'foo', 'http://example.com/foo?v1'],
-            [false, ['http://example.com', 'https://example.com'], '', 'foo', 'http://example.com/foo?v1'],
-            [false, ['http://example.com', 'https://example.com'], '', 'fooa', 'https://example.com/fooa?v1'],
+            [false, ['http://example.com', 'https://example.com'], '', 'foo', 'https://example.com/foo?v1'],
+            [false, ['http://example.com', 'https://example.com'], '', 'fooa', 'http://example.com/fooa?v1'],
             [false, ['http://example.com/bar'], '', 'foo', 'http://example.com/bar/foo?v1'],
             [false, ['http://example.com/bar/'], '', 'foo', 'http://example.com/bar/foo?v1'],
             [false, ['//example.com/bar/'], '', 'foo', '//example.com/bar/foo?v1'],
 
             [true, ['http://example.com'], '', 'foo', 'http://example.com/foo?v1'],
             [true, ['http://example.com', 'https://example.com'], '', 'foo', 'https://example.com/foo?v1'],
+            [true, ['', 'https://example.com'], '', 'foo', 'https://example.com/foo?v1'],
+            [true, ['', 'https://example.com'], '', 'bar', '/bar?v1'],
         ];
     }
 
@@ -105,16 +104,14 @@ class UrlPackageTest extends TestCase
         new UrlPackage([], new EmptyVersionStrategy());
     }
 
-    /**
-     * @dataProvider getWrongBaseUrlConfig
-     */
-    public function testWrongBaseUrl($baseUrls)
+    #[DataProvider('getWrongBaseUrlConfig')]
+    public function testWrongBaseUrl(string $baseUrls)
     {
         $this->expectException(InvalidArgumentException::class);
         new UrlPackage($baseUrls, new EmptyVersionStrategy());
     }
 
-    public static function getWrongBaseUrlConfig()
+    public static function getWrongBaseUrlConfig(): array
     {
         return [
             ['not-a-url'],
@@ -122,7 +119,7 @@ class UrlPackageTest extends TestCase
         ];
     }
 
-    private function getContext($secure)
+    private function getContext($secure): ContextInterface
     {
         $context = $this->createMock(ContextInterface::class);
         $context->expects($this->any())->method('isSecure')->willReturn($secure);
