@@ -11,6 +11,7 @@
 
 namespace Symfony\Component\AssetMapper\Tests\ImportMap;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\AssetMapper\AssetMapperInterface;
@@ -49,9 +50,7 @@ class ImportMapManagerTest extends TestCase
         $this->filesystem->remove(self::$writableRoot);
     }
 
-    /**
-     * @dataProvider getRequirePackageTests
-     */
+    #[DataProvider('getRequirePackageTests')]
     public function testRequire(array $packages, int $expectedProviderPackageArgumentCount, array $resolvedPackages, array $expectedImportMap)
     {
         $manager = $this->createImportMapManager();
@@ -248,7 +247,7 @@ class ImportMapManagerTest extends TestCase
             ->method('resolvePackages')
             ->with($this->callback(function ($packages) {
                 $this->assertInstanceOf(PackageRequireOptions::class, $packages[0]);
-                /** @var PackageRequireOptions[] $packages */
+                /* @var PackageRequireOptions[] $packages */
                 $this->assertCount(2, $packages);
 
                 $this->assertSame('lodash', $packages[0]->packageModuleSpecifier);
@@ -314,9 +313,7 @@ class ImportMapManagerTest extends TestCase
         $manager->update(['cowsay']);
     }
 
-    /**
-     * @dataProvider getPackageNameTests
-     */
+    #[DataProvider('getPackageNameTests')]
     public function testParsePackageName(string $packageName, array $expectedReturn)
     {
         $parsed = ImportMapManager::parsePackageName($packageName);
@@ -366,6 +363,34 @@ class ImportMapManagerTest extends TestCase
         ];
     }
 
+    public function testUpdatePreservesEntrypointStatus()
+    {
+        $manager = $this->createImportMapManager();
+
+        $this->mockImportMap([
+            self::createRemoteEntry('my_entrypoint', version: '1.0.0', isEntrypoint: true),
+            self::createRemoteEntry('standard_lib', version: '2.0.0', isEntrypoint: false),
+        ]);
+
+        $this->packageResolver->expects($this->once())
+            ->method('resolvePackages')
+            ->willReturn([
+                self::resolvedPackage('my_entrypoint', '1.0.1', isEntrypoint: true),
+                self::resolvedPackage('standard_lib', '2.1.0'),
+            ]);
+
+        $this->configReader->expects($this->once())
+            ->method('writeEntries')
+            ->with($this->callback(function (ImportMapEntries $entries) {
+                $this->assertTrue($entries->get('my_entrypoint')->isEntrypoint, 'Entrypoint status lost!');
+                $this->assertFalse($entries->get('standard_lib')->isEntrypoint);
+
+                return true;
+            }));
+
+        $manager->update();
+    }
+
     private function createImportMapManager(): ImportMapManager
     {
         $this->assetMapper = $this->createMock(AssetMapperInterface::class);
@@ -390,10 +415,10 @@ class ImportMapManagerTest extends TestCase
         );
     }
 
-    private static function resolvedPackage(string $packageName, string $version, ImportMapType $type = ImportMapType::JS)
+    private static function resolvedPackage(string $packageName, string $version, ImportMapType $type = ImportMapType::JS, bool $isEntrypoint = false)
     {
         return new ResolvedImportMapPackage(
-            new PackageRequireOptions($packageName),
+            new PackageRequireOptions($packageName, entrypoint: $isEntrypoint),
             $version,
             $type,
         );
@@ -417,11 +442,11 @@ class ImportMapManagerTest extends TestCase
         return ImportMapEntry::createLocal($importName, $type, path: $path, isEntrypoint: $isEntrypoint);
     }
 
-    private static function createRemoteEntry(string $importName, string $version, ?string $path = null, ImportMapType $type = ImportMapType::JS, ?string $packageSpecifier = null): ImportMapEntry
+    private static function createRemoteEntry(string $importName, string $version, ?string $path = null, ImportMapType $type = ImportMapType::JS, ?string $packageSpecifier = null, bool $isEntrypoint = false): ImportMapEntry
     {
-        $packageSpecifier = $packageSpecifier ?? $importName;
-        $path = $path ?? '/vendor/any-path.js';
+        $packageSpecifier ??= $importName;
+        $path ??= '/vendor/any-path.js';
 
-        return ImportMapEntry::createRemote($importName, $type, path: $path, version: $version, packageModuleSpecifier: $packageSpecifier, isEntrypoint: false);
+        return ImportMapEntry::createRemote($importName, $type, path: $path, version: $version, packageModuleSpecifier: $packageSpecifier, isEntrypoint: $isEntrypoint);
     }
 }
