@@ -25,8 +25,6 @@ interface ConfigCacheFactoryInterface
      *
      * @param string   $file     The absolute cache file path
      * @param callable $callable The callable to be executed when the cache needs to be filled (i. e. is not fresh). The cache will be passed as the only parameter to this callback
-     *
-     * @return ConfigCacheInterface The cache instance
      */
-    public function cache($file, $callable);
+    public function cache(string $file, callable $callable): ConfigCacheInterface;
 }
