@@ -345,10 +345,9 @@ class ArrayNodeDefinition extends NodeDefinition implements ParentNodeDefinition
      *
      * @return $this
      */
-    public function canBeEnabled(/* ?string $info = null */): static
+    public function canBeEnabled(?string $info = null): static
     {
         $disabledNode = $this
-            ->attribute('auto_enable', true)
             ->addDefaultsIfNotSet()
             ->treatFalseLike(['enabled' => false])
             ->treatTrueLike(['enabled' => true])
@@ -366,7 +365,6 @@ class ArrayNodeDefinition extends NodeDefinition implements ParentNodeDefinition
                     ->defaultFalse()
         ;
 
-        $info = 1 <= \func_num_args() ? func_get_arg(0) : null;
         if ($info) {
             $disabledNode->info($info);
         }
@@ -383,20 +381,26 @@ class ArrayNodeDefinition extends NodeDefinition implements ParentNodeDefinition
      *
      * @return $this
      */
-    public function canBeDisabled(/* ?string $info = null */): static
+    public function canBeDisabled(?string $info = null): static
     {
         $enabledNode = $this
-            ->attribute('auto_enable', true)
             ->addDefaultsIfNotSet()
             ->treatFalseLike(['enabled' => false])
             ->treatTrueLike(['enabled' => true])
             ->treatNullLike(['enabled' => true])
+            ->beforeNormalization()
+                ->ifArray()
+                ->then(static function ($v) {
+                    $v['enabled'] ??= true;
+
+                    return $v;
+                })
+            ->end()
             ->children()
                 ->booleanNode('enabled')
                     ->defaultTrue()
         ;
 
-        $info = 1 <= \func_num_args() ? func_get_arg(0) : null;
         if ($info) {
             $enabledNode->info($info);
         }
@@ -528,24 +532,18 @@ class ArrayNodeDefinition extends NodeDefinition implements ParentNodeDefinition
             $node->setDeprecated($this->deprecation['package'], $this->deprecation['version'], $this->deprecation['message']);
         }
 
-        $normalizedTypes = $this->allowedTypes ?? [];
-
         if (isset($this->normalization)) {
-            $normalizedTypes = $normalizedTypes ?: $this->normalization->declaredTypes;
+            $allowedTypes = $this->allowedTypes ?? $this->normalization->declaredTypes;
+            foreach ([$this->trueEquivalent, $this->falseEquivalent] as $equivalent) {
+                if (\is_array($equivalent) && $equivalent) {
+                    $allowedTypes[] = ExprBuilder::TYPE_BOOL;
+                }
+            }
             $node->setNormalizationClosures($this->normalization->before);
+            $node->setNormalizedTypes($allowedTypes ?: [ExprBuilder::TYPE_ARRAY]);
             $node->setXmlRemappings($this->normalization->remappings);
         }
 
-        $normalizedTypes[] = ExprBuilder::TYPE_ARRAY;
-
-        foreach ([$this->trueEquivalent, $this->falseEquivalent] as $equivalent) {
-            if (\is_array($equivalent) && $equivalent) {
-                $normalizedTypes[] = ExprBuilder::TYPE_BOOL;
-            }
-        }
-
-        $node->setNormalizedTypes(array_values(array_unique($normalizedTypes)));
-
         if (isset($this->merge)) {
             $node->setAllowOverwrite($this->merge->allowOverwrite);
             $node->setAllowFalse($this->merge->allowFalse);
