@@ -19,7 +19,7 @@ use Symfony\Component\Config\Definition\NodeInterface;
 /**
  * This class provides a fluent interface for defining a node.
  *
- * @template TParent of NodeParentInterface|null = null
+ * @template TParent of NodeParentInterface|null
  *
  * @author Johannes M. Schmitt <schmittjoh@gmail.com>
  */
@@ -179,8 +179,7 @@ abstract class NodeDefinition implements NodeParentInterface
     public function defaultValue(mixed $value): static
     {
         if ($this->required) {
-            // throw new InvalidDefinitionException(sprintf('The node "%s" cannot be required and have a default value.', $this->name));
-            trigger_deprecation('symfony/config', '7.4', 'Setting a default value to a required node is deprecated. Remove the default value from the node "%s" or make it optional.', $this->name);
+            throw new InvalidDefinitionException(\sprintf('The node "%s" cannot be required and have a default value.', $this->name));
         }
 
         $this->default = true;
@@ -197,8 +196,7 @@ abstract class NodeDefinition implements NodeParentInterface
     public function isRequired(): static
     {
         if ($this->default) {
-            // throw new InvalidDefinitionException(sprintf('The node "%s" cannot be required and have a default value.', $this->name));
-            trigger_deprecation('symfony/config', '7.4', 'Flagging a node with a default value as required is deprecated. Remove the default from node "%s" or make it optional.', $this->name);
+            throw new InvalidDefinitionException(\sprintf('The node "%s" cannot be required and have a default value.', $this->name));
         }
 
         $this->required = true;
