@@ -23,9 +23,9 @@ class InputOptionTest extends TestCase
     public function testConstructor()
     {
         $option = new InputOption('foo');
-        $this->assertEquals('foo', $option->getName(), '__construct() takes a name as its first argument');
+        $this->assertSame('foo', $option->getName(), '__construct() takes a name as its first argument');
         $option = new InputOption('--foo');
-        $this->assertEquals('foo', $option->getName(), '__construct() removes the leading -- of the option name');
+        $this->assertSame('foo', $option->getName(), '__construct() removes the leading -- of the option name');
     }
 
     public function testArrayModeWithoutValue()
@@ -52,11 +52,11 @@ class InputOptionTest extends TestCase
     public function testShortcut()
     {
         $option = new InputOption('foo', 'f');
-        $this->assertEquals('f', $option->getShortcut(), '__construct() can take a shortcut as its second argument');
+        $this->assertSame('f', $option->getShortcut(), '__construct() can take a shortcut as its second argument');
         $option = new InputOption('foo', '-f|-ff|fff');
-        $this->assertEquals('f|ff|fff', $option->getShortcut(), '__construct() removes the leading - of the shortcuts');
+        $this->assertSame('f|ff|fff', $option->getShortcut(), '__construct() removes the leading - of the shortcuts');
         $option = new InputOption('foo', ['f', 'ff', '-fff']);
-        $this->assertEquals('f|ff|fff', $option->getShortcut(), '__construct() removes the leading - of the shortcuts');
+        $this->assertSame('f|ff|fff', $option->getShortcut(), '__construct() removes the leading - of the shortcuts');
         $option = new InputOption('foo');
         $this->assertNull($option->getShortcut(), '__construct() makes the shortcut null by default');
         $option = new InputOption('foo', '');
@@ -64,17 +64,15 @@ class InputOptionTest extends TestCase
         $option = new InputOption('foo', []);
         $this->assertNull($option->getShortcut(), '__construct() makes the shortcut null when given an empty array');
         $option = new InputOption('foo', ['f', '', 'fff']);
-        $this->assertEquals('f|fff', $option->getShortcut(), '__construct() removes empty shortcuts');
+        $this->assertSame('f|fff', $option->getShortcut(), '__construct() removes empty shortcuts');
         $option = new InputOption('foo', 'f||fff');
-        $this->assertEquals('f|fff', $option->getShortcut(), '__construct() removes empty shortcuts');
+        $this->assertSame('f|fff', $option->getShortcut(), '__construct() removes empty shortcuts');
         $option = new InputOption('foo', '0');
-        $this->assertEquals('0', $option->getShortcut(), '-0 is an acceptable shortcut value');
+        $this->assertSame('0', $option->getShortcut(), '-0 is an acceptable shortcut value');
         $option = new InputOption('foo', ['0', 'z']);
-        $this->assertEquals('0|z', $option->getShortcut(), '-0 is an acceptable shortcut value when embedded in an array');
+        $this->assertSame('0|z', $option->getShortcut(), '-0 is an acceptable shortcut value when embedded in an array');
         $option = new InputOption('foo', '0|z');
-        $this->assertEquals('0|z', $option->getShortcut(), '-0 is an acceptable shortcut value when embedded in a string-list');
-        $option = new InputOption('foo', false);
-        $this->assertNull($option->getShortcut(), '__construct() makes the shortcut null when given a false as value');
+        $this->assertSame('0|z', $option->getShortcut(), '-0 is an acceptable shortcut value when embedded in a string-list');
     }
 
     public function testModes()
@@ -142,22 +140,22 @@ class InputOptionTest extends TestCase
     public function testGetDescription()
     {
         $option = new InputOption('foo', 'f', null, 'Some description');
-        $this->assertEquals('Some description', $option->getDescription(), '->getDescription() returns the description message');
+        $this->assertSame('Some description', $option->getDescription(), '->getDescription() returns the description message');
     }
 
     public function testGetDefault()
     {
         $option = new InputOption('foo', null, InputOption::VALUE_OPTIONAL, '', 'default');
-        $this->assertEquals('default', $option->getDefault(), '->getDefault() returns the default value');
+        $this->assertSame('default', $option->getDefault(), '->getDefault() returns the default value');
 
         $option = new InputOption('foo', null, InputOption::VALUE_REQUIRED, '', 'default');
-        $this->assertEquals('default', $option->getDefault(), '->getDefault() returns the default value');
+        $this->assertSame('default', $option->getDefault(), '->getDefault() returns the default value');
 
         $option = new InputOption('foo', null, InputOption::VALUE_REQUIRED);
         $this->assertNull($option->getDefault(), '->getDefault() returns null if no default value is configured');
 
         $option = new InputOption('foo', null, InputOption::VALUE_OPTIONAL | InputOption::VALUE_IS_ARRAY);
-        $this->assertEquals([], $option->getDefault(), '->getDefault() returns an empty array if option is an array');
+        $this->assertSame([], $option->getDefault(), '->getDefault() returns an empty array if option is an array');
 
         $option = new InputOption('foo', null, InputOption::VALUE_NONE);
         $this->assertFalse($option->getDefault(), '->getDefault() returns false if the option does not take a value');
@@ -169,11 +167,11 @@ class InputOptionTest extends TestCase
         $option->setDefault(null);
         $this->assertNull($option->getDefault(), '->setDefault() can reset the default value by passing null');
         $option->setDefault('another');
-        $this->assertEquals('another', $option->getDefault(), '->setDefault() changes the default value');
+        $this->assertSame('another', $option->getDefault(), '->setDefault() changes the default value');
 
         $option = new InputOption('foo', null, InputOption::VALUE_REQUIRED | InputOption::VALUE_IS_ARRAY);
         $option->setDefault([1, 2]);
-        $this->assertEquals([1, 2], $option->getDefault(), '->setDefault() changes the default value');
+        $this->assertSame([1, 2], $option->getDefault(), '->setDefault() changes the default value');
     }
 
     public function testDefaultValueWithValueNoneMode()
