@@ -22,29 +22,29 @@ class InputTest extends TestCase
     public function testConstructor()
     {
         $input = new ArrayInput(['name' => 'foo'], new InputDefinition([new InputArgument('name')]));
-        $this->assertEquals('foo', $input->getArgument('name'), '->__construct() takes a InputDefinition as an argument');
+        $this->assertSame('foo', $input->getArgument('name'), '->__construct() takes a InputDefinition as an argument');
     }
 
     public function testOptions()
     {
         $input = new ArrayInput(['--name' => 'foo'], new InputDefinition([new InputOption('name')]));
-        $this->assertEquals('foo', $input->getOption('name'), '->getOption() returns the value for the given option');
+        $this->assertSame('foo', $input->getOption('name'), '->getOption() returns the value for the given option');
 
         $input->setOption('name', 'bar');
-        $this->assertEquals('bar', $input->getOption('name'), '->setOption() sets the value for a given option');
-        $this->assertEquals(['name' => 'bar'], $input->getOptions(), '->getOptions() returns all option values');
+        $this->assertSame('bar', $input->getOption('name'), '->setOption() sets the value for a given option');
+        $this->assertSame(['name' => 'bar'], $input->getOptions(), '->getOptions() returns all option values');
 
         $input = new ArrayInput(['--name' => 'foo'], new InputDefinition([new InputOption('name'), new InputOption('bar', '', InputOption::VALUE_OPTIONAL, '', 'default')]));
-        $this->assertEquals('default', $input->getOption('bar'), '->getOption() returns the default value for optional options');
-        $this->assertEquals(['name' => 'foo', 'bar' => 'default'], $input->getOptions(), '->getOptions() returns all option values, even optional ones');
+        $this->assertSame('default', $input->getOption('bar'), '->getOption() returns the default value for optional options');
+        $this->assertSame(['name' => 'foo', 'bar' => 'default'], $input->getOptions(), '->getOptions() returns all option values, even optional ones');
 
         $input = new ArrayInput(['--name' => 'foo', '--bar' => ''], new InputDefinition([new InputOption('name'), new InputOption('bar', '', InputOption::VALUE_OPTIONAL, '', 'default')]));
-        $this->assertEquals('', $input->getOption('bar'), '->getOption() returns null for options explicitly passed without value (or an empty value)');
-        $this->assertEquals(['name' => 'foo', 'bar' => ''], $input->getOptions(), '->getOptions() returns all option values.');
+        $this->assertSame('', $input->getOption('bar'), '->getOption() returns null for options explicitly passed without value (or an empty value)');
+        $this->assertSame(['name' => 'foo', 'bar' => ''], $input->getOptions(), '->getOptions() returns all option values.');
 
         $input = new ArrayInput(['--name' => 'foo', '--bar' => null], new InputDefinition([new InputOption('name'), new InputOption('bar', '', InputOption::VALUE_OPTIONAL, '', 'default')]));
         $this->assertNull($input->getOption('bar'), '->getOption() returns null for options explicitly passed without value (or an empty value)');
-        $this->assertEquals(['name' => 'foo', 'bar' => null], $input->getOptions(), '->getOptions() returns all option values');
+        $this->assertSame(['name' => 'foo', 'bar' => null], $input->getOptions(), '->getOptions() returns all option values');
 
         $input = new ArrayInput(['--name' => null], new InputDefinition([new InputOption('name', null, InputOption::VALUE_NEGATABLE)]));
         $this->assertTrue($input->hasOption('name'));
@@ -84,15 +84,15 @@ class InputTest extends TestCase
     public function testArguments()
     {
         $input = new ArrayInput(['name' => 'foo'], new InputDefinition([new InputArgument('name')]));
-        $this->assertEquals('foo', $input->getArgument('name'), '->getArgument() returns the value for the given argument');
+        $this->assertSame('foo', $input->getArgument('name'), '->getArgument() returns the value for the given argument');
 
         $input->setArgument('name', 'bar');
-        $this->assertEquals('bar', $input->getArgument('name'), '->setArgument() sets the value for a given argument');
-        $this->assertEquals(['name' => 'bar'], $input->getArguments(), '->getArguments() returns all argument values');
+        $this->assertSame('bar', $input->getArgument('name'), '->setArgument() sets the value for a given argument');
+        $this->assertSame(['name' => 'bar'], $input->getArguments(), '->getArguments() returns all argument values');
 
         $input = new ArrayInput(['name' => 'foo'], new InputDefinition([new InputArgument('name'), new InputArgument('bar', InputArgument::OPTIONAL, '', 'default')]));
-        $this->assertEquals('default', $input->getArgument('bar'), '->getArgument() returns the default value for optional arguments');
-        $this->assertEquals(['name' => 'foo', 'bar' => 'default'], $input->getArguments(), '->getArguments() returns all argument values, even optional ones');
+        $this->assertSame('default', $input->getArgument('bar'), '->getArgument() returns the default value for optional arguments');
+        $this->assertSame(['name' => 'foo', 'bar' => 'default'], $input->getArguments(), '->getArguments() returns all argument values, even optional ones');
     }
 
     public function testSetInvalidArgument()
