@@ -35,10 +35,8 @@ class ResolveInvalidReferencesPass implements CompilerPassInterface
 
     /**
      * Process the ContainerBuilder to resolve invalid references.
-     *
-     * @return void
      */
-    public function process(ContainerBuilder $container)
+    public function process(ContainerBuilder $container): void
     {
         $this->container = $container;
         $this->signalingException = new RuntimeException('Invalid reference.');
@@ -64,7 +62,7 @@ class ResolveInvalidReferencesPass implements CompilerPassInterface
         } elseif ($value instanceof ArgumentInterface) {
             $value->setValues($this->processValue($value->getValues(), $rootLevel, 1 + $level));
         } elseif ($value instanceof Definition) {
-            if ($value->isSynthetic() || $value->isAbstract()) {
+            if ($value->isSynthetic() || $value->isAbstract() || $value->hasTag('container.excluded')) {
                 return $value;
             }
             $value->setArguments($this->processValue($value->getArguments(), 0));
