@@ -18,7 +18,6 @@ use PHPUnit\Framework\TestCase;
 use Psr\Log\LoggerInterface;
 use Psr\Log\NullLogger;
 use Symfony\Bridge\PhpUnit\ClassExistsMock;
-use Symfony\Component\Config\FileLocator;
 use Symfony\Component\Config\Resource\ClassExistenceResource;
 use Symfony\Component\DependencyInjection\Argument\ServiceLocatorArgument;
 use Symfony\Component\DependencyInjection\Argument\TaggedIteratorArgument;
@@ -32,7 +31,6 @@ use Symfony\Component\DependencyInjection\ContainerBuilder;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\DependencyInjection\Exception\AutowiringFailedException;
 use Symfony\Component\DependencyInjection\Exception\RuntimeException;
-use Symfony\Component\DependencyInjection\Loader\XmlFileLoader;
 use Symfony\Component\DependencyInjection\Reference;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\BarInterface;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\CaseSensitiveClass;
@@ -988,22 +986,6 @@ class AutowirePassTest extends TestCase
         }
     }
 
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testInlineServicesAreNotCandidates()
-    {
-        $this->expectUserDeprecationMessage('Since symfony/dependency-injection 7.4: XML configuration format is deprecated, use YAML or PHP instead.');
-
-        $container = new ContainerBuilder();
-        $loader = new XmlFileLoader($container, new FileLocator(realpath(__DIR__.'/../Fixtures/xml')));
-        $loader->load('services_inline_not_candidate.xml');
-
-        $pass = new AutowirePass();
-        $pass->process($container);
-
-        $this->assertSame([], $container->getDefinition('autowired')->getArguments());
-    }
-
     public function testAutowireDecorator()
     {
         $container = new ContainerBuilder();
@@ -1505,30 +1487,4 @@ class AutowirePassTest extends TestCase
         $dep = $service->getDependency()->getSelf();
         $this->assertInstanceOf(ExtendedLazyProxyClass::class, $dep);
     }
-
-    public function testLazyProxyForDecoratedService()
-    {
-        $container = new ContainerBuilder();
-
-        $container->register('some_service', SomeServiceClass::class)
-            ->setPublic(true);
-
-        $container->register('some_service.decorated', DecoratedSomeServiceClass::class)
-            ->setDecoratedService('some_service')
-            ->addArgument(new Reference('.inner'));
-
-        $container->register(LazyDecoratedServiceConsumer::class)
-            ->setAutowired(true)
-            ->setPublic(true);
-
-        $container->setAlias(SomeServiceInterface::class, 'some_service');
-
-        $container->compile();
-
-        $service = $container->get(LazyDecoratedServiceConsumer::class);
-        $this->assertInstanceOf(LazyDecoratedServiceConsumer::class, $service);
-
-        $result = $service->getValue();
-        $this->assertSame('decorated:original', $result);
-    }
 }
