@@ -72,7 +72,6 @@ use Symfony\Component\DependencyInjection\Tests\Fixtures\TestServiceSubscriber;
 use Symfony\Component\DependencyInjection\Tests\Fixtures\WitherStaticReturnType;
 use Symfony\Component\DependencyInjection\TypedReference;
 use Symfony\Component\ExpressionLanguage\Expression;
-use Symfony\Component\VarExporter\LazyObjectInterface;
 
 require_once __DIR__.'/../Fixtures/includes/autowiring_classes.php';
 require_once __DIR__.'/../Fixtures/includes/classes.php';
@@ -342,7 +341,7 @@ class PhpDumperTest extends TestCase
         if ('\\' === \DIRECTORY_SEPARATOR) {
             $dump = str_replace("'.\\DIRECTORY_SEPARATOR.'", '/', $dump);
         }
-        $this->assertStringMatchesFormatFile(self::$fixturesPath.'/php/'.(\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services9_lazy_inlined_factories.txt', $dump);
+        $this->assertStringMatchesFormatFile(self::$fixturesPath.'/php/services9_lazy_inlined_factories.txt', $dump);
     }
 
     public function testServicesWithAnonymousFactories()
@@ -792,7 +791,7 @@ class PhpDumperTest extends TestCase
             'inline_class_loader' => false,
         ]);
         $this->assertStringEqualsFile(
-            self::$fixturesPath.'/php/'.(\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_non_shared_lazy_public.php',
+            self::$fixturesPath.'/php/services_non_shared_lazy_public.php',
             '\\' === \DIRECTORY_SEPARATOR ? str_replace("'.\\DIRECTORY_SEPARATOR.'", '/', $dump) : $dump
         );
         eval('?>'.$dump);
@@ -800,18 +799,10 @@ class PhpDumperTest extends TestCase
         $container = new \Symfony_DI_PhpDumper_Service_Non_Shared_Lazy();
 
         $foo1 = $container->get('foo');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($foo1))->isUninitializedLazyObject($foo1));
-        } else {
-            $this->assertTrue($foo1->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($foo1))->isUninitializedLazyObject($foo1));
 
         $foo2 = $container->get('foo');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($foo2))->isUninitializedLazyObject($foo2));
-        } else {
-            $this->assertTrue($foo2->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($foo2))->isUninitializedLazyObject($foo2));
 
         $this->assertNotSame($foo1, $foo2);
     }
@@ -838,7 +829,7 @@ class PhpDumperTest extends TestCase
 
         $stringDump = print_r($dumps, true);
         $this->assertStringMatchesFormatFile(
-            self::$fixturesPath.'/php/'.(\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_non_shared_lazy_as_files.txt',
+            self::$fixturesPath.'/php/services_non_shared_lazy_as_files.txt',
             '\\' === \DIRECTORY_SEPARATOR ? str_replace("'.\\DIRECTORY_SEPARATOR.'", '/', $stringDump) : $stringDump
         );
 
@@ -850,18 +841,10 @@ class PhpDumperTest extends TestCase
         $container = eval('?>'.$lastDump);
 
         $foo1 = $container->get('non_shared_foo');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($foo1))->isUninitializedLazyObject($foo1));
-        } else {
-            $this->assertTrue($foo1->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($foo1))->isUninitializedLazyObject($foo1));
 
         $foo2 = $container->get('non_shared_foo');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($foo2))->isUninitializedLazyObject($foo2));
-        } else {
-            $this->assertTrue($foo2->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($foo2))->isUninitializedLazyObject($foo2));
 
         $this->assertNotSame($foo1, $foo2);
     }
@@ -881,7 +864,7 @@ class PhpDumperTest extends TestCase
             $dumper->setProxyDumper(new \DummyProxyDumper());
         }
 
-        $this->assertStringEqualsGeneratedFile((\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_non_shared_lazy'.($asGhostObject ? '_ghost' : '').'.php', $dumper->dump());
+        $this->assertStringEqualsGeneratedFile('services_non_shared_lazy'.($asGhostObject ? '_ghost' : '').'.php', $dumper->dump());
     }
 
     public function testNonSharedDuplicates()
@@ -954,7 +937,7 @@ class PhpDumperTest extends TestCase
 
         $dumper = new PhpDumper($container);
 
-        $this->assertStringEqualsGeneratedFile((\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_dedup_lazy.php', $dumper->dump());
+        $this->assertStringEqualsGeneratedFile('services_dedup_lazy.php', $dumper->dump());
     }
 
     public function testLazyArgumentProvideGenerator()
@@ -1617,17 +1600,13 @@ class PhpDumperTest extends TestCase
         $container->compile();
         $dumper = new PhpDumper($container);
         $dump = $dumper->dump(['class' => 'Symfony_DI_PhpDumper_Service_Wither_Lazy']);
-        $this->assertStringEqualsGeneratedFile((\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_wither_lazy.php', $dump);
+        $this->assertStringEqualsGeneratedFile('services_wither_lazy.php', $dump);
         eval('?>'.$dump);
 
         $container = new \Symfony_DI_PhpDumper_Service_Wither_Lazy();
 
         $wither = $container->get('wither');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($wither))->isUninitializedLazyObject($wither));
-        } else {
-            $this->assertTrue($wither->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($wither))->isUninitializedLazyObject($wither));
         $this->assertInstanceOf(Foo::class, $wither->foo);
     }
 
@@ -1646,25 +1625,17 @@ class PhpDumperTest extends TestCase
         $container->compile();
         $dumper = new PhpDumper($container);
         $dump = $dumper->dump(['class' => 'Symfony_DI_PhpDumper_Service_Wither_Lazy_Non_Shared']);
-        $this->assertStringEqualsGeneratedFile((\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'services_wither_lazy_non_shared.php', $dump);
+        $this->assertStringEqualsGeneratedFile('services_wither_lazy_non_shared.php', $dump);
         eval('?>'.$dump);
 
         $container = new \Symfony_DI_PhpDumper_Service_Wither_Lazy_Non_Shared();
 
         $wither1 = $container->get('wither');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($wither1))->isUninitializedLazyObject($wither1));
-        } else {
-            $this->assertTrue($wither1->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($wither1))->isUninitializedLazyObject($wither1));
         $this->assertInstanceOf(Foo::class, $wither1->foo);
 
         $wither2 = $container->get('wither');
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertTrue((new \ReflectionClass($wither2))->isUninitializedLazyObject($wither2));
-        } else {
-            $this->assertTrue($wither2->resetLazyObject());
-        }
+        $this->assertTrue((new \ReflectionClass($wither2))->isUninitializedLazyObject($wither2));
         $this->assertInstanceOf(Foo::class, $wither2->foo);
 
         $this->assertNotSame($wither1, $wither2);
@@ -1992,21 +1963,16 @@ class PhpDumperTest extends TestCase
         $container->compile();
         $dumper = new PhpDumper($container);
 
-        $this->assertStringEqualsGeneratedFile((\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'lazy_autowire_attribute.php', $dumper->dump(['class' => 'Symfony_DI_PhpDumper_Test_Lazy_Autowire_Attribute']));
+        $this->assertStringEqualsGeneratedFile('lazy_autowire_attribute.php', $dumper->dump(['class' => 'Symfony_DI_PhpDumper_Test_Lazy_Autowire_Attribute']));
 
-        require self::$fixturesPath.'/php/'.(\PHP_VERSION_ID < 80400 ? 'legacy_' : '').'lazy_autowire_attribute.php';
+        require self::$fixturesPath.'/php/lazy_autowire_attribute.php';
 
         $container = new \Symfony_DI_PhpDumper_Test_Lazy_Autowire_Attribute();
 
         $this->assertInstanceOf(Foo::class, $container->get('bar')->foo);
-        if (\PHP_VERSION_ID >= 80400) {
-            $r = new \ReflectionClass(Foo::class);
-            $this->assertTrue($r->isUninitializedLazyObject($container->get('bar')->foo));
-            $this->assertSame($container->get('foo'), $r->initializeLazyObject($container->get('bar')->foo));
-        } else {
-            $this->assertInstanceOf(LazyObjectInterface::class, $container->get('bar')->foo);
-            $this->assertSame($container->get('foo'), $container->get('bar')->foo->initializeLazyObject());
-        }
+        $r = new \ReflectionClass(Foo::class);
+        $this->assertTrue($r->isUninitializedLazyObject($container->get('bar')->foo));
+        $this->assertSame($container->get('foo'), $r->initializeLazyObject($container->get('bar')->foo));
     }
 
     public function testLazyAutowireAttributeWithIntersection()
@@ -2029,11 +1995,7 @@ class PhpDumperTest extends TestCase
 
         $dumper = new PhpDumper($container);
 
-        if (\PHP_VERSION_ID >= 80400) {
-            $this->assertStringEqualsGeneratedFile('lazy_autowire_attribute_with_intersection.php', $dumper->dump());
-        } else {
-            $this->assertStringEqualsGeneratedFile('legacy_lazy_autowire_attribute_with_intersection.php', $dumper->dump());
-        }
+        $this->assertStringEqualsGeneratedFile('lazy_autowire_attribute_with_intersection.php', $dumper->dump());
     }
 
     public function testCallableAdapterConsumer()
