@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\DependencyInjection\Tests\LazyProxy\PhpDumper;
 
-use PHPUnit\Framework\Attributes\RequiresPhp;
 use PHPUnit\Framework\TestCase;
 use Psr\Container\ContainerInterface;
 use Symfony\Component\DependencyInjection\Definition;
@@ -66,14 +65,13 @@ class LazyServiceDumperTest extends TestCase
         $dumper->getProxyCode($definition);
     }
 
-    #[RequiresPhp('>=8.3')]
     public function testReadonlyClass()
     {
         $dumper = new LazyServiceDumper();
         $definition = (new Definition(ReadOnlyClass::class))->setLazy(true);
 
         $this->assertTrue($dumper->isProxyCandidate($definition));
-        $this->assertStringContainsString(\PHP_VERSION_ID >= 80400 ? '' : 'readonly class ReadOnlyClassGhost', $dumper->getProxyCode($definition));
+        $this->assertStringContainsString('', $dumper->getProxyCode($definition));
     }
 }
 
