@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\DomCrawler;
 
-use Masterminds\HTML5;
 use Symfony\Component\CssSelector\CssSelectorConverter;
 
 /**
@@ -56,8 +55,6 @@ class Crawler implements \Countable, \IteratorAggregate
      */
     private bool $isHtml = true;
 
-    private ?HTML5 $html5Parser = null;
-
     /**
      * @param \DOMNodeList<\DOMNode>|\DOMNode|\DOMNode[]|string|null $node A Node to use as the base for the crawling
      */
@@ -65,14 +62,8 @@ class Crawler implements \Countable, \IteratorAggregate
         \DOMNodeList|\DOMNode|array|string|null $node = null,
         protected ?string $uri = null,
         ?string $baseHref = null,
-        private bool $useHtml5Parser = true,
     ) {
-        if (\PHP_VERSION_ID >= 80400 && !$useHtml5Parser) {
-            trigger_deprecation('symfony/dom-crawler', '7.4', 'Disabling HTML5 parsing is deprecated. Symfony 8 will unconditionally use the native HTML5 parser.');
-        }
-
         $this->baseHref = $baseHref ?: $uri;
-        $this->html5Parser = \PHP_VERSION_ID < 80400 && $useHtml5Parser ? new HTML5(['disable_html_ns' => true]) : null;
         $this->cachedNamespaces = new \ArrayObject();
 
         $this->add($node);
@@ -174,7 +165,7 @@ class Crawler implements \Countable, \IteratorAggregate
      */
     public function addHtmlContent(string $content, string $charset = 'UTF-8'): void
     {
-        $dom = $this->parseHtmlString($content, $charset);
+        $dom = $this->parseHtml5($content, $charset);
         $this->addDocument($dom);
 
         $base = $this->filterRelativeXPath('descendant-or-self::base')->extract(['href']);
@@ -400,11 +391,9 @@ class Crawler implements \Countable, \IteratorAggregate
      *
      * @see https://developer.mozilla.org/en-US/docs/Web/API/Element/closest#Polyfill
      *
-     * @return ?static
-     *
      * @throws \InvalidArgumentException When current node is empty
      */
-    public function closest(string $selector): ?self
+    public function closest(string $selector): ?static
     {
         if (!$this->nodes) {
             throw new \InvalidArgumentException('The current node list is empty.');
@@ -606,10 +595,6 @@ class Crawler implements \Countable, \IteratorAggregate
         $node = $this->getNode(0);
         $owner = $node->ownerDocument;
 
-        if ($this->html5Parser && '<!DOCTYPE html>' === $owner->saveXML($owner->childNodes[0])) {
-            $owner = $this->html5Parser;
-        }
-
         $html = '';
         foreach ($node->childNodes as $child) {
             $html .= $owner->saveHTML($child);
@@ -630,10 +615,6 @@ class Crawler implements \Countable, \IteratorAggregate
         $node = $this->getNode(0);
         $owner = $node->ownerDocument;
 
-        if ($this->html5Parser && '<!DOCTYPE html>' === $owner->saveXML($owner->childNodes[0])) {
-            $owner = $this->html5Parser;
-        }
-
         return $owner->saveHTML($node);
     }
 
@@ -642,10 +623,8 @@ class Crawler implements \Countable, \IteratorAggregate
      *
      * Since an XPath expression might evaluate to either a simple type or a \DOMNodeList,
      * this method will return either an array of simple types or a new Crawler instance.
-     *
-     * @return array|static
      */
-    public function evaluate(string $xpath): array|self
+    public function evaluate(string $xpath): array|static
     {
         if (null === $this->document) {
             throw new \LogicException('Cannot evaluate the expression on an uninitialized crawler.');
@@ -1068,46 +1047,6 @@ class Crawler implements \Countable, \IteratorAggregate
 
     private function parseHtml5(string $htmlContent, string $charset = 'UTF-8'): \DOMDocument
     {
-        if (!$this->supportsEncoding($charset)) {
-            $htmlContent = $this->convertToHtmlEntities($htmlContent, $charset);
-            $charset = 'UTF-8';
-        }
-
-        return $this->html5Parser->parse($htmlContent, ['encoding' => $charset]);
-    }
-
-    private function supportsEncoding(string $encoding): bool
-    {
-        try {
-            return '' === @mb_convert_encoding('', $encoding, 'UTF-8');
-        } catch (\Throwable) {
-            return false;
-        }
-    }
-
-    private function parseXhtml(string $htmlContent, string $charset = 'UTF-8'): \DOMDocument
-    {
-        if (\PHP_VERSION_ID < 80400 || !$this->useHtml5Parser) {
-            if ('UTF-8' === $charset && preg_match('//u', $htmlContent)) {
-                $htmlContent = '<?xml encoding="UTF-8">'.$htmlContent;
-            } else {
-                $htmlContent = $this->convertToHtmlEntities($htmlContent, $charset);
-            }
-
-            $internalErrors = libxml_use_internal_errors(true);
-
-            $dom = new \DOMDocument('1.0', $charset);
-            $dom->validateOnParse = true;
-
-            if ('' !== trim($htmlContent)) {
-                @$dom->loadHTML($htmlContent);
-            }
-
-            libxml_use_internal_errors($internalErrors);
-
-            return $dom;
-        }
-
         $internalErrors = libxml_use_internal_errors(true);
 
         try {
@@ -1203,7 +1142,6 @@ class Crawler implements \Countable, \IteratorAggregate
         $crawler->document = $this->document;
         $crawler->namespaces = $this->namespaces;
         $crawler->cachedNamespaces = $this->cachedNamespaces;
-        $crawler->html5Parser = $this->html5Parser;
 
         return $crawler;
     }
@@ -1220,39 +1158,6 @@ class Crawler implements \Countable, \IteratorAggregate
         return new CssSelectorConverter($this->isHtml);
     }
 
-    /**
-     * Parse string into DOMDocument object using HTML5 parser if the content is HTML5 and the library is available.
-     * Use libxml parser otherwise.
-     */
-    private function parseHtmlString(string $content, string $charset): \DOMDocument
-    {
-        if ($this->canParseHtml5String($content)) {
-            return $this->parseHtml5($content, $charset);
-        }
-
-        return $this->parseXhtml($content, $charset);
-    }
-
-    private function canParseHtml5String(string $content): bool
-    {
-        if (!$this->html5Parser) {
-            return false;
-        }
-
-        if (false === $pos = stripos($content, '<!doctype html>')) {
-            return false;
-        }
-
-        $header = substr($content, 0, $pos);
-
-        return '' === $header || $this->isValidHtml5Heading($header);
-    }
-
-    private function isValidHtml5Heading(string $heading): bool
-    {
-        return 1 === preg_match('/^\x{FEFF}?\s*(<!--[^>]*?-->\s*)*$/u', $heading);
-    }
-
     private function copyFromHtml5ToDom(\Dom\Node $source, \DOMDocument $target): void
     {
         /** @var list<array{0: iterable<\Dom\Node>, 1: \DOMNode}> $stack */
