@@ -113,15 +113,8 @@ class Parser
      *
      * @throws SyntaxError When the passed expression is invalid
      */
-    public function lint(TokenStream $stream, ?array $names = [], int $flags = 0): void
+    public function lint(TokenStream $stream, array $names = [], int $flags = 0): void
     {
-        if (null === $names) {
-            trigger_deprecation('symfony/expression-language', '7.1', 'Passing "null" as the second argument of "%s()" is deprecated, pass "%s::IGNORE_UNKNOWN_VARIABLES" instead as a third argument.', __METHOD__, __CLASS__);
-
-            $flags |= self::IGNORE_UNKNOWN_VARIABLES;
-            $names = [];
-        }
-
         $this->doParse($stream, $names, $flags);
     }
 
