@@ -18,6 +18,7 @@ use Symfony\Component\Form\Extension\Core\DataMapper\DataMapper;
 use Symfony\Component\Form\FormInterface;
 use Symfony\Component\PropertyAccess\Exception\AccessException as PropertyAccessException;
 use Symfony\Component\PropertyAccess\Exception\NoSuchIndexException;
+use Symfony\Component\PropertyAccess\Exception\NoSuchPropertyException;
 use Symfony\Component\PropertyAccess\Exception\UninitializedPropertyException;
 use Symfony\Component\PropertyAccess\PropertyAccess;
 use Symfony\Component\PropertyAccess\PropertyAccessorInterface;
@@ -72,7 +73,11 @@ class PropertyPathAccessor implements DataAccessorInterface
         // If the data is identical to the value in $data, we are
         // dealing with a reference
         if (!\is_object($data) || !$form->getConfig()->getByReference() || $value !== $getValue()) {
-            $this->propertyAccessor->setValue($data, $propertyPath, $value);
+            try {
+                $this->propertyAccessor->setValue($data, $propertyPath, $value);
+            } catch (NoSuchPropertyException $e) {
+                throw new NoSuchPropertyException($e->getMessage().' Make the property public, add a setter, or set the "mapped" field option in the form type to be false.', 0, $e);
+            }
         }
     }
 
@@ -95,10 +100,7 @@ class PropertyPathAccessor implements DataAccessorInterface
                 return null;
             }
 
-            if (!$e instanceof UninitializedPropertyException
-                // For versions without UninitializedPropertyException check the exception message
-                && (class_exists(UninitializedPropertyException::class) || !str_contains($e->getMessage(), 'You should initialize it'))
-            ) {
+            if (!$e instanceof UninitializedPropertyException) {
                 throw $e;
             }
 
