@@ -22,15 +22,11 @@ use Symfony\Contracts\Translation\TranslatorInterface;
  */
 class CsrfExtension extends AbstractExtension
 {
-    private CsrfTokenManagerInterface $tokenManager;
-    private ?TranslatorInterface $translator;
-    private ?string $translationDomain;
-
-    public function __construct(CsrfTokenManagerInterface $tokenManager, ?TranslatorInterface $translator = null, ?string $translationDomain = null)
-    {
-        $this->tokenManager = $tokenManager;
-        $this->translator = $translator;
-        $this->translationDomain = $translationDomain;
+    public function __construct(
+        private CsrfTokenManagerInterface $tokenManager,
+        private ?TranslatorInterface $translator = null,
+        private ?string $translationDomain = null,
+    ) {
     }
 
     protected function loadTypeExtensions(): array
