@@ -13,7 +13,7 @@ namespace Symfony\Component\Form\Tests\Console\Descriptor;
 
 use Symfony\Component\Form\Console\Descriptor\TextDescriptor;
 
-class TextDescriptorTest extends AbstractDescriptorTest
+class TextDescriptorTest extends AbstractDescriptorTestCase
 {
     protected function getDescriptor()
     {
