@@ -12,9 +12,10 @@
 namespace Symfony\Component\Form\Tests\Extension\Core\EventListener;
 
 use PHPUnit\Framework\TestCase;
+use Symfony\Component\EventDispatcher\EventDispatcher;
 use Symfony\Component\Form\Extension\Core\EventListener\TrimListener;
 use Symfony\Component\Form\Form;
-use Symfony\Component\Form\FormConfigInterface;
+use Symfony\Component\Form\FormConfigBuilder;
 use Symfony\Component\Form\FormEvent;
 
 class TrimListenerTest extends TestCase
@@ -22,7 +23,7 @@ class TrimListenerTest extends TestCase
     public function testTrim()
     {
         $data = ' Foo! ';
-        $form = new Form($this->getMockBuilder(FormConfigInterface::class)->getMock());
+        $form = new Form(new FormConfigBuilder('name', null, new EventDispatcher()));
         $event = new FormEvent($form, $data);
 
         $filter = new TrimListener();
@@ -34,7 +35,7 @@ class TrimListenerTest extends TestCase
     public function testTrimSkipNonStrings()
     {
         $data = 1234;
-        $form = new Form($this->getMockBuilder(FormConfigInterface::class)->getMock());
+        $form = new Form(new FormConfigBuilder('name', null, new EventDispatcher()));
         $event = new FormEvent($form, $data);
 
         $filter = new TrimListener();
