@@ -12,9 +12,12 @@
 namespace Symfony\Component\Form\Tests\Extension\Validator\Type;
 
 use Symfony\Component\Form\Extension\Core\Type\SearchType;
+use Symfony\Component\Form\Test\Traits\ValidatorExtensionTrait;
 
 class SearchTypeValidatorExtensionTest extends BaseValidatorExtensionTestCase
 {
+    use ValidatorExtensionTrait;
+
     protected function createForm(array $options = [])
     {
         return $this->factory->create(SearchType::class, null, $options);
