@@ -25,5 +25,5 @@ interface ParserInterface
      *
      * @param string $context The name of the context element in which the HTML is parsed
      */
-    public function parse(string $html/* , string $context = 'body' */): \Dom\Node|\DOMNode|null;
+    public function parse(string $html, string $context = 'body'): \Dom\Node|\DOMNode|null;
 }
