@@ -22,18 +22,14 @@ use Symfony\Contracts\HttpClient\ChunkInterface;
  */
 class ErrorChunk implements ChunkInterface
 {
-    private $didThrow = false;
-    private $offset;
-    private $errorMessage;
-    private $error;
-
-    /**
-     * @param \Throwable|string $error
-     */
-    public function __construct(int $offset, $error)
-    {
-        $this->offset = $offset;
+    private bool $didThrow = false;
+    private string $errorMessage;
+    private ?\Throwable $error = null;
 
+    public function __construct(
+        private int $offset,
+        \Throwable|string $error,
+    ) {
         if (\is_string($error)) {
             $this->errorMessage = $error;
         } else {
@@ -42,9 +38,6 @@ class ErrorChunk implements ChunkInterface
         }
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function isTimeout(): bool
     {
         $this->didThrow = true;
@@ -56,62 +49,41 @@ class ErrorChunk implements ChunkInterface
         return true;
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function isFirst(): bool
     {
         $this->didThrow = true;
         throw null !== $this->error ? new TransportException($this->errorMessage, 0, $this->error) : new TimeoutException($this->errorMessage);
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function isLast(): bool
     {
         $this->didThrow = true;
         throw null !== $this->error ? new TransportException($this->errorMessage, 0, $this->error) : new TimeoutException($this->errorMessage);
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function getInformationalStatus(): ?array
     {
         $this->didThrow = true;
         throw null !== $this->error ? new TransportException($this->errorMessage, 0, $this->error) : new TimeoutException($this->errorMessage);
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function getContent(): string
     {
         $this->didThrow = true;
         throw null !== $this->error ? new TransportException($this->errorMessage, 0, $this->error) : new TimeoutException($this->errorMessage);
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function getOffset(): int
     {
         return $this->offset;
     }
 
-    /**
-     * {@inheritdoc}
-     */
     public function getError(): ?string
     {
         return $this->errorMessage;
     }
 
-    /**
-     * @return bool Whether the wrapped error has been thrown or not
-     */
-    public function didThrow(bool $didThrow = null): bool
+    public function didThrow(?bool $didThrow = null): bool
     {
         if (null !== $didThrow && $this->didThrow !== $didThrow) {
             return !$this->didThrow = $didThrow;
@@ -120,12 +92,12 @@ class ErrorChunk implements ChunkInterface
         return $this->didThrow;
     }
 
-    public function __sleep(): array
+    public function __serialize(): array
     {
         throw new \BadMethodCallException('Cannot serialize '.__CLASS__);
     }
 
-    public function __wakeup()
+    public function __unserialize(array $data): void
     {
         throw new \BadMethodCallException('Cannot unserialize '.__CLASS__);
     }
