@@ -65,17 +65,18 @@ abstract class Kernel implements KernelInterface, RebootableInterface, Terminabl
     private ?string $warmupDir = null;
     private int $requestStackSize = 0;
     private bool $resetServices = false;
+    private bool $handlingHttpCache = false;
 
     /**
      * @var array<string, bool>
      */
     private static array $freshCache = [];
 
-    public const VERSION = '8.0.0';
-    public const VERSION_ID = 80000;
+    public const VERSION = '8.0.2';
+    public const VERSION_ID = 80002;
     public const MAJOR_VERSION = 8;
     public const MINOR_VERSION = 0;
-    public const RELEASE_VERSION = 0;
+    public const RELEASE_VERSION = 2;
     public const EXTRA_VERSION = '';
 
     public const END_OF_MAINTENANCE = '07/2026';
@@ -96,6 +97,7 @@ abstract class Kernel implements KernelInterface, RebootableInterface, Terminabl
         $this->container = null;
         $this->requestStackSize = 0;
         $this->resetServices = false;
+        $this->handlingHttpCache = false;
     }
 
     public function boot(): void
@@ -168,13 +170,22 @@ abstract class Kernel implements KernelInterface, RebootableInterface, Terminabl
             $container = $this->container ?? $this->preBoot();
 
             if ($container->has('http_cache')) {
-                return $container->get('http_cache')->handle($request, $type, $catch);
+                $this->handlingHttpCache = true;
+
+                try {
+                    return $container->get('http_cache')->handle($request, $type, $catch);
+                } finally {
+                    $this->handlingHttpCache = false;
+                    $this->resetServices = true;
+                }
             }
         }
 
         $this->boot();
         ++$this->requestStackSize;
-        $this->resetServices = true;
+        if (!$this->handlingHttpCache) {
+            $this->resetServices = true;
+        }
 
         try {
             return $this->getHttpKernel()->handle($request, $type, $catch);
