@@ -101,12 +101,11 @@ class SsiFragmentRendererTest extends TestCase
 
     private function getInlineStrategy($called = false)
     {
-        if (!$called) {
-            return $this->createStub(InlineFragmentRenderer::class);
-        }
-
         $inline = $this->createMock(InlineFragmentRenderer::class);
-        $inline->expects($this->once())->method('render');
+
+        if ($called) {
+            $inline->expects($this->once())->method('render');
+        }
 
         return $inline;
     }
