@@ -930,6 +930,10 @@ return [
             'EC$',
             'دولار شرق الكاريبي',
         ],
+        'XCG' => [
+            'Cg.',
+            'غيلدر كاريبي',
+        ],
         'XEU' => [
             'XEU',
             'وحدة النقد الأوروبية',
@@ -994,6 +998,10 @@ return [
             'ZWD',
             'دولار زمبابوي',
         ],
+        'ZWG' => [
+            'ZWG',
+            'ذهب زيمبابوي',
+        ],
         'ZWL' => [
             'ZWL',
             'دولار زمبابوي 2009',
