@@ -3,8 +3,8 @@
 return [
     'Names' => [
         'AUD' => [
-            0 => '$',
-            1 => 'Australian Dollar',
+            '$',
+            'Australian Dollar',
         ],
     ],
 ];
