@@ -3,8 +3,8 @@
 return [
     'Names' => [
         'TZS' => [
-            0 => 'TSh',
-            1 => 'Tanzanian Shilling',
+            'TSh',
+            'Tanzanian Shilling',
         ],
     ],
 ];
