@@ -3,8 +3,8 @@
 return [
     'Names' => [
         'USD' => [
-            0 => '$',
-            1 => 'dólar estadounidense',
+            '$',
+            'dólar estadounidense',
         ],
     ],
 ];
