@@ -1058,6 +1058,10 @@ return [
             'EC$',
             'ອີ​ສ ຄາ​ຣິ​ບຽນ ໂດ​ລ່າ',
         ],
+        'XCG' => [
+            'Cg.',
+            'ຄາຣິບຽນ ກິວເດີ',
+        ],
         'XEU' => [
             'XEU',
             'ຫົວໜ່ວຍສະກຸນເງິນ ເອີຣົບ',
@@ -1134,6 +1138,10 @@ return [
             'ZWD',
             'ດອນລາ ຊິມບັບເວ (1980–2008)',
         ],
+        'ZWG' => [
+            'ZWG',
+            'ຊິມບັບວຽນ ໂກລ',
+        ],
         'ZWL' => [
             'ZWL',
             'ດອນລາ ຊິມບັບເວ (2009)',
