@@ -3,12 +3,12 @@
 return [
     'Names' => [
         'GEL' => [
-            0 => 'GEL',
-            1 => 'Лар',
+            'GEL',
+            'Лар',
         ],
         'RUB' => [
-            0 => '₽',
-            1 => 'Сом',
+            '₽',
+            'Сом',
         ],
     ],
 ];
