@@ -23,6 +23,7 @@ return [
         'am' => 'amharština',
         'an' => 'aragonština',
         'ang' => 'staroangličtina',
+        'ann' => 'obolo',
         'anp' => 'angika',
         'ar' => 'arabština',
         'arc' => 'aramejština',
@@ -38,6 +39,7 @@ return [
         'asa' => 'asu',
         'ase' => 'znaková řeč (americká)',
         'ast' => 'asturština',
+        'atj' => 'atikamekština',
         'av' => 'avarština',
         'avk' => 'kotava',
         'awa' => 'awadhština',
@@ -59,6 +61,7 @@ return [
         'bfd' => 'bafut',
         'bfq' => 'badagština',
         'bg' => 'bulharština',
+        'bgc' => 'harijánština',
         'bgn' => 'balúčština (západní)',
         'bho' => 'bhódžpurština',
         'bi' => 'bislamština',
@@ -67,6 +70,7 @@ return [
         'bjn' => 'bandžarština',
         'bkm' => 'kom',
         'bla' => 'siksika',
+        'blo' => 'aniiština',
         'bm' => 'bambarština',
         'bn' => 'bengálština',
         'bo' => 'tibetština',
@@ -102,15 +106,24 @@ return [
         'chp' => 'čipevajština',
         'chr' => 'čerokézština',
         'chy' => 'čejenština',
+        'cic' => 'čikasavština',
         'ckb' => 'kurdština (sorání)',
+        'clc' => 'čilkotinština',
         'co' => 'korsičtina',
         'cop' => 'koptština',
         'cps' => 'kapiznonština',
         'cr' => 'kríjština',
-        'crh' => 'turečtina (krymská)',
+        'crg' => 'mičif',
+        'crh' => 'tatarština (krymská)',
+        'crj' => 'kríjština (jihovýchodní)',
+        'crk' => 'kríjština (z plání)',
+        'crl' => 'kríjština (severovýchodní)',
+        'crm' => 'kríjština (Moose)',
+        'crr' => 'algonkinština (Karolína)',
         'crs' => 'kreolština (seychelská)',
         'cs' => 'čeština',
         'csb' => 'kašubština',
+        'csw' => 'kríjština (z bažin)',
         'cu' => 'staroslověnština',
         'cv' => 'čuvaština',
         'cy' => 'velština',
@@ -185,7 +198,6 @@ return [
         'gmh' => 'hornoněmčina (středověká)',
         'gn' => 'guaranština',
         'goh' => 'hornoněmčina (stará)',
-        'gom' => 'konkánština (Goa)',
         'gon' => 'góndština',
         'gor' => 'gorontalo',
         'got' => 'gótština',
@@ -202,6 +214,7 @@ return [
         'hai' => 'haidština',
         'hak' => 'čínština (dialekty Hakka)',
         'haw' => 'havajština',
+        'hax' => 'haidština (jižní)',
         'he' => 'hebrejština',
         'hi' => 'hindština',
         'hif' => 'hindština (Fidži)',
@@ -215,6 +228,7 @@ return [
         'ht' => 'haitština',
         'hu' => 'maďarština',
         'hup' => 'hupa',
+        'hur' => 'halkomelem',
         'hy' => 'arménština',
         'hz' => 'hererština',
         'ia' => 'interlingua',
@@ -225,6 +239,7 @@ return [
         'ig' => 'igboština',
         'ii' => 'iština (sečuánská)',
         'ik' => 'inupiakština',
+        'ikt' => 'inuktitutština (západokanadská)',
         'ilo' => 'ilokánština',
         'inh' => 'inguština',
         'io' => 'ido',
@@ -291,6 +306,8 @@ return [
         'kut' => 'kutenajština',
         'kv' => 'komijština',
         'kw' => 'kornština',
+        'kwk' => 'kvakiutština',
+        'kxv' => 'kúvi',
         'ky' => 'kyrgyzština',
         'la' => 'latina',
         'lad' => 'ladinština',
@@ -303,8 +320,10 @@ return [
         'lg' => 'gandština',
         'li' => 'limburština',
         'lij' => 'ligurština',
+        'lil' => 'lillooetština',
         'liv' => 'livonština',
         'lkt' => 'lakotština',
+        'lld' => 'ladinština',
         'lmo' => 'lombardština',
         'ln' => 'lingalština',
         'lo' => 'laoština',
@@ -312,6 +331,7 @@ return [
         'lou' => 'kreolština (Louisiana)',
         'loz' => 'lozština',
         'lrc' => 'lúrština (severní)',
+        'lsm' => 'samia',
         'lt' => 'litevština',
         'ltg' => 'latgalština',
         'lu' => 'lubu-katanžština',
@@ -350,6 +370,7 @@ return [
         'mn' => 'mongolština',
         'mnc' => 'mandžuština',
         'mni' => 'manipurština',
+        'moe' => 'innu-aimun',
         'moh' => 'mohawkština',
         'mos' => 'mosi',
         'mr' => 'maráthština',
@@ -399,6 +420,11 @@ return [
         'nzi' => 'nzima',
         'oc' => 'okcitánština',
         'oj' => 'odžibvejština',
+        'ojb' => 'odžibvejština (severozápadní)',
+        'ojc' => 'odžibvejština (střední)',
+        'ojs' => 'odžibvejština (severní)',
+        'ojw' => 'odžibvejština (západní)',
+        'oka' => 'okanaganština',
         'om' => 'oromština',
         'or' => 'urijština',
         'os' => 'osetština',
@@ -418,10 +444,12 @@ return [
         'pfl' => 'falčtina',
         'phn' => 'féničtina',
         'pi' => 'pálí',
+        'pis' => 'pidžin (Šalomounovy ostrovy)',
         'pl' => 'polština',
         'pms' => 'piemonština',
         'pnt' => 'pontština',
         'pon' => 'pohnpeiština',
+        'pqm' => 'malesitština-passamaquoddština',
         'prg' => 'pruština',
         'pro' => 'provensálština',
         'ps' => 'paštština',
@@ -480,6 +508,7 @@ return [
         'sid' => 'sidamo',
         'sk' => 'slovenština',
         'sl' => 'slovinština',
+        'slh' => 'lushootseed (jižní)',
         'sli' => 'němčina (slezská)',
         'sly' => 'selajarština',
         'sm' => 'samojština',
@@ -499,6 +528,7 @@ return [
         'ssy' => 'saho',
         'st' => 'sotština (jižní)',
         'stq' => 'fríština (saterlandská)',
+        'str' => 'saliština (z úžin)',
         'su' => 'sundština',
         'suk' => 'sukuma',
         'sus' => 'susu',
@@ -510,6 +540,7 @@ return [
         'syr' => 'syrština',
         'szl' => 'slezština',
         'ta' => 'tamilština',
+        'tce' => 'tutčonština (jižní)',
         'tcy' => 'tuluština',
         'te' => 'telugština',
         'tem' => 'temne',
@@ -517,7 +548,9 @@ return [
         'ter' => 'tereno',
         'tet' => 'tetumština',
         'tg' => 'tádžičtina',
+        'tgx' => 'tagiš',
         'th' => 'thajština',
+        'tht' => 'tahltan',
         'ti' => 'tigrinijština',
         'tig' => 'tigrejština',
         'tiv' => 'tivština',
@@ -532,6 +565,7 @@ return [
         'tn' => 'setswanština',
         'to' => 'tongánština',
         'tog' => 'tonžština (nyasa)',
+        'tok' => 'toki pona',
         'tpi' => 'tok pisin',
         'tr' => 'turečtina',
         'tru' => 'turojština',
@@ -540,6 +574,7 @@ return [
         'tsd' => 'tsakonština',
         'tsi' => 'tsimšijské jazyky',
         'tt' => 'tatarština',
+        'ttm' => 'tutčonština (severní)',
         'ttt' => 'tatština',
         'tum' => 'tumbukština',
         'tvl' => 'tuvalština',
@@ -555,13 +590,13 @@ return [
         'umb' => 'umbundu',
         'ur' => 'urdština',
         'uz' => 'uzbečtina',
-        'vai' => 'vai',
         've' => 'venda',
         'vec' => 'benátština',
         'vep' => 'vepština',
         'vi' => 'vietnamština',
         'vls' => 'vlámština (západní)',
         'vmf' => 'němčina (mohansko-franské dialekty)',
+        'vmw' => 'makhuwština',
         'vo' => 'volapük',
         'vot' => 'votština',
         'vro' => 'võruština',
@@ -577,6 +612,7 @@ return [
         'xal' => 'kalmyčtina',
         'xh' => 'xhoština',
         'xmf' => 'mingrelština',
+        'xnr' => 'kángrí',
         'xog' => 'sogština',
         'yao' => 'jaoština',
         'yap' => 'japština',
