@@ -52,6 +52,7 @@ return [
         'bik' => 'बिकोल',
         'bin' => 'बिनी',
         'bla' => 'सिक्सिका',
+        'blo' => 'ॲनीआय',
         'bm' => 'बाम्बारा',
         'bn' => 'बंगाली',
         'bo' => 'तिबेटी',
@@ -191,13 +192,13 @@ return [
         'hu' => 'हंगेरियन',
         'hup' => 'हूपा',
         'hur' => 'हॉल्कमेलम',
-        'hy' => 'आर्मेनियन',
+        'hy' => 'अर्मेनियन',
         'hz' => 'हरेरो',
         'ia' => 'इंटरलिंग्वा',
         'iba' => 'इबान',
         'ibb' => 'इबिबिओ',
         'id' => 'इंडोनेशियन',
-        'ie' => 'इन्टरलिंग',
+        'ie' => 'इंटरलिंग',
         'ig' => 'ईग्बो',
         'ii' => 'सिचुआन यी',
         'ik' => 'इनूपियाक',
@@ -250,7 +251,7 @@ return [
         'krc' => 'कराचय-बाल्कर',
         'krl' => 'करेलियन',
         'kru' => 'कुरूख',
-        'ks' => 'काश्मीरी',
+        'ks' => 'काश्मिरी',
         'ksb' => 'शांबाला',
         'ksf' => 'बाफिया',
         'ksh' => 'कोलोग्नियन',
@@ -260,6 +261,7 @@ return [
         'kv' => 'कोमी',
         'kw' => 'कोर्निश',
         'kwk' => 'क्वक्क्वाला',
+        'kxv' => 'कुवी',
         'ky' => 'किरगीझ',
         'la' => 'लॅटिन',
         'lad' => 'लादीनो',
@@ -270,8 +272,10 @@ return [
         'lez' => 'लेझ्घीयन',
         'lg' => 'गांडा',
         'li' => 'लिंबूर्गिश',
+        'lij' => 'लिगुरिअन',
         'lil' => 'लिलूएट',
         'lkt' => 'लाकोटा',
+        'lmo' => 'लोंबार्ड',
         'ln' => 'लिंगाला',
         'lo' => 'लाओ',
         'lol' => 'मोंगो',
@@ -341,7 +345,7 @@ return [
         'nmg' => 'क्वासिओ',
         'nn' => 'नॉर्वेजियन न्योर्स्क',
         'nnh' => 'जिएम्बून',
-        'no' => 'नोर्वेजियन',
+        'no' => 'नॉर्वेजियन',
         'nog' => 'नोगाई',
         'non' => 'पुरातन नॉर्स',
         'nqo' => 'एन्को',
@@ -454,6 +458,7 @@ return [
         'swb' => 'कोमोरियन',
         'syc' => 'अभिजात सिरियाक',
         'syr' => 'सिरियाक',
+        'szl' => 'सिलेशियन',
         'ta' => 'तामिळ',
         'tce' => 'दक्षिणात्य टचोन',
         'te' => 'तेलगू',
@@ -501,7 +506,9 @@ return [
         'uz' => 'उझ्बेक',
         'vai' => 'वाई',
         've' => 'व्हेंदा',
+        'vec' => 'व्हेनेशियन',
         'vi' => 'व्हिएतनामी',
+        'vmw' => 'मखुवा',
         'vo' => 'ओलापुक',
         'vot' => 'वॉटिक',
         'vun' => 'वुंजो',
@@ -515,6 +522,7 @@ return [
         'wuu' => 'व्हू चिनी',
         'xal' => 'काल्मिक',
         'xh' => 'खोसा',
+        'xnr' => 'कांगरी',
         'xog' => 'सोगा',
         'yao' => 'याओ',
         'yap' => 'यापीस',
