@@ -12,11 +12,9 @@ return [
         'moh' => 'мохок',
         'nqo' => 'н’ко',
         'shi' => 'јужни шилха',
-        'tzm' => 'централноатласки тамашек',
         'xh' => 'исикоса',
         'zgh' => 'стандардни марокански тамашек',
         'zu' => 'исизулу',
     ],
-    'LocalizedNames' => [
-    ],
+    'LocalizedNames' => [],
 ];
