@@ -23,6 +23,7 @@ return [
         'am' => 'อัมฮารา',
         'an' => 'อารากอน',
         'ang' => 'อังกฤษโบราณ',
+        'ann' => 'โอโบโล',
         'anp' => 'อังคิกา',
         'ar' => 'อาหรับ',
         'arc' => 'อราเมอิก',
@@ -38,6 +39,7 @@ return [
         'asa' => 'อาซู',
         'ase' => 'ภาษามืออเมริกัน',
         'ast' => 'อัสตูเรียส',
+        'atj' => 'อะทิคาเมก',
         'av' => 'อาวาร์',
         'avk' => 'โคตาวา',
         'awa' => 'อวธี',
@@ -59,6 +61,7 @@ return [
         'bfd' => 'บาฟัต',
         'bfq' => 'พทคะ',
         'bg' => 'บัลแกเรีย',
+        'bgc' => 'หริยนวี',
         'bgn' => 'บาลูจิตะวันตก',
         'bho' => 'โภชปุรี',
         'bi' => 'บิสลามา',
@@ -67,6 +70,7 @@ return [
         'bjn' => 'บันจาร์',
         'bkm' => 'กม',
         'bla' => 'สิกสิกา',
+        'blo' => 'อานี',
         'bm' => 'บัมบารา',
         'bn' => 'บังกลา',
         'bo' => 'ทิเบต',
@@ -103,14 +107,22 @@ return [
         'chr' => 'เชอโรกี',
         'chy' => 'เชเยนเน',
         'ckb' => 'เคิร์ดตอนกลาง',
+        'clc' => 'ชิลโคติน',
         'co' => 'คอร์ซิกา',
         'cop' => 'คอปติก',
         'cps' => 'กาปิซนอน',
         'cr' => 'ครี',
+        'crg' => 'มิชิฟ',
         'crh' => 'ตุรกีไครเมีย',
+        'crj' => 'ครีตะวันออกเฉียงใต้',
+        'crk' => 'เพลนส์ครี',
+        'crl' => 'ครีตะวันออกเฉียงเหนือ',
+        'crm' => 'มูสครี',
+        'crr' => 'อัลกอนควินแคโรไลนา',
         'crs' => 'ครีโอลเซเซลส์ฝรั่งเศส',
         'cs' => 'เช็ก',
         'csb' => 'คาซูเบียน',
+        'csw' => 'สวอมปีครี',
         'cu' => 'เชอร์ชสลาวิก',
         'cv' => 'ชูวัช',
         'cy' => 'เวลส์',
@@ -162,7 +174,7 @@ return [
         'fo' => 'แฟโร',
         'fon' => 'ฟอน',
         'fr' => 'ฝรั่งเศส',
-        'frc' => 'ฝรั่งเศสกาฌ็อง',
+        'frc' => 'ฝรั่งเศสเคจัน',
         'frm' => 'ฝรั่งเศสกลาง',
         'fro' => 'ฝรั่งเศสโบราณ',
         'frp' => 'อาร์พิตา',
@@ -185,7 +197,6 @@ return [
         'gmh' => 'เยอรมันสูงกลาง',
         'gn' => 'กัวรานี',
         'goh' => 'เยอรมันสูงโบราณ',
-        'gom' => 'กอนกานีของกัว',
         'gon' => 'กอนดิ',
         'gor' => 'กอรอนทาโล',
         'got' => 'โกธิก',
@@ -202,6 +213,7 @@ return [
         'hai' => 'ไฮดา',
         'hak' => 'จีนแคะ',
         'haw' => 'ฮาวาย',
+        'hax' => 'เฮดาใต้',
         'he' => 'ฮิบรู',
         'hi' => 'ฮินดี',
         'hif' => 'ฮินดีฟิจิ',
@@ -215,6 +227,7 @@ return [
         'ht' => 'เฮติครีโอล',
         'hu' => 'ฮังการี',
         'hup' => 'ฮูปา',
+        'hur' => 'ฮัลโกเมเลม',
         'hy' => 'อาร์เมเนีย',
         'hz' => 'เฮเรโร',
         'ia' => 'อินเตอร์ลิงกัว',
@@ -225,6 +238,7 @@ return [
         'ig' => 'อิกโบ',
         'ii' => 'เสฉวนยี่',
         'ik' => 'อีนูเปียก',
+        'ikt' => 'อินุกติตุตแคนาดาตะวันตก',
         'ilo' => 'อีโลโก',
         'inh' => 'อินกุช',
         'io' => 'อีโด',
@@ -248,7 +262,7 @@ return [
         'kaj' => 'คจู',
         'kam' => 'คัมบา',
         'kaw' => 'กวี',
-        'kbd' => 'คาร์บาเดีย',
+        'kbd' => 'คาบาร์เดีย',
         'kbl' => 'คาเนมบู',
         'kcg' => 'ทีแยป',
         'kde' => 'มาคอนเด',
@@ -280,7 +294,7 @@ return [
         'krc' => 'คาราไช-บัลคาร์',
         'kri' => 'คริโอ',
         'krj' => 'กินารายอา',
-        'krl' => 'แกรเลียน',
+        'krl' => 'คารีเลียน',
         'kru' => 'กุรุข',
         'ks' => 'แคชเมียร์',
         'ksb' => 'ชัมบาลา',
@@ -291,6 +305,8 @@ return [
         'kut' => 'คูเทไน',
         'kv' => 'โกมิ',
         'kw' => 'คอร์นิช',
+        'kwk' => 'ควักวาลา',
+        'kxv' => 'กูวี',
         'ky' => 'คีร์กีซ',
         'la' => 'ละติน',
         'lad' => 'ลาดิโน',
@@ -298,20 +314,22 @@ return [
         'lah' => 'ลาฮ์นดา',
         'lam' => 'แลมบา',
         'lb' => 'ลักเซมเบิร์ก',
-        'lez' => 'เลซเกียน',
+        'lez' => 'เลซเกีย',
         'lfn' => 'ลิงกัวฟรังกาโนวา',
         'lg' => 'ยูกันดา',
         'li' => 'ลิมเบิร์ก',
         'lij' => 'ลิกูเรีย',
+        'lil' => 'ลิลลูเอต',
         'liv' => 'ลิโวเนีย',
         'lkt' => 'ลาโกตา',
         'lmo' => 'ลอมบาร์ด',
         'ln' => 'ลิงกาลา',
         'lo' => 'ลาว',
         'lol' => 'มองโก',
-        'lou' => 'ภาษาครีโอลุยเซียนา',
+        'lou' => 'ครีโอลุยเซียนา',
         'loz' => 'โลซิ',
         'lrc' => 'ลูรีเหนือ',
+        'lsm' => 'ซาเมีย',
         'lt' => 'ลิทัวเนีย',
         'ltg' => 'ลัตเกล',
         'lu' => 'ลูบา-กาตองกา',
@@ -341,7 +359,7 @@ return [
         'mga' => 'ไอริชกลาง',
         'mgh' => 'มากัววา-มีทโท',
         'mgo' => 'เมตา',
-        'mh' => 'มาร์แชลลิส',
+        'mh' => 'มาร์แชลล์',
         'mi' => 'เมารี',
         'mic' => 'มิกแมก',
         'min' => 'มีนังกาเบา',
@@ -350,6 +368,7 @@ return [
         'mn' => 'มองโกเลีย',
         'mnc' => 'แมนจู',
         'mni' => 'มณีปุระ',
+        'moe' => 'อินนุ-ไอมุน',
         'moh' => 'โมฮอว์ก',
         'mos' => 'โมซี',
         'mr' => 'มราฐี',
@@ -357,7 +376,7 @@ return [
         'ms' => 'มาเลย์',
         'mt' => 'มอลตา',
         'mua' => 'มันดัง',
-        'mus' => 'ครีก',
+        'mus' => 'มัสคีกี',
         'mwl' => 'มีรันดา',
         'mwr' => 'มารวาฑี',
         'mwv' => 'เม็นตาไว',
@@ -399,29 +418,36 @@ return [
         'nzi' => 'นซิมา',
         'oc' => 'อ็อกซิตัน',
         'oj' => 'โอจิบวา',
+        'ojb' => 'โอจิบเวตะวันตกเฉียงเหนือ',
+        'ojc' => 'โอจิบเวตอนกลาง',
+        'ojs' => 'ออจิ-ครี',
+        'ojw' => 'โอจิบเวตะวันตก',
+        'oka' => 'โอคานากัน',
         'om' => 'โอโรโม',
         'or' => 'โอดิยา',
         'os' => 'ออสเซเตีย',
         'osa' => 'โอซากี',
         'ota' => 'ตุรกีออตโตมัน',
         'pa' => 'ปัญจาบ',
-        'pag' => 'ปางาซีนัน',
+        'pag' => 'ปังกาซีนัน',
         'pal' => 'ปะห์ลาวี',
-        'pam' => 'ปัมปางา',
+        'pam' => 'ปัมปังกา',
         'pap' => 'ปาเปียเมนโต',
         'pau' => 'ปาเลา',
         'pcd' => 'ปิการ์',
-        'pcm' => 'พิดจิน',
+        'pcm' => 'ไนจีเรียนพิดจิน',
         'pdc' => 'เยอรมันเพนซิลเวเนีย',
         'pdt' => 'เพลาท์ดิช',
         'peo' => 'เปอร์เซียโบราณ',
         'pfl' => 'เยอรมันพาลาทิเนต',
         'phn' => 'ฟินิเชีย',
         'pi' => 'บาลี',
+        'pis' => 'พิดจิน',
         'pl' => 'โปแลนด์',
         'pms' => 'พีดมอนต์',
         'pnt' => 'พอนติก',
         'pon' => 'พอห์นเพ',
+        'pqm' => 'มาเลไซท์-ปัสมาโควดี',
         'prg' => 'ปรัสเซีย',
         'pro' => 'โปรวองซาลโบราณ',
         'ps' => 'พัชโต',
@@ -430,7 +456,7 @@ return [
         'quc' => 'กีเช',
         'qug' => 'ควิชัวไฮแลนด์ชิมโบราโซ',
         'raj' => 'ราชสถาน',
-        'rap' => 'ราปานู',
+        'rap' => 'ราปานูอี',
         'rar' => 'ราโรทองกา',
         'rgn' => 'โรมัณโญ',
         'rhg' => 'โรฮิงญา',
@@ -444,7 +470,7 @@ return [
         'ru' => 'รัสเซีย',
         'rue' => 'รูซิน',
         'rug' => 'โรเวียนา',
-        'rup' => 'อาโรมาเนียน',
+        'rup' => 'อาโรมาเนีย',
         'rw' => 'รวันดา',
         'rwk' => 'รวา',
         'sa' => 'สันสกฤต',
@@ -480,6 +506,7 @@ return [
         'sid' => 'ซิดาโม',
         'sk' => 'สโลวัก',
         'sl' => 'สโลวีเนีย',
+        'slh' => 'ลูชูตซีดใต้',
         'sli' => 'ไซลีเซียตอนล่าง',
         'sly' => 'เซลายาร์',
         'sm' => 'ซามัว',
@@ -493,23 +520,25 @@ return [
         'sog' => 'ซอกดีน',
         'sq' => 'แอลเบเนีย',
         'sr' => 'เซอร์เบีย',
-        'srn' => 'ซูรินาเม',
+        'srn' => 'สรานานตองโก',
         'srr' => 'เซแรร์',
         'ss' => 'สวาติ',
         'ssy' => 'ซาโฮ',
         'st' => 'โซโทใต้',
         'stq' => 'ฟรีเซียนซัทเธอร์แลนด์',
+        'str' => 'สเตรตส์ซาลิช',
         'su' => 'ซุนดา',
         'suk' => 'ซูคูมา',
         'sus' => 'ซูซู',
         'sux' => 'ซูเมอ',
         'sv' => 'สวีเดน',
         'sw' => 'สวาฮีลี',
-        'swb' => 'โคเมอเรียน',
+        'swb' => 'โคเมอเรีย',
         'syc' => 'ซีเรียแบบดั้งเดิม',
         'syr' => 'ซีเรีย',
         'szl' => 'ไซลีเซีย',
         'ta' => 'ทมิฬ',
+        'tce' => 'ทัชโชนใต้',
         'tcy' => 'ตูลู',
         'te' => 'เตลูกู',
         'tem' => 'ทิมเน',
@@ -517,7 +546,9 @@ return [
         'ter' => 'เทเรโน',
         'tet' => 'เตตุม',
         'tg' => 'ทาจิก',
+        'tgx' => 'ทากิช',
         'th' => 'ไทย',
+        'tht' => 'ทาลทาน',
         'ti' => 'ติกริญญา',
         'tig' => 'ตีเกร',
         'tiv' => 'ทิฟ',
@@ -529,17 +560,19 @@ return [
         'tli' => 'ทลิงกิต',
         'tly' => 'ทาลิช',
         'tmh' => 'ทามาเชก',
-        'tn' => 'บอตสวานา',
+        'tn' => 'สวานา',
         'to' => 'ตองกา',
         'tog' => 'ไนอะซาตองกา',
+        'tok' => 'โทคิโพนา',
         'tpi' => 'ท็อกพิซิน',
         'tr' => 'ตุรกี',
         'tru' => 'ตูโรโย',
         'trv' => 'ทาโรโก',
-        'ts' => 'ซิตซองกา',
+        'ts' => 'ซองกา',
         'tsd' => 'ซาโคเนีย',
         'tsi' => 'ซิมชีแอน',
         'tt' => 'ตาตาร์',
+        'ttm' => 'ทัชโชนเหนือ',
         'ttt' => 'ตัตมุสลิม',
         'tum' => 'ทุมบูกา',
         'tvl' => 'ตูวาลู',
@@ -562,13 +595,14 @@ return [
         'vi' => 'เวียดนาม',
         'vls' => 'เฟลมิชตะวันตก',
         'vmf' => 'เมน-ฟรานโกเนีย',
+        'vmw' => 'มากัววา',
         'vo' => 'โวลาพึค',
         'vot' => 'โวทิก',
         'vro' => 'โวโร',
         'vun' => 'วุนจู',
-        'wa' => 'วาโลนี',
+        'wa' => 'วอลลูน',
         'wae' => 'วัลเซอร์',
-        'wal' => 'วาลาโม',
+        'wal' => 'โวแลตตา',
         'war' => 'วาเรย์',
         'was' => 'วาโช',
         'wbp' => 'วอล์เพอร์รี',
@@ -577,6 +611,7 @@ return [
         'xal' => 'คัลมืยค์',
         'xh' => 'คะห์โอซา',
         'xmf' => 'เมเกรเลีย',
+        'xnr' => 'กังกรี',
         'xog' => 'โซกา',
         'yao' => 'เย้า',
         'yap' => 'ยัป',
@@ -610,7 +645,7 @@ return [
         'es_MX' => 'สเปน - เม็กซิโก',
         'fa_AF' => 'ดารี',
         'fr_CA' => 'ฝรั่งเศส - แคนาดา',
-        'fr_CH' => 'ฝรั่งเศส (สวิส)',
+        'fr_CH' => 'ฝรั่งเศส - สวิส',
         'nds_NL' => 'แซกซอนใต้',
         'nl_BE' => 'เฟลมิช',
         'pt_BR' => 'โปรตุเกส - บราซิล',
