@@ -61,6 +61,7 @@ return [
         'bfd' => 'Bafut',
         'bfq' => 'Badaga',
         'bg' => 'Bulgarca',
+        'bgc' => 'Haryanvi dili',
         'bgn' => 'Batı Balochi',
         'bho' => 'Arayanice',
         'bi' => 'Bislama',
@@ -69,6 +70,7 @@ return [
         'bjn' => 'Banjar Dili',
         'bkm' => 'Kom',
         'bla' => 'Karaayak dili',
+        'blo' => 'Aniice',
         'bm' => 'Bambara',
         'bn' => 'Bengalce',
         'bo' => 'Tibetçe',
@@ -195,7 +197,6 @@ return [
         'gmh' => 'Ortaçağ Yüksek Almancası',
         'gn' => 'Guarani dili',
         'goh' => 'Eski Yüksek Almanca',
-        'gom' => 'Goa Konkanicesi',
         'gon' => 'Gondi dili',
         'gor' => 'Gorontalo dili',
         'got' => 'Gotça',
@@ -305,6 +306,7 @@ return [
         'kv' => 'Komi',
         'kw' => 'Kernevekçe',
         'kwk' => 'Kwakʼwala dili',
+        'kxv' => 'Kuvi',
         'ky' => 'Kırgızca',
         'la' => 'Latince',
         'lad' => 'Ladino',
@@ -593,6 +595,7 @@ return [
         'vi' => 'Vietnamca',
         'vls' => 'Batı Flamanca',
         'vmf' => 'Main Frankonya Dili',
+        'vmw' => 'Makuaca',
         'vo' => 'Volapük',
         'vot' => 'Votça',
         'vro' => 'Võro',
@@ -608,6 +611,7 @@ return [
         'xal' => 'Kalmıkça',
         'xh' => 'Zosa dili',
         'xmf' => 'Megrelce',
+        'xnr' => 'Kangrice',
         'xog' => 'Soga',
         'yao' => 'Yao',
         'yap' => 'Yapça',
