@@ -270,7 +270,7 @@ return [
         'kw' => '康沃尔语',
         'kwk' => '夸夸瓦拉语',
         'kxv' => '库维语',
-        'ky' => '柯尔克孜语',
+        'ky' => '吉尔吉斯语',
         'la' => '拉丁语',
         'lad' => '拉迪诺语',
         'lag' => '朗吉语',
