@@ -46,6 +46,8 @@ return [
         'az_Cyrl_AZ' => 'Azerbaijani (Cyrillic, Azerbaijan)',
         'az_Latn' => 'Azerbaijani (Latin)',
         'az_Latn_AZ' => 'Azerbaijani (Latin, Azerbaijan)',
+        'ba' => 'Bashkir',
+        'ba_RU' => 'Bashkir (Russia)',
         'be' => 'Belarusian',
         'be_BY' => 'Belarusian (Belarus)',
         'bg' => 'Bulgarian',
@@ -125,6 +127,7 @@ return [
         'en_DE' => 'English (Germany)',
         'en_DK' => 'English (Denmark)',
         'en_DM' => 'English (Dominica)',
+        'en_EE' => 'English (Estonia)',
         'en_ER' => 'English (Eritrea)',
         'en_ES' => 'English (Spain)',
         'en_FI' => 'English (Finland)',
@@ -134,6 +137,7 @@ return [
         'en_FR' => 'English (France)',
         'en_GB' => 'English (United Kingdom)',
         'en_GD' => 'English (Grenada)',
+        'en_GE' => 'English (Georgia)',
         'en_GG' => 'English (Guernsey)',
         'en_GH' => 'English (Ghana)',
         'en_GI' => 'English (Gibraltar)',
@@ -152,6 +156,7 @@ return [
         'en_IT' => 'English (Italy)',
         'en_JE' => 'English (Jersey)',
         'en_JM' => 'English (Jamaica)',
+        'en_JP' => 'English (Japan)',
         'en_KE' => 'English (Kenya)',
         'en_KI' => 'English (Kiribati)',
         'en_KN' => 'English (St. Kitts & Nevis)',
@@ -159,6 +164,8 @@ return [
         'en_LC' => 'English (St. Lucia)',
         'en_LR' => 'English (Liberia)',
         'en_LS' => 'English (Lesotho)',
+        'en_LT' => 'English (Lithuania)',
+        'en_LV' => 'English (Latvia)',
         'en_MG' => 'English (Madagascar)',
         'en_MH' => 'English (Marshall Islands)',
         'en_MO' => 'English (Macao SAR China)',
@@ -205,6 +212,7 @@ return [
         'en_TT' => 'English (Trinidad & Tobago)',
         'en_TV' => 'English (Tuvalu)',
         'en_TZ' => 'English (Tanzania)',
+        'en_UA' => 'English (Ukraine)',
         'en_UG' => 'English (Uganda)',
         'en_UM' => 'English (U.S. Outlying Islands)',
         'en_US' => 'English (United States)',
@@ -391,6 +399,8 @@ return [
         'ki' => 'Kikuyu',
         'ki_KE' => 'Kikuyu (Kenya)',
         'kk' => 'Kazakh',
+        'kk_Arab' => 'Kazakh (Arabic)',
+        'kk_Arab_CN' => 'Kazakh (Arabic, China)',
         'kk_Cyrl' => 'Kazakh (Cyrillic)',
         'kk_Cyrl_KZ' => 'Kazakh (Cyrillic, Kazakhstan)',
         'kk_KZ' => 'Kazakh (Kazakhstan)',
@@ -411,6 +421,11 @@ return [
         'ks_Deva_IN' => 'Kashmiri (Devanagari, India)',
         'ks_IN' => 'Kashmiri (India)',
         'ku' => 'Kurdish',
+        'ku_Latn' => 'Kurdish (Latin)',
+        'ku_Latn_IQ' => 'Kurdish (Latin, Iraq)',
+        'ku_Latn_SY' => 'Kurdish (Latin, Syria)',
+        'ku_Latn_TR' => 'Kurdish (Latin, Türkiye)',
+        'ku_SY' => 'Kurdish (Syria)',
         'ku_TR' => 'Kurdish (Türkiye)',
         'kw' => 'Cornish',
         'kw_GB' => 'Cornish (United Kingdom)',
