@@ -46,6 +46,8 @@ return [
         'az_Cyrl_AZ' => 'әзірбайжан тілі (кирилл жазуы, Әзірбайжан)',
         'az_Latn' => 'әзірбайжан тілі (латын жазуы)',
         'az_Latn_AZ' => 'әзірбайжан тілі (латын жазуы, Әзірбайжан)',
+        'ba' => 'башқұрт тілі',
+        'ba_RU' => 'башқұрт тілі (Ресей)',
         'be' => 'беларусь тілі',
         'be_BY' => 'беларусь тілі (Беларусь)',
         'bg' => 'болгар тілі',
@@ -125,6 +127,7 @@ return [
         'en_DE' => 'ағылшын тілі (Германия)',
         'en_DK' => 'ағылшын тілі (Дания)',
         'en_DM' => 'ағылшын тілі (Доминика)',
+        'en_EE' => 'ағылшын тілі (Эстония)',
         'en_ER' => 'ағылшын тілі (Эритрея)',
         'en_ES' => 'ағылшын тілі (Испания)',
         'en_FI' => 'ағылшын тілі (Финляндия)',
@@ -134,6 +137,7 @@ return [
         'en_FR' => 'ағылшын тілі (Франция)',
         'en_GB' => 'ағылшын тілі (Ұлыбритания)',
         'en_GD' => 'ағылшын тілі (Гренада)',
+        'en_GE' => 'ағылшын тілі (Грузия)',
         'en_GG' => 'ағылшын тілі (Гернси)',
         'en_GH' => 'ағылшын тілі (Гана)',
         'en_GI' => 'ағылшын тілі (Гибралтар)',
@@ -152,6 +156,7 @@ return [
         'en_IT' => 'ағылшын тілі (Италия)',
         'en_JE' => 'ағылшын тілі (Джерси)',
         'en_JM' => 'ағылшын тілі (Ямайка)',
+        'en_JP' => 'ағылшын тілі (Жапония)',
         'en_KE' => 'ағылшын тілі (Кения)',
         'en_KI' => 'ағылшын тілі (Кирибати)',
         'en_KN' => 'ағылшын тілі (Сент-Китс және Невис)',
@@ -159,6 +164,8 @@ return [
         'en_LC' => 'ағылшын тілі (Сент-Люсия)',
         'en_LR' => 'ағылшын тілі (Либерия)',
         'en_LS' => 'ағылшын тілі (Лесото)',
+        'en_LT' => 'ағылшын тілі (Литва)',
+        'en_LV' => 'ағылшын тілі (Латвия)',
         'en_MG' => 'ағылшын тілі (Мадагаскар)',
         'en_MH' => 'ағылшын тілі (Маршалл аралдары)',
         'en_MO' => 'ағылшын тілі (Макао АӘА)',
@@ -205,6 +212,7 @@ return [
         'en_TT' => 'ағылшын тілі (Тринидад және Тобаго)',
         'en_TV' => 'ағылшын тілі (Тувалу)',
         'en_TZ' => 'ағылшын тілі (Танзания)',
+        'en_UA' => 'ағылшын тілі (Украина)',
         'en_UG' => 'ағылшын тілі (Уганда)',
         'en_UM' => 'ағылшын тілі (АҚШ-тың сыртқы кіші аралдары)',
         'en_US' => 'ағылшын тілі (Америка Құрама Штаттары)',
@@ -391,6 +399,8 @@ return [
         'ki' => 'кикуйю тілі',
         'ki_KE' => 'кикуйю тілі (Кения)',
         'kk' => 'қазақ тілі',
+        'kk_Arab' => 'қазақ тілі (араб жазуы)',
+        'kk_Arab_CN' => 'қазақ тілі (араб жазуы, Қытай)',
         'kk_Cyrl' => 'қазақ тілі (кирилл жазуы)',
         'kk_Cyrl_KZ' => 'қазақ тілі (кирилл жазуы, Қазақстан)',
         'kk_KZ' => 'қазақ тілі (Қазақстан)',
@@ -411,6 +421,11 @@ return [
         'ks_Deva_IN' => 'кашмир тілі (деванагари жазуы, Үндістан)',
         'ks_IN' => 'кашмир тілі (Үндістан)',
         'ku' => 'күрд тілі',
+        'ku_Latn' => 'күрд тілі (латын жазуы)',
+        'ku_Latn_IQ' => 'күрд тілі (латын жазуы, Ирак)',
+        'ku_Latn_SY' => 'күрд тілі (латын жазуы, Сирия)',
+        'ku_Latn_TR' => 'күрд тілі (латын жазуы, Түркия)',
+        'ku_SY' => 'күрд тілі (Сирия)',
         'ku_TR' => 'күрд тілі (Түркия)',
         'kw' => 'корн тілі',
         'kw_GB' => 'корн тілі (Ұлыбритания)',
