@@ -46,6 +46,8 @@ return [
         'az_Cyrl_AZ' => 'азербайжан (кирилл, Азербайжан)',
         'az_Latn' => 'азербайжан (латин)',
         'az_Latn_AZ' => 'азербайжан (латин, Азербайжан)',
+        'ba' => 'башкир',
+        'ba_RU' => 'башкир (Орос)',
         'be' => 'беларусь',
         'be_BY' => 'беларусь (Беларусь)',
         'bg' => 'болгар',
@@ -125,6 +127,7 @@ return [
         'en_DE' => 'англи (Герман)',
         'en_DK' => 'англи (Дани)',
         'en_DM' => 'англи (Доминика)',
+        'en_EE' => 'англи (Эстони)',
         'en_ER' => 'англи (Эритрей)',
         'en_ES' => 'англи (Испани)',
         'en_FI' => 'англи (Финланд)',
@@ -134,6 +137,7 @@ return [
         'en_FR' => 'англи (Франц)',
         'en_GB' => 'англи (Их Британи)',
         'en_GD' => 'англи (Гренада)',
+        'en_GE' => 'англи (Гүрж)',
         'en_GG' => 'англи (Гернси)',
         'en_GH' => 'англи (Гана)',
         'en_GI' => 'англи (Гибралтар)',
@@ -152,6 +156,7 @@ return [
         'en_IT' => 'англи (Итали)',
         'en_JE' => 'англи (Жерси)',
         'en_JM' => 'англи (Ямайка)',
+        'en_JP' => 'англи (Япон)',
         'en_KE' => 'англи (Кени)',
         'en_KI' => 'англи (Кирибати)',
         'en_KN' => 'англи (Сент-Киттс ба Невис)',
@@ -159,6 +164,8 @@ return [
         'en_LC' => 'англи (Сент Люсиа)',
         'en_LR' => 'англи (Либери)',
         'en_LS' => 'англи (Лесото)',
+        'en_LT' => 'англи (Литва)',
+        'en_LV' => 'англи (Латви)',
         'en_MG' => 'англи (Мадагаскар)',
         'en_MH' => 'англи (Маршаллын арлууд)',
         'en_MO' => 'англи (БНХАУ-ын Тусгай захиргааны бүс Макао)',
@@ -205,6 +212,7 @@ return [
         'en_TT' => 'англи (Тринидад ба Тобаго)',
         'en_TV' => 'англи (Тувалу)',
         'en_TZ' => 'англи (Танзани)',
+        'en_UA' => 'англи (Украин)',
         'en_UG' => 'англи (Уганда)',
         'en_UM' => 'англи (Америкийн Нэгдсэн Улсын бага арлууд)',
         'en_US' => 'англи (Америкийн Нэгдсэн Улс)',
@@ -391,6 +399,8 @@ return [
         'ki' => 'кикуюү',
         'ki_KE' => 'кикуюү (Кени)',
         'kk' => 'казах',
+        'kk_Arab' => 'казах (араб)',
+        'kk_Arab_CN' => 'казах (араб, Хятад)',
         'kk_Cyrl' => 'казах (кирилл)',
         'kk_Cyrl_KZ' => 'казах (кирилл, Казахстан)',
         'kk_KZ' => 'казах (Казахстан)',
@@ -411,6 +421,11 @@ return [
         'ks_Deva_IN' => 'кашмир (деванагари, Энэтхэг)',
         'ks_IN' => 'кашмир (Энэтхэг)',
         'ku' => 'курд',
+        'ku_Latn' => 'курд (латин)',
+        'ku_Latn_IQ' => 'курд (латин, Ирак)',
+        'ku_Latn_SY' => 'курд (латин, Сири)',
+        'ku_Latn_TR' => 'курд (латин, Турк)',
+        'ku_SY' => 'курд (Сири)',
         'ku_TR' => 'курд (Турк)',
         'kw' => 'корн',
         'kw_GB' => 'корн (Их Британи)',
