@@ -46,6 +46,8 @@ return [
         'az_Cyrl_AZ' => 'అజర్బైజాని (సిరిలిక్, అజర్బైజాన్)',
         'az_Latn' => 'అజర్బైజాని (లాటిన్)',
         'az_Latn_AZ' => 'అజర్బైజాని (లాటిన్, అజర్బైజాన్)',
+        'ba' => 'బాష్కిర్',
+        'ba_RU' => 'బాష్కిర్ (రష్యా)',
         'be' => 'బెలారుషియన్',
         'be_BY' => 'బెలారుషియన్ (బెలారస్)',
         'bg' => 'బల్గేరియన్',
@@ -61,11 +63,11 @@ return [
         'br' => 'బ్రెటన్',
         'br_FR' => 'బ్రెటన్ (ఫ్రాన్స్‌)',
         'bs' => 'బోస్నియన్',
-        'bs_BA' => 'బోస్నియన్ (బోస్నియా మరియు హెర్జిగోవినా)',
+        'bs_BA' => 'బోస్నియన్ (బోస్నియా & హెర్జిగోవినా)',
         'bs_Cyrl' => 'బోస్నియన్ (సిరిలిక్)',
-        'bs_Cyrl_BA' => 'బోస్నియన్ (సిరిలిక్, బోస్నియా మరియు హెర్జిగోవినా)',
+        'bs_Cyrl_BA' => 'బోస్నియన్ (సిరిలిక్, బోస్నియా & హెర్జిగోవినా)',
         'bs_Latn' => 'బోస్నియన్ (లాటిన్)',
-        'bs_Latn_BA' => 'బోస్నియన్ (లాటిన్, బోస్నియా మరియు హెర్జిగోవినా)',
+        'bs_Latn_BA' => 'బోస్నియన్ (లాటిన్, బోస్నియా & హెర్జిగోవినా)',
         'ca' => 'కాటలాన్',
         'ca_AD' => 'కాటలాన్ (ఆండోరా)',
         'ca_ES' => 'కాటలాన్ (స్పెయిన్)',
@@ -102,7 +104,7 @@ return [
         'en_001' => 'ఇంగ్లీష్ (ప్రపంచం)',
         'en_150' => 'ఇంగ్లీష్ (యూరప్)',
         'en_AE' => 'ఇంగ్లీష్ (యునైటెడ్ అరబ్ ఎమిరేట్స్)',
-        'en_AG' => 'ఇంగ్లీష్ (ఆంటిగ్వా మరియు బార్బుడా)',
+        'en_AG' => 'ఇంగ్లీష్ (ఆంటిగ్వా & బార్బుడా)',
         'en_AI' => 'ఇంగ్లీష్ (ఆంగ్విల్లా)',
         'en_AS' => 'ఇంగ్లీష్ (అమెరికన్ సమోవా)',
         'en_AT' => 'ఇంగ్లీష్ (ఆస్ట్రియా)',
@@ -121,41 +123,52 @@ return [
         'en_CM' => 'ఇంగ్లీష్ (కామెరూన్)',
         'en_CX' => 'ఇంగ్లీష్ (క్రిస్మస్ దీవి)',
         'en_CY' => 'ఇంగ్లీష్ (సైప్రస్)',
+        'en_CZ' => 'ఇంగ్లీష్ (చెకియా)',
         'en_DE' => 'ఇంగ్లీష్ (జర్మనీ)',
         'en_DK' => 'ఇంగ్లీష్ (డెన్మార్క్)',
         'en_DM' => 'ఇంగ్లీష్ (డొమినికా)',
+        'en_EE' => 'ఇంగ్లీష్ (ఎస్టోనియా)',
         'en_ER' => 'ఇంగ్లీష్ (ఎరిట్రియా)',
+        'en_ES' => 'ఇంగ్లీష్ (స్పెయిన్)',
         'en_FI' => 'ఇంగ్లీష్ (ఫిన్లాండ్)',
         'en_FJ' => 'ఇంగ్లీష్ (ఫిజీ)',
         'en_FK' => 'ఇంగ్లీష్ (ఫాక్‌ల్యాండ్ దీవులు)',
         'en_FM' => 'ఇంగ్లీష్ (మైక్రోనేషియా)',
+        'en_FR' => 'ఇంగ్లీష్ (ఫ్రాన్స్‌)',
         'en_GB' => 'ఇంగ్లీష్ (యునైటెడ్ కింగ్‌డమ్)',
         'en_GD' => 'ఇంగ్లీష్ (గ్రెనడా)',
+        'en_GE' => 'ఇంగ్లీష్ (జార్జియా)',
         'en_GG' => 'ఇంగ్లీష్ (గర్న్‌సీ)',
         'en_GH' => 'ఇంగ్లీష్ (ఘనా)',
         'en_GI' => 'ఇంగ్లీష్ (జిబ్రాల్టర్)',
         'en_GM' => 'ఇంగ్లీష్ (గాంబియా)',
+        'en_GS' => 'ఇంగ్లీష్ (దక్షిణ జార్జియా మరియు దక్షిణ శాండ్విచ్ దీవులు)',
         'en_GU' => 'ఇంగ్లీష్ (గ్వామ్)',
         'en_GY' => 'ఇంగ్లీష్ (గయానా)',
-        'en_HK' => 'ఇంగ్లీష్ (హాంకాంగ్ ఎస్ఏఆర్ చైనా)',
+        'en_HK' => 'ఇంగ్లీష్ (హాంకాంగ్ SAR చైనా)',
+        'en_HU' => 'ఇంగ్లీష్ (హంగేరీ)',
         'en_ID' => 'ఇంగ్లీష్ (ఇండోనేషియా)',
         'en_IE' => 'ఇంగ్లీష్ (ఐర్లాండ్)',
         'en_IL' => 'ఇంగ్లీష్ (ఇజ్రాయెల్)',
         'en_IM' => 'ఇంగ్లీష్ (ఐల్ ఆఫ్ మాన్)',
         'en_IN' => 'ఇంగ్లీష్ (భారతదేశం)',
         'en_IO' => 'ఇంగ్లీష్ (బ్రిటిష్ హిందూ మహాసముద్ర ప్రాంతం)',
+        'en_IT' => 'ఇంగ్లీష్ (ఇటలీ)',
         'en_JE' => 'ఇంగ్లీష్ (జెర్సీ)',
         'en_JM' => 'ఇంగ్లీష్ (జమైకా)',
+        'en_JP' => 'ఇంగ్లీష్ (జపాన్)',
         'en_KE' => 'ఇంగ్లీష్ (కెన్యా)',
         'en_KI' => 'ఇంగ్లీష్ (కిరిబాటి)',
-        'en_KN' => 'ఇంగ్లీష్ (సెయింట్ కిట్స్ మరియు నెవిస్)',
+        'en_KN' => 'ఇంగ్లీష్ (సెయింట్ కిట్స్ & నెవిస్)',
         'en_KY' => 'ఇంగ్లీష్ (కేమాన్ దీవులు)',
         'en_LC' => 'ఇంగ్లీష్ (సెయింట్ లూసియా)',
         'en_LR' => 'ఇంగ్లీష్ (లైబీరియా)',
         'en_LS' => 'ఇంగ్లీష్ (లెసోతో)',
+        'en_LT' => 'ఇంగ్లీష్ (లిథువేనియా)',
+        'en_LV' => 'ఇంగ్లీష్ (లాత్వియా)',
         'en_MG' => 'ఇంగ్లీష్ (మడగాస్కర్)',
         'en_MH' => 'ఇంగ్లీష్ (మార్షల్ దీవులు)',
-        'en_MO' => 'ఇంగ్లీష్ (మకావ్ ఎస్ఏఆర్ చైనా)',
+        'en_MO' => 'ఇంగ్లీష్ (మకావ్ SAR చైనా)',
         'en_MP' => 'ఇంగ్లీష్ (ఉత్తర మరియానా దీవులు)',
         'en_MS' => 'ఇంగ్లీష్ (మాంట్సెరాట్)',
         'en_MT' => 'ఇంగ్లీష్ (మాల్టా)',
@@ -167,15 +180,19 @@ return [
         'en_NF' => 'ఇంగ్లీష్ (నార్ఫోక్ దీవి)',
         'en_NG' => 'ఇంగ్లీష్ (నైజీరియా)',
         'en_NL' => 'ఇంగ్లీష్ (నెదర్లాండ్స్)',
+        'en_NO' => 'ఇంగ్లీష్ (నార్వే)',
         'en_NR' => 'ఇంగ్లీష్ (నౌరు)',
         'en_NU' => 'ఇంగ్లీష్ (నియూ)',
         'en_NZ' => 'ఇంగ్లీష్ (న్యూజిలాండ్)',
         'en_PG' => 'ఇంగ్లీష్ (పాపువా న్యూ గినియా)',
         'en_PH' => 'ఇంగ్లీష్ (ఫిలిప్పైన్స్)',
         'en_PK' => 'ఇంగ్లీష్ (పాకిస్తాన్)',
+        'en_PL' => 'ఇంగ్లీష్ (పోలాండ్)',
         'en_PN' => 'ఇంగ్లీష్ (పిట్‌కెయిర్న్ దీవులు)',
         'en_PR' => 'ఇంగ్లీష్ (ప్యూర్టో రికో)',
+        'en_PT' => 'ఇంగ్లీష్ (పోర్చుగల్)',
         'en_PW' => 'ఇంగ్లీష్ (పాలావ్)',
+        'en_RO' => 'ఇంగ్లీష్ (రోమేనియా)',
         'en_RW' => 'ఇంగ్లీష్ (రువాండా)',
         'en_SB' => 'ఇంగ్లీష్ (సోలమన్ దీవులు)',
         'en_SC' => 'ఇంగ్లీష్ (సీషెల్స్)',
@@ -184,18 +201,20 @@ return [
         'en_SG' => 'ఇంగ్లీష్ (సింగపూర్)',
         'en_SH' => 'ఇంగ్లీష్ (సెయింట్ హెలెనా)',
         'en_SI' => 'ఇంగ్లీష్ (స్లోవేనియా)',
+        'en_SK' => 'ఇంగ్లీష్ (స్లొవేకియా)',
         'en_SL' => 'ఇంగ్లీష్ (సియెర్రా లియాన్)',
         'en_SS' => 'ఇంగ్లీష్ (దక్షిణ సూడాన్)',
         'en_SX' => 'ఇంగ్లీష్ (సింట్ మార్టెన్)',
         'en_SZ' => 'ఇంగ్లీష్ (ఈస్వాటిని)',
-        'en_TC' => 'ఇంగ్లీష్ (టర్క్స్ మరియు కైకోస్ దీవులు)',
+        'en_TC' => 'ఇంగ్లీష్ (టర్క్స్ & కైకోస్ దీవులు)',
         'en_TK' => 'ఇంగ్లీష్ (టోకెలావ్)',
         'en_TO' => 'ఇంగ్లీష్ (టోంగా)',
         'en_TT' => 'ఇంగ్లీష్ (ట్రినిడాడ్ మరియు టొబాగో)',
         'en_TV' => 'ఇంగ్లీష్ (టువాలు)',
         'en_TZ' => 'ఇంగ్లీష్ (టాంజానియా)',
+        'en_UA' => 'ఇంగ్లీష్ (ఉక్రెయిన్)',
         'en_UG' => 'ఇంగ్లీష్ (ఉగాండా)',
-        'en_UM' => 'ఇంగ్లీష్ (సంయుక్త రాజ్య అమెరికా బయట ఉన్న దీవులు)',
+        'en_UM' => 'ఇంగ్లీష్ (U.S. బయట ఉన్న దీవులు)',
         'en_US' => 'ఇంగ్లీష్ (యునైటెడ్ స్టేట్స్)',
         'en_VC' => 'ఇంగ్లీష్ (సెయింట్ విన్సెంట్ మరియు గ్రెనడీన్స్)',
         'en_VG' => 'ఇంగ్లీష్ (బ్రిటిష్ వర్జిన్ దీవులు)',
@@ -241,37 +260,37 @@ return [
         'fa' => 'పర్షియన్',
         'fa_AF' => 'పర్షియన్ (ఆఫ్ఘనిస్తాన్)',
         'fa_IR' => 'పర్షియన్ (ఇరాన్)',
-        'ff' => 'ఫ్యుల',
-        'ff_Adlm' => 'ఫ్యుల (అద్లామ్)',
-        'ff_Adlm_BF' => 'ఫ్యుల (అద్లామ్, బుర్కినా ఫాసో)',
-        'ff_Adlm_CM' => 'ఫ్యుల (అద్లామ్, కామెరూన్)',
-        'ff_Adlm_GH' => 'ఫ్యుల (అద్లామ్, ఘనా)',
-        'ff_Adlm_GM' => 'ఫ్యుల (అద్లామ్, గాంబియా)',
-        'ff_Adlm_GN' => 'ఫ్యుల (అద్లామ్, గినియా)',
-        'ff_Adlm_GW' => 'ఫ్యుల (అద్లామ్, గినియా-బిస్సావ్)',
-        'ff_Adlm_LR' => 'ఫ్యుల (అద్లామ్, లైబీరియా)',
-        'ff_Adlm_MR' => 'ఫ్యుల (అద్లామ్, మారిటేనియా)',
-        'ff_Adlm_NE' => 'ఫ్యుల (అద్లామ్, నైజర్)',
-        'ff_Adlm_NG' => 'ఫ్యుల (అద్లామ్, నైజీరియా)',
-        'ff_Adlm_SL' => 'ఫ్యుల (అద్లామ్, సియెర్రా లియాన్)',
-        'ff_Adlm_SN' => 'ఫ్యుల (అద్లామ్, సెనెగల్)',
-        'ff_CM' => 'ఫ్యుల (కామెరూన్)',
-        'ff_GN' => 'ఫ్యుల (గినియా)',
-        'ff_Latn' => 'ఫ్యుల (లాటిన్)',
-        'ff_Latn_BF' => 'ఫ్యుల (లాటిన్, బుర్కినా ఫాసో)',
-        'ff_Latn_CM' => 'ఫ్యుల (లాటిన్, కామెరూన్)',
-        'ff_Latn_GH' => 'ఫ్యుల (లాటిన్, ఘనా)',
-        'ff_Latn_GM' => 'ఫ్యుల (లాటిన్, గాంబియా)',
-        'ff_Latn_GN' => 'ఫ్యుల (లాటిన్, గినియా)',
-        'ff_Latn_GW' => 'ఫ్యుల (లాటిన్, గినియా-బిస్సావ్)',
-        'ff_Latn_LR' => 'ఫ్యుల (లాటిన్, లైబీరియా)',
-        'ff_Latn_MR' => 'ఫ్యుల (లాటిన్, మారిటేనియా)',
-        'ff_Latn_NE' => 'ఫ్యుల (లాటిన్, నైజర్)',
-        'ff_Latn_NG' => 'ఫ్యుల (లాటిన్, నైజీరియా)',
-        'ff_Latn_SL' => 'ఫ్యుల (లాటిన్, సియెర్రా లియాన్)',
-        'ff_Latn_SN' => 'ఫ్యుల (లాటిన్, సెనెగల్)',
-        'ff_MR' => 'ఫ్యుల (మారిటేనియా)',
-        'ff_SN' => 'ఫ్యుల (సెనెగల్)',
+        'ff' => 'ఫూలా',
+        'ff_Adlm' => 'ఫూలా (అద్లామ్)',
+        'ff_Adlm_BF' => 'ఫూలా (అద్లామ్, బుర్కినా ఫాసో)',
+        'ff_Adlm_CM' => 'ఫూలా (అద్లామ్, కామెరూన్)',
+        'ff_Adlm_GH' => 'ఫూలా (అద్లామ్, ఘనా)',
+        'ff_Adlm_GM' => 'ఫూలా (అద్లామ్, గాంబియా)',
+        'ff_Adlm_GN' => 'ఫూలా (అద్లామ్, గినియా)',
+        'ff_Adlm_GW' => 'ఫూలా (అద్లామ్, గినియా-బిస్సావ్)',
+        'ff_Adlm_LR' => 'ఫూలా (అద్లామ్, లైబీరియా)',
+        'ff_Adlm_MR' => 'ఫూలా (అద్లామ్, మారిటేనియా)',
+        'ff_Adlm_NE' => 'ఫూలా (అద్లామ్, నైజర్)',
+        'ff_Adlm_NG' => 'ఫూలా (అద్లామ్, నైజీరియా)',
+        'ff_Adlm_SL' => 'ఫూలా (అద్లామ్, సియెర్రా లియాన్)',
+        'ff_Adlm_SN' => 'ఫూలా (అద్లామ్, సెనెగల్)',
+        'ff_CM' => 'ఫూలా (కామెరూన్)',
+        'ff_GN' => 'ఫూలా (గినియా)',
+        'ff_Latn' => 'ఫూలా (లాటిన్)',
+        'ff_Latn_BF' => 'ఫూలా (లాటిన్, బుర్కినా ఫాసో)',
+        'ff_Latn_CM' => 'ఫూలా (లాటిన్, కామెరూన్)',
+        'ff_Latn_GH' => 'ఫూలా (లాటిన్, ఘనా)',
+        'ff_Latn_GM' => 'ఫూలా (లాటిన్, గాంబియా)',
+        'ff_Latn_GN' => 'ఫూలా (లాటిన్, గినియా)',
+        'ff_Latn_GW' => 'ఫూలా (లాటిన్, గినియా-బిస్సావ్)',
+        'ff_Latn_LR' => 'ఫూలా (లాటిన్, లైబీరియా)',
+        'ff_Latn_MR' => 'ఫూలా (లాటిన్, మారిటేనియా)',
+        'ff_Latn_NE' => 'ఫూలా (లాటిన్, నైజర్)',
+        'ff_Latn_NG' => 'ఫూలా (లాటిన్, నైజీరియా)',
+        'ff_Latn_SL' => 'ఫూలా (లాటిన్, సియెర్రా లియాన్)',
+        'ff_Latn_SN' => 'ఫూలా (లాటిన్, సెనెగల్)',
+        'ff_MR' => 'ఫూలా (మారిటేనియా)',
+        'ff_SN' => 'ఫూలా (సెనెగల్)',
         'fi' => 'ఫిన్నిష్',
         'fi_FI' => 'ఫిన్నిష్ (ఫిన్లాండ్)',
         'fo' => 'ఫారోస్',
@@ -309,7 +328,7 @@ return [
         'fr_MQ' => 'ఫ్రెంచ్ (మార్టినీక్)',
         'fr_MR' => 'ఫ్రెంచ్ (మారిటేనియా)',
         'fr_MU' => 'ఫ్రెంచ్ (మారిషస్)',
-        'fr_NC' => 'ఫ్రెంచ్ (క్రొత్త కాలెడోనియా)',
+        'fr_NC' => 'ఫ్రెంచ్ (కొత్త కాలెడోనియా)',
         'fr_NE' => 'ఫ్రెంచ్ (నైజర్)',
         'fr_PF' => 'ఫ్రెంచ్ (ఫ్రెంచ్ పోలినీషియా)',
         'fr_PM' => 'ఫ్రెంచ్ (సెయింట్ పియెర్ మరియు మికెలాన్)',
@@ -341,14 +360,14 @@ return [
         'ha_GH' => 'హౌసా (ఘనా)',
         'ha_NE' => 'హౌసా (నైజర్)',
         'ha_NG' => 'హౌసా (నైజీరియా)',
-        'he' => 'హిబ్రూ',
-        'he_IL' => 'హిబ్రూ (ఇజ్రాయెల్)',
+        'he' => 'హీబ్రూ',
+        'he_IL' => 'హీబ్రూ (ఇజ్రాయెల్)',
         'hi' => 'హిందీ',
         'hi_IN' => 'హిందీ (భారతదేశం)',
         'hi_Latn' => 'హిందీ (లాటిన్)',
         'hi_Latn_IN' => 'హిందీ (లాటిన్, భారతదేశం)',
         'hr' => 'క్రొయేషియన్',
-        'hr_BA' => 'క్రొయేషియన్ (బోస్నియా మరియు హెర్జిగోవినా)',
+        'hr_BA' => 'క్రొయేషియన్ (బోస్నియా & హెర్జిగోవినా)',
         'hr_HR' => 'క్రొయేషియన్ (క్రొయేషియా)',
         'hu' => 'హంగేరియన్',
         'hu_HU' => 'హంగేరియన్ (హంగేరీ)',
@@ -380,6 +399,8 @@ return [
         'ki' => 'కికుయు',
         'ki_KE' => 'కికుయు (కెన్యా)',
         'kk' => 'కజఖ్',
+        'kk_Arab' => 'కజఖ్ (అరబిక్)',
+        'kk_Arab_CN' => 'కజఖ్ (అరబిక్, చైనా)',
         'kk_Cyrl' => 'కజఖ్ (సిరిలిక్)',
         'kk_Cyrl_KZ' => 'కజఖ్ (సిరిలిక్, కజకిస్తాన్)',
         'kk_KZ' => 'కజఖ్ (కజకిస్తాన్)',
@@ -400,6 +421,11 @@ return [
         'ks_Deva_IN' => 'కాశ్మీరి (దేవనాగరి, భారతదేశం)',
         'ks_IN' => 'కాశ్మీరి (భారతదేశం)',
         'ku' => 'కుర్దిష్',
+        'ku_Latn' => 'కుర్దిష్ (లాటిన్)',
+        'ku_Latn_IQ' => 'కుర్దిష్ (లాటిన్, ఇరాక్)',
+        'ku_Latn_SY' => 'కుర్దిష్ (లాటిన్, సిరియా)',
+        'ku_Latn_TR' => 'కుర్దిష్ (లాటిన్, తుర్కియె)',
+        'ku_SY' => 'కుర్దిష్ (సిరియా)',
         'ku_TR' => 'కుర్దిష్ (తుర్కియె)',
         'kw' => 'కోర్నిష్',
         'kw_GB' => 'కోర్నిష్ (యునైటెడ్ కింగ్‌డమ్)',
@@ -494,7 +520,7 @@ return [
         'pt_GQ' => 'పోర్చుగీస్ (ఈక్వటోరియల్ గినియా)',
         'pt_GW' => 'పోర్చుగీస్ (గినియా-బిస్సావ్)',
         'pt_LU' => 'పోర్చుగీస్ (లక్సెంబర్గ్)',
-        'pt_MO' => 'పోర్చుగీస్ (మకావ్ ఎస్ఏఆర్ చైనా)',
+        'pt_MO' => 'పోర్చుగీస్ (మకావ్ SAR చైనా)',
         'pt_MZ' => 'పోర్చుగీస్ (మొజాంబిక్)',
         'pt_PT' => 'పోర్చుగీస్ (పోర్చుగల్)',
         'pt_ST' => 'పోర్చుగీస్ (సావో టోమ్ మరియు ప్రిన్సిపి)',
@@ -537,7 +563,7 @@ return [
         'sg' => 'సాంగో',
         'sg_CF' => 'సాంగో (సెంట్రల్ ఆఫ్రికన్ రిపబ్లిక్)',
         'sh' => 'సేర్బో-క్రొయేషియన్',
-        'sh_BA' => 'సేర్బో-క్రొయేషియన్ (బోస్నియా మరియు హెర్జిగోవినా)',
+        'sh_BA' => 'సేర్బో-క్రొయేషియన్ (బోస్నియా & హెర్జిగోవినా)',
         'si' => 'సింహళం',
         'si_LK' => 'సింహళం (శ్రీలంక)',
         'sk' => 'స్లోవక్',
@@ -555,13 +581,13 @@ return [
         'sq_AL' => 'అల్బేనియన్ (అల్బేనియా)',
         'sq_MK' => 'అల్బేనియన్ (ఉత్తర మాసిడోనియా)',
         'sr' => 'సెర్బియన్',
-        'sr_BA' => 'సెర్బియన్ (బోస్నియా మరియు హెర్జిగోవినా)',
+        'sr_BA' => 'సెర్బియన్ (బోస్నియా & హెర్జిగోవినా)',
         'sr_Cyrl' => 'సెర్బియన్ (సిరిలిక్)',
-        'sr_Cyrl_BA' => 'సెర్బియన్ (సిరిలిక్, బోస్నియా మరియు హెర్జిగోవినా)',
+        'sr_Cyrl_BA' => 'సెర్బియన్ (సిరిలిక్, బోస్నియా & హెర్జిగోవినా)',
         'sr_Cyrl_ME' => 'సెర్బియన్ (సిరిలిక్, మాంటెనెగ్రో)',
         'sr_Cyrl_RS' => 'సెర్బియన్ (సిరిలిక్, సెర్బియా)',
         'sr_Latn' => 'సెర్బియన్ (లాటిన్)',
-        'sr_Latn_BA' => 'సెర్బియన్ (లాటిన్, బోస్నియా మరియు హెర్జిగోవినా)',
+        'sr_Latn_BA' => 'సెర్బియన్ (లాటిన్, బోస్నియా & హెర్జిగోవినా)',
         'sr_Latn_ME' => 'సెర్బియన్ (లాటిన్, మాంటెనెగ్రో)',
         'sr_Latn_RS' => 'సెర్బియన్ (లాటిన్, సెర్బియా)',
         'sr_ME' => 'సెర్బియన్ (మాంటెనెగ్రో)',
@@ -641,19 +667,19 @@ return [
         'za_CN' => 'జువాన్ (చైనా)',
         'zh' => 'చైనీస్',
         'zh_CN' => 'చైనీస్ (చైనా)',
-        'zh_HK' => 'చైనీస్ (హాంకాంగ్ ఎస్ఏఆర్ చైనా)',
+        'zh_HK' => 'చైనీస్ (హాంకాంగ్ SAR చైనా)',
         'zh_Hans' => 'చైనీస్ (సరళీకృతం)',
         'zh_Hans_CN' => 'చైనీస్ (సరళీకృతం, చైనా)',
-        'zh_Hans_HK' => 'చైనీస్ (సరళీకృతం, హాంకాంగ్ ఎస్ఏఆర్ చైనా)',
-        'zh_Hans_MO' => 'చైనీస్ (సరళీకృతం, మకావ్ ఎస్ఏఆర్ చైనా)',
+        'zh_Hans_HK' => 'చైనీస్ (సరళీకృతం, హాంకాంగ్ SAR చైనా)',
+        'zh_Hans_MO' => 'చైనీస్ (సరళీకృతం, మకావ్ SAR చైనా)',
         'zh_Hans_MY' => 'చైనీస్ (సరళీకృతం, మలేషియా)',
         'zh_Hans_SG' => 'చైనీస్ (సరళీకృతం, సింగపూర్)',
         'zh_Hant' => 'చైనీస్ (సాంప్రదాయక)',
-        'zh_Hant_HK' => 'చైనీస్ (సాంప్రదాయక, హాంకాంగ్ ఎస్ఏఆర్ చైనా)',
-        'zh_Hant_MO' => 'చైనీస్ (సాంప్రదాయక, మకావ్ ఎస్ఏఆర్ చైనా)',
+        'zh_Hant_HK' => 'చైనీస్ (సాంప్రదాయక, హాంకాంగ్ SAR చైనా)',
+        'zh_Hant_MO' => 'చైనీస్ (సాంప్రదాయక, మకావ్ SAR చైనా)',
         'zh_Hant_MY' => 'చైనీస్ (సాంప్రదాయక, మలేషియా)',
         'zh_Hant_TW' => 'చైనీస్ (సాంప్రదాయక, తైవాన్)',
-        'zh_MO' => 'చైనీస్ (మకావ్ ఎస్ఏఆర్ చైనా)',
+        'zh_MO' => 'చైనీస్ (మకావ్ SAR చైనా)',
         'zh_SG' => 'చైనీస్ (సింగపూర్)',
         'zh_TW' => 'చైనీస్ (తైవాన్)',
         'zu' => 'జూలూ',
