@@ -1,6 +1,7 @@
 <?php
 
 return [
+    'UserAssignedNames' => [],
     'Names' => [
         'BR' => 'ब्राज़ील',
         'CN' => 'चीन',
@@ -10,6 +11,7 @@ return [
         'IN' => 'भारत',
         'IT' => 'इटली',
         'JP' => 'जापान',
+        'PK' => 'पाकिस्तान',
         'RU' => 'रशिया',
         'US' => 'अमेरिका',
     ],
