@@ -343,7 +343,7 @@ return [
         'Europe/Busingen' => 'Централноевропейско време (Бюзинген)',
         'Europe/Chisinau' => 'Източноевропейско време (Кишинев)',
         'Europe/Copenhagen' => 'Централноевропейско време (Копенхаген)',
-        'Europe/Dublin' => 'Средно гринуичко време (Дъблин)',
+        'Europe/Dublin' => 'Ирландия (Дъблин)',
         'Europe/Gibraltar' => 'Централноевропейско време (Гибралтар)',
         'Europe/Guernsey' => 'Средно гринуичко време (Гърнзи)',
         'Europe/Helsinki' => 'Източноевропейско време (Хелзинки)',
