@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'východoafrický čas (Addis Abeba)',
         'Africa/Algiers' => 'středoevropský čas (Alžír)',
         'Africa/Asmera' => 'východoafrický čas (Asmara)',
+        'Africa/Asmara' => 'východoafrický čas (Asmara)',
         'Africa/Bamako' => 'greenwichský střední čas (Bamako)',
         'Africa/Bangui' => 'západoafrický čas (Bangui)',
         'Africa/Banjul' => 'greenwichský střední čas (Banjul)',
@@ -22,7 +23,7 @@ return [
         'Africa/Dar_es_Salaam' => 'východoafrický čas (Dar es Salaam)',
         'Africa/Djibouti' => 'východoafrický čas (Džibuti)',
         'Africa/Douala' => 'západoafrický čas (Douala)',
-        'Africa/El_Aaiun' => 'západoevropský čas (El Aaiun)',
+        'Africa/El_Aaiun' => 'západoevropský čas (El Aaiún)',
         'Africa/Freetown' => 'greenwichský střední čas (Freetown)',
         'Africa/Gaborone' => 'středoafrický čas (Gaborone)',
         'Africa/Harare' => 'středoafrický čas (Harare)',
@@ -58,13 +59,13 @@ return [
         'America/Anchorage' => 'aljašský čas (Anchorage)',
         'America/Anguilla' => 'atlantický čas (Anguilla)',
         'America/Antigua' => 'atlantický čas (Antigua)',
-        'America/Araguaina' => 'brasilijský čas (Araguaina)',
+        'America/Araguaina' => 'brasilijský čas (Araguaína)',
         'America/Argentina/La_Rioja' => 'argentinský čas (La Rioja)',
-        'America/Argentina/Rio_Gallegos' => 'argentinský čas (Rio Gallegos)',
+        'America/Argentina/Rio_Gallegos' => 'argentinský čas (Río Gallegos)',
         'America/Argentina/Salta' => 'argentinský čas (Salta)',
         'America/Argentina/San_Juan' => 'argentinský čas (San Juan)',
         'America/Argentina/San_Luis' => 'argentinský čas (San Luis)',
-        'America/Argentina/Tucuman' => 'argentinský čas (Tucuman)',
+        'America/Argentina/Tucuman' => 'argentinský čas (Tucumán)',
         'America/Argentina/Ushuaia' => 'argentinský čas (Ushuaia)',
         'America/Aruba' => 'atlantický čas (Aruba)',
         'America/Asuncion' => 'paraguayský čas (Asunción)',
@@ -78,21 +79,26 @@ return [
         'America/Bogota' => 'kolumbijský čas (Bogotá)',
         'America/Boise' => 'severoamerický horský čas (Boise)',
         'America/Buenos_Aires' => 'argentinský čas (Buenos Aires)',
+        'America/Argentina/Buenos_Aires' => 'argentinský čas (Buenos Aires)',
         'America/Cambridge_Bay' => 'severoamerický horský čas (Cambridge Bay)',
         'America/Campo_Grande' => 'amazonský čas (Campo Grande)',
         'America/Cancun' => 'severoamerický východní čas (Cancún)',
         'America/Caracas' => 'venezuelský čas (Caracas)',
         'America/Catamarca' => 'argentinský čas (Catamarca)',
+        'America/Argentina/Catamarca' => 'argentinský čas (Catamarca)',
         'America/Cayenne' => 'francouzskoguyanský čas (Cayenne)',
         'America/Cayman' => 'severoamerický východní čas (Kajmanské ostrovy)',
         'America/Chicago' => 'severoamerický centrální čas (Chicago)',
         'America/Chihuahua' => 'severoamerický centrální čas (Chihuahua)',
         'America/Ciudad_Juarez' => 'severoamerický horský čas (Ciudad Juárez)',
         'America/Coral_Harbour' => 'severoamerický východní čas (Atikokan)',
+        'America/Atikokan' => 'severoamerický východní čas (Atikokan)',
         'America/Cordoba' => 'argentinský čas (Córdoba)',
+        'America/Argentina/Cordoba' => 'argentinský čas (Córdoba)',
         'America/Costa_Rica' => 'severoamerický centrální čas (Kostarika)',
+        'America/Coyhaique' => 'chilský čas (Coyhaique)',
         'America/Creston' => 'severoamerický horský čas (Creston)',
-        'America/Cuiaba' => 'amazonský čas (Cuiaba)',
+        'America/Cuiaba' => 'amazonský čas (Cuiabá)',
         'America/Curacao' => 'atlantický čas (Curaçao)',
         'America/Danmarkshavn' => 'greenwichský střední čas (Danmarkshavn)',
         'America/Dawson' => 'yukonský čas (Dawson)',
@@ -101,12 +107,13 @@ return [
         'America/Detroit' => 'severoamerický východní čas (Detroit)',
         'America/Dominica' => 'atlantický čas (Dominika)',
         'America/Edmonton' => 'severoamerický horský čas (Edmonton)',
-        'America/Eirunepe' => 'acrejský čas (Eirunepe)',
+        'America/Eirunepe' => 'acrejský čas (Eirunepé)',
         'America/El_Salvador' => 'severoamerický centrální čas (Salvador)',
         'America/Fort_Nelson' => 'severoamerický horský čas (Fort Nelson)',
         'America/Fortaleza' => 'brasilijský čas (Fortaleza)',
         'America/Glace_Bay' => 'atlantický čas (Glace Bay)',
         'America/Godthab' => 'časové pásmo Grónsko (Nuuk)',
+        'America/Nuuk' => 'časové pásmo Grónsko (Nuuk)',
         'America/Goose_Bay' => 'atlantický čas (Goose Bay)',
         'America/Grand_Turk' => 'severoamerický východní čas (Grand Turk)',
         'America/Grenada' => 'atlantický čas (Grenada)',
@@ -125,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'severoamerický východní čas (Vincennes, Indiana)',
         'America/Indiana/Winamac' => 'severoamerický východní čas (Winamac, Indiana)',
         'America/Indianapolis' => 'severoamerický východní čas (Indianapolis)',
+        'America/Indiana/Indianapolis' => 'severoamerický východní čas (Indianapolis)',
         'America/Inuvik' => 'severoamerický horský čas (Inuvik)',
         'America/Iqaluit' => 'severoamerický východní čas (Iqaluit)',
         'America/Jamaica' => 'severoamerický východní čas (Jamajka)',
         'America/Jujuy' => 'argentinský čas (Jujuy)',
+        'America/Argentina/Jujuy' => 'argentinský čas (Jujuy)',
         'America/Juneau' => 'aljašský čas (Juneau)',
         'America/Kentucky/Monticello' => 'severoamerický východní čas (Monticello, Kentucky)',
         'America/Kralendijk' => 'atlantický čas (Kralendijk)',
@@ -136,8 +145,9 @@ return [
         'America/Lima' => 'peruánský čas (Lima)',
         'America/Los_Angeles' => 'severoamerický pacifický čas (Los Angeles)',
         'America/Louisville' => 'severoamerický východní čas (Louisville)',
+        'America/Kentucky/Louisville' => 'severoamerický východní čas (Louisville)',
         'America/Lower_Princes' => 'atlantický čas (Lower Prince’s Quarter)',
-        'America/Maceio' => 'brasilijský čas (Maceio)',
+        'America/Maceio' => 'brasilijský čas (Maceió)',
         'America/Managua' => 'severoamerický centrální čas (Managua)',
         'America/Manaus' => 'amazonský čas (Manaus)',
         'America/Marigot' => 'atlantický čas (Marigot)',
@@ -145,11 +155,12 @@ return [
         'America/Matamoros' => 'severoamerický centrální čas (Matamoros)',
         'America/Mazatlan' => 'mexický pacifický čas (Mazatlán)',
         'America/Mendoza' => 'argentinský čas (Mendoza)',
+        'America/Argentina/Mendoza' => 'argentinský čas (Mendoza)',
         'America/Menominee' => 'severoamerický centrální čas (Menominee)',
         'America/Merida' => 'severoamerický centrální čas (Merida)',
         'America/Metlakatla' => 'aljašský čas (Metlakatla)',
         'America/Mexico_City' => 'severoamerický centrální čas (Ciudad de México)',
-        'America/Miquelon' => 'pierre-miquelonský čas',
+        'America/Miquelon' => 'pierre-miquelonský čas (Saint-Pierre)',
         'America/Moncton' => 'atlantický čas (Moncton)',
         'America/Monterrey' => 'severoamerický centrální čas (Monterrey)',
         'America/Montevideo' => 'uruguayský čas (Montevideo)',
@@ -199,35 +210,35 @@ return [
         'America/Yakutat' => 'aljašský čas (Yakutat)',
         'Antarctica/Casey' => 'západoaustralský čas (Casey)',
         'Antarctica/Davis' => 'čas Davisovy stanice',
-        'Antarctica/DumontDUrville' => 'čas stanice Dumonta d’Urvilla (Dumont d’Urville)',
+        'Antarctica/DumontDUrville' => 'čas stanice Dumonta d’Urvilla (Dumont-d’Urville)',
         'Antarctica/Macquarie' => 'východoaustralský čas (Macquarie)',
         'Antarctica/Mawson' => 'čas Mawsonovy stanice',
         'Antarctica/McMurdo' => 'novozélandský čas (McMurdo)',
         'Antarctica/Palmer' => 'chilský čas (Palmer)',
         'Antarctica/Rothera' => 'čas Rotherovy stanice (Rothera)',
-        'Antarctica/Syowa' => 'čas stanice Šówa (Syowa)',
+        'Antarctica/Syowa' => 'čas stanice Šówa (Showa)',
         'Antarctica/Troll' => 'greenwichský střední čas (Troll)',
         'Antarctica/Vostok' => 'čas stanice Vostok',
         'Arctic/Longyearbyen' => 'středoevropský čas (Longyearbyen)',
         'Asia/Aden' => 'arabský čas (Aden)',
-        'Asia/Almaty' => 'západokazachstánský čas (Almaty)',
+        'Asia/Almaty' => 'kazachstánský čas (Almaty)',
         'Asia/Amman' => 'východoevropský čas (Ammán)',
-        'Asia/Anadyr' => 'anadyrský čas',
-        'Asia/Aqtau' => 'západokazachstánský čas (Aktau)',
-        'Asia/Aqtobe' => 'západokazachstánský čas (Aktobe)',
+        'Asia/Anadyr' => 'petropavlovsko-kamčatský čas (Anadyr)',
+        'Asia/Aqtau' => 'kazachstánský čas (Aktau)',
+        'Asia/Aqtobe' => 'kazachstánský čas (Aktobe)',
         'Asia/Ashgabat' => 'turkmenský čas (Ašchabad)',
-        'Asia/Atyrau' => 'západokazachstánský čas (Atyrau)',
+        'Asia/Atyrau' => 'kazachstánský čas (Atyrau)',
         'Asia/Baghdad' => 'arabský čas (Bagdád)',
         'Asia/Bahrain' => 'arabský čas (Bahrajn)',
         'Asia/Baku' => 'ázerbájdžánský čas (Baku)',
         'Asia/Bangkok' => 'indočínský čas (Bangkok)',
-        'Asia/Barnaul' => 'časové pásmo Rusko (Barnaul)',
+        'Asia/Barnaul' => 'krasnojarský čas (Barnaul)',
         'Asia/Beirut' => 'východoevropský čas (Bejrút)',
         'Asia/Bishkek' => 'kyrgyzský čas (Biškek)',
         'Asia/Brunei' => 'brunejský čas',
         'Asia/Calcutta' => 'indický čas (Kalkata)',
+        'Asia/Kolkata' => 'indický čas (Kalkata)',
         'Asia/Chita' => 'jakutský čas (Čita)',
-        'Asia/Choibalsan' => 'ulánbátarský čas (Čojbalsan)',
         'Asia/Colombo' => 'indický čas (Kolombo)',
         'Asia/Damascus' => 'východoevropský čas (Damašek)',
         'Asia/Dhaka' => 'bangladéšský čas (Dháka)',
@@ -238,7 +249,7 @@ return [
         'Asia/Gaza' => 'východoevropský čas (Gaza)',
         'Asia/Hebron' => 'východoevropský čas (Hebron)',
         'Asia/Hong_Kong' => 'hongkongský čas',
-        'Asia/Hovd' => 'hovdský čas',
+        'Asia/Hovd' => 'hovdský čas (Khovd)',
         'Asia/Irkutsk' => 'irkutský čas',
         'Asia/Jakarta' => 'západoindonéský čas (Jakarta)',
         'Asia/Jayapura' => 'východoindonéský čas (Jayapura)',
@@ -247,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'petropavlovsko-kamčatský čas (Kamčatka)',
         'Asia/Karachi' => 'pákistánský čas (Karáčí)',
         'Asia/Katmandu' => 'nepálský čas (Káthmándú)',
+        'Asia/Kathmandu' => 'nepálský čas (Káthmándú)',
         'Asia/Khandyga' => 'jakutský čas (Chandyga)',
         'Asia/Krasnoyarsk' => 'krasnojarský čas',
         'Asia/Kuala_Lumpur' => 'malajský čas (Kuala Lumpur)',
@@ -259,19 +271,21 @@ return [
         'Asia/Muscat' => 'standardní čas Perského zálivu (Maskat)',
         'Asia/Nicosia' => 'východoevropský čas (Nikósie)',
         'Asia/Novokuznetsk' => 'krasnojarský čas (Novokuzněck)',
-        'Asia/Novosibirsk' => 'novosibirský čas',
+        'Asia/Novosibirsk' => 'krasnojarský čas (Novosibirsk)',
         'Asia/Omsk' => 'omský čas',
-        'Asia/Oral' => 'západokazachstánský čas (Uralsk)',
+        'Asia/Oral' => 'kazachstánský čas (Uralsk)',
         'Asia/Phnom_Penh' => 'indočínský čas (Phnompenh)',
         'Asia/Pontianak' => 'západoindonéský čas (Pontianak)',
         'Asia/Pyongyang' => 'korejský čas (Pchjongjang)',
         'Asia/Qatar' => 'arabský čas (Katar)',
-        'Asia/Qostanay' => 'západokazachstánský čas (Kostanaj)',
-        'Asia/Qyzylorda' => 'západokazachstánský čas (Kyzylorda)',
+        'Asia/Qostanay' => 'kazachstánský čas (Kostanaj)',
+        'Asia/Qyzylorda' => 'kazachstánský čas (Kyzylorda)',
         'Asia/Rangoon' => 'myanmarský čas (Rangún)',
+        'Asia/Yangon' => 'myanmarský čas (Rangún)',
         'Asia/Riyadh' => 'arabský čas (Rijád)',
         'Asia/Saigon' => 'indočínský čas (Ho Či Minovo město)',
-        'Asia/Sakhalin' => 'sachalinský čas',
+        'Asia/Ho_Chi_Minh' => 'indočínský čas (Ho Či Minovo město)',
+        'Asia/Sakhalin' => 'magadanský čas (Sachalin)',
         'Asia/Samarkand' => 'uzbecký čas (Samarkand)',
         'Asia/Seoul' => 'korejský čas (Soul)',
         'Asia/Shanghai' => 'čínský čas (Šanghaj)',
@@ -283,7 +297,7 @@ return [
         'Asia/Tehran' => 'íránský čas (Teherán)',
         'Asia/Thimphu' => 'bhútánský čas (Thimbú)',
         'Asia/Tokyo' => 'japonský čas (Tokio)',
-        'Asia/Tomsk' => 'časové pásmo Rusko (Tomsk)',
+        'Asia/Tomsk' => 'krasnojarský čas (Tomsk)',
         'Asia/Ulaanbaatar' => 'ulánbátarský čas',
         'Asia/Urumqi' => 'časové pásmo Čína (Urumči)',
         'Asia/Ust-Nera' => 'vladivostocký čas (Ust-Nera)',
@@ -297,6 +311,7 @@ return [
         'Atlantic/Canary' => 'západoevropský čas (Kanárské ostrovy)',
         'Atlantic/Cape_Verde' => 'kapverdský čas (Kapverdy)',
         'Atlantic/Faeroe' => 'západoevropský čas (Faerské ostrovy)',
+        'Atlantic/Faroe' => 'západoevropský čas (Faerské ostrovy)',
         'Atlantic/Madeira' => 'západoevropský čas (Madeira)',
         'Atlantic/Reykjavik' => 'greenwichský střední čas (Reykjavík)',
         'Atlantic/South_Georgia' => 'čas Jižní Georgie',
@@ -313,13 +328,11 @@ return [
         'Australia/Melbourne' => 'východoaustralský čas (Melbourne)',
         'Australia/Perth' => 'západoaustralský čas (Perth)',
         'Australia/Sydney' => 'východoaustralský čas (Sydney)',
-        'CST6CDT' => 'severoamerický centrální čas',
-        'EST5EDT' => 'severoamerický východní čas',
         'Etc/GMT' => 'greenwichský střední čas',
         'Etc/UTC' => 'koordinovaný světový čas',
         'Europe/Amsterdam' => 'středoevropský čas (Amsterdam)',
         'Europe/Andorra' => 'středoevropský čas (Andorra)',
-        'Europe/Astrakhan' => 'moskevský čas (Astrachaň)',
+        'Europe/Astrakhan' => 'samarský čas (Astrachaň)',
         'Europe/Athens' => 'východoevropský čas (Athény)',
         'Europe/Belgrade' => 'středoevropský čas (Bělehrad)',
         'Europe/Berlin' => 'středoevropský čas (Berlín)',
@@ -327,19 +340,20 @@ return [
         'Europe/Brussels' => 'středoevropský čas (Brusel)',
         'Europe/Bucharest' => 'východoevropský čas (Bukurešť)',
         'Europe/Budapest' => 'středoevropský čas (Budapešť)',
-        'Europe/Busingen' => 'středoevropský čas (Busingen)',
+        'Europe/Busingen' => 'středoevropský čas (Büsingen)',
         'Europe/Chisinau' => 'východoevropský čas (Kišiněv)',
         'Europe/Copenhagen' => 'středoevropský čas (Kodaň)',
-        'Europe/Dublin' => 'greenwichský střední čas (Dublin)',
+        'Europe/Dublin' => 'časové pásmo Irsko (Dublin)',
         'Europe/Gibraltar' => 'středoevropský čas (Gibraltar)',
         'Europe/Guernsey' => 'greenwichský střední čas (Guernsey)',
         'Europe/Helsinki' => 'východoevropský čas (Helsinky)',
         'Europe/Isle_of_Man' => 'greenwichský střední čas (Ostrov Man)',
-        'Europe/Istanbul' => 'časové pásmo Turecko (Istanbul)',
+        'Europe/Istanbul' => 'Turecký čas (Istanbul)',
         'Europe/Jersey' => 'greenwichský střední čas (Jersey)',
         'Europe/Kaliningrad' => 'východoevropský čas (Kaliningrad)',
         'Europe/Kiev' => 'východoevropský čas (Kyjev)',
-        'Europe/Kirov' => 'časové pásmo Rusko (Kirov)',
+        'Europe/Kyiv' => 'východoevropský čas (Kyjev)',
+        'Europe/Kirov' => 'moskevský čas (Kirov)',
         'Europe/Lisbon' => 'západoevropský čas (Lisabon)',
         'Europe/Ljubljana' => 'středoevropský čas (Lublaň)',
         'Europe/London' => 'greenwichský střední čas (Londýn)',
@@ -359,19 +373,19 @@ return [
         'Europe/Samara' => 'samarský čas (Samara)',
         'Europe/San_Marino' => 'středoevropský čas (San Marino)',
         'Europe/Sarajevo' => 'středoevropský čas (Sarajevo)',
-        'Europe/Saratov' => 'moskevský čas (Saratov)',
+        'Europe/Saratov' => 'samarský čas (Saratov)',
         'Europe/Simferopol' => 'moskevský čas (Simferopol)',
         'Europe/Skopje' => 'středoevropský čas (Skopje)',
         'Europe/Sofia' => 'východoevropský čas (Sofie)',
         'Europe/Stockholm' => 'středoevropský čas (Stockholm)',
         'Europe/Tallinn' => 'východoevropský čas (Tallinn)',
         'Europe/Tirane' => 'středoevropský čas (Tirana)',
-        'Europe/Ulyanovsk' => 'moskevský čas (Uljanovsk)',
+        'Europe/Ulyanovsk' => 'samarský čas (Uljanovsk)',
         'Europe/Vaduz' => 'středoevropský čas (Vaduz)',
         'Europe/Vatican' => 'středoevropský čas (Vatikán)',
         'Europe/Vienna' => 'středoevropský čas (Vídeň)',
         'Europe/Vilnius' => 'východoevropský čas (Vilnius)',
-        'Europe/Volgograd' => 'volgogradský čas',
+        'Europe/Volgograd' => 'moskevský čas (Volgograd)',
         'Europe/Warsaw' => 'středoevropský čas (Varšava)',
         'Europe/Zagreb' => 'středoevropský čas (Záhřeb)',
         'Europe/Zurich' => 'středoevropský čas (Curych)',
@@ -386,15 +400,14 @@ return [
         'Indian/Mauritius' => 'mauricijský čas (Mauricius)',
         'Indian/Mayotte' => 'východoafrický čas (Mayotte)',
         'Indian/Reunion' => 'réunionský čas',
-        'MST7MDT' => 'severoamerický horský čas',
-        'PST8PDT' => 'severoamerický pacifický čas',
         'Pacific/Apia' => 'apijský čas (Apia)',
         'Pacific/Auckland' => 'novozélandský čas (Auckland)',
         'Pacific/Bougainville' => 'čas Papuy-Nové Guiney (Bougainville)',
         'Pacific/Chatham' => 'chathamský čas (Chathamské ostrovy)',
         'Pacific/Easter' => 'čas Velikonočního ostrova (Velikonoční ostrov)',
         'Pacific/Efate' => 'vanuatský čas (Éfaté)',
-        'Pacific/Enderbury' => 'čas Fénixových ostrovů (Enderbury)',
+        'Pacific/Enderbury' => 'čas Fénixových ostrovů (Kanton (ostrov))',
+        'Pacific/Kanton' => 'čas Fénixových ostrovů (Kanton (ostrov))',
         'Pacific/Fakaofo' => 'tokelauský čas (Fakaofo)',
         'Pacific/Fiji' => 'fidžijský čas',
         'Pacific/Funafuti' => 'tuvalský čas (Funafuti)',
@@ -402,7 +415,7 @@ return [
         'Pacific/Gambier' => 'gambierský čas (Gambierovy ostrovy)',
         'Pacific/Guadalcanal' => 'čas Šalamounových ostrovů (Guadalcanal)',
         'Pacific/Guam' => 'chamorrský čas (Guam)',
-        'Pacific/Honolulu' => 'havajsko-aleutský čas (Honolulu)',
+        'Pacific/Honolulu' => 'havajsko-aleutský standardní čas (Honolulu)',
         'Pacific/Kiritimati' => 'čas Rovníkových ostrovů (Kiritimati)',
         'Pacific/Kosrae' => 'kosrajský čas (Kosrae)',
         'Pacific/Kwajalein' => 'čas Marshallových ostrovů (Kwajalein)',
@@ -417,6 +430,7 @@ return [
         'Pacific/Palau' => 'palauský čas',
         'Pacific/Pitcairn' => 'čas Pitcairnových ostrovů (Pitcairnovy ostrovy)',
         'Pacific/Ponape' => 'ponapský čas (Pohnpei)',
+        'Pacific/Pohnpei' => 'ponapský čas (Pohnpei)',
         'Pacific/Port_Moresby' => 'čas Papuy-Nové Guiney (Port Moresby)',
         'Pacific/Rarotonga' => 'čas Cookových ostrovů (Rarotonga)',
         'Pacific/Saipan' => 'chamorrský čas (Saipan)',
@@ -424,8 +438,9 @@ return [
         'Pacific/Tarawa' => 'čas Gilbertových ostrovů (Tarawa)',
         'Pacific/Tongatapu' => 'tonžský čas (Tongatapu)',
         'Pacific/Truk' => 'chuukský čas (Chuukské ostrovy)',
+        'Pacific/Chuuk' => 'chuukský čas (Chuukské ostrovy)',
         'Pacific/Wake' => 'čas ostrova Wake',
-        'Pacific/Wallis' => 'čas ostrovů Wallis a Futuna',
+        'Pacific/Wallis' => 'čas ostrovů Wallis a Futuna (Wallis & Futuna)',
     ],
     'Meta' => [
         'HourFormatPos' => '+%d:%02d',
