@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'East-Afrikaanske tiid (Addis Abeba)',
         'Africa/Algiers' => 'Midden-Europeeske tiid (Algiers)',
         'Africa/Asmera' => 'East-Afrikaanske tiid (Asmara)',
+        'Africa/Asmara' => 'East-Afrikaanske tiid (Asmara)',
         'Africa/Bamako' => 'Greenwich Mean Time (Bamako)',
         'Africa/Bangui' => 'West-Afrikaanske tiid (Bangui)',
         'Africa/Banjul' => 'Greenwich Mean Time (Banjul)',
@@ -22,7 +23,7 @@ return [
         'Africa/Dar_es_Salaam' => 'East-Afrikaanske tiid (Dar es Salaam)',
         'Africa/Djibouti' => 'East-Afrikaanske tiid (Djibouti)',
         'Africa/Douala' => 'West-Afrikaanske tiid (Douala)',
-        'Africa/El_Aaiun' => 'West-Europeeske tiid (El Aaiun)',
+        'Africa/El_Aaiun' => 'West-Europeeske tiid (El Aaiún)',
         'Africa/Freetown' => 'Greenwich Mean Time (Freetown)',
         'Africa/Gaborone' => 'Sintraal-Afrikaanske tiid (Gaborone)',
         'Africa/Harare' => 'Sintraal-Afrikaanske tiid (Harare)',
@@ -45,7 +46,7 @@ return [
         'Africa/Mogadishu' => 'East-Afrikaanske tiid (Mogadishu)',
         'Africa/Monrovia' => 'Greenwich Mean Time (Monrovia)',
         'Africa/Nairobi' => 'East-Afrikaanske tiid (Nairobi)',
-        'Africa/Ndjamena' => 'West-Afrikaanske tiid (Ndjamena)',
+        'Africa/Ndjamena' => 'West-Afrikaanske tiid (N’Djamena)',
         'Africa/Niamey' => 'West-Afrikaanske tiid (Niamey)',
         'Africa/Nouakchott' => 'Greenwich Mean Time (Nouakchott)',
         'Africa/Ouagadougou' => 'Greenwich Mean Time (Ouagadougou)',
@@ -58,7 +59,7 @@ return [
         'America/Anchorage' => 'Alaska-tiid (Anchorage)',
         'America/Anguilla' => 'Atlantic-tiid (Anguilla)',
         'America/Antigua' => 'Atlantic-tiid (Antigua)',
-        'America/Araguaina' => 'Brazyljaanske tiid (Araguaina)',
+        'America/Araguaina' => 'Brazyljaanske tiid (Araguaína)',
         'America/Argentina/La_Rioja' => 'Argentynske tiid (La Rioja)',
         'America/Argentina/Rio_Gallegos' => 'Argentynske tiid (Río Gallegos)',
         'America/Argentina/Salta' => 'Argentynske tiid (Salta)',
@@ -78,18 +79,24 @@ return [
         'America/Bogota' => 'Kolombiaanske tiid (Bogotá)',
         'America/Boise' => 'Mountain-tiid (Boise)',
         'America/Buenos_Aires' => 'Argentynske tiid (Buenos Aires)',
+        'America/Argentina/Buenos_Aires' => 'Argentynske tiid (Buenos Aires)',
         'America/Cambridge_Bay' => 'Mountain-tiid (Cambridge Bay)',
         'America/Campo_Grande' => 'Amazone-tiid (Campo Grande)',
-        'America/Cancun' => 'Eastern-tiid (Cancun)',
+        'America/Cancun' => 'Eastern-tiid (Cancún)',
         'America/Caracas' => 'Fenezolaanske tiid (Caracas)',
         'America/Catamarca' => 'Argentynske tiid (Catamarca)',
+        'America/Argentina/Catamarca' => 'Argentynske tiid (Catamarca)',
         'America/Cayenne' => 'Frâns-Guyaanske tiid (Cayenne)',
         'America/Cayman' => 'Eastern-tiid (Cayman)',
         'America/Chicago' => 'Central-tiid (Chicago)',
-        'America/Chihuahua' => 'Mexico-tiid (Chihuahua)',
+        'America/Chihuahua' => 'Central-tiid (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Mountain-tiid (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Eastern-tiid (Atikokan)',
+        'America/Atikokan' => 'Eastern-tiid (Atikokan)',
         'America/Cordoba' => 'Argentynske tiid (Córdoba)',
+        'America/Argentina/Cordoba' => 'Argentynske tiid (Córdoba)',
         'America/Costa_Rica' => 'Central-tiid (Costa Rica)',
+        'America/Coyhaique' => 'Sileenske tiid (Coyhaique)',
         'America/Creston' => 'Mountain-tiid (Creston)',
         'America/Cuiaba' => 'Amazone-tiid (Cuiabá)',
         'America/Curacao' => 'Atlantic-tiid (Curaçao)',
@@ -100,12 +107,13 @@ return [
         'America/Detroit' => 'Eastern-tiid (Detroit)',
         'America/Dominica' => 'Atlantic-tiid (Dominica)',
         'America/Edmonton' => 'Mountain-tiid (Edmonton)',
-        'America/Eirunepe' => 'Acre-tiid (Eirunepe)',
+        'America/Eirunepe' => 'Acre-tiid (Eirunepé)',
         'America/El_Salvador' => 'Central-tiid (Salvador)',
         'America/Fort_Nelson' => 'Mountain-tiid (Fort Nelson)',
         'America/Fortaleza' => 'Brazyljaanske tiid (Fortaleza)',
         'America/Glace_Bay' => 'Atlantic-tiid (Glace Bay)',
-        'America/Godthab' => 'West-Groenlânske tiid (Nuuk)',
+        'America/Godthab' => 'Grienlân-tiid (Nuuk)',
+        'America/Nuuk' => 'Grienlân-tiid (Nuuk)',
         'America/Goose_Bay' => 'Atlantic-tiid (Goose Bay)',
         'America/Grand_Turk' => 'Eastern-tiid (Grand Turk)',
         'America/Grenada' => 'Atlantic-tiid (Grenada)',
@@ -124,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'Eastern-tiid (Vincennes, Indiana)',
         'America/Indiana/Winamac' => 'Eastern-tiid (Winamac, Indiana)',
         'America/Indianapolis' => 'Eastern-tiid (Indianapolis)',
+        'America/Indiana/Indianapolis' => 'Eastern-tiid (Indianapolis)',
         'America/Inuvik' => 'Mountain-tiid (Inuvik)',
         'America/Iqaluit' => 'Eastern-tiid (Iqaluit)',
         'America/Jamaica' => 'Eastern-tiid (Jamaica)',
         'America/Jujuy' => 'Argentynske tiid (Jujuy)',
+        'America/Argentina/Jujuy' => 'Argentynske tiid (Jujuy)',
         'America/Juneau' => 'Alaska-tiid (Juneau)',
         'America/Kentucky/Monticello' => 'Eastern-tiid (Monticello, Kentucky)',
         'America/Kralendijk' => 'Atlantic-tiid (Kralendijk)',
@@ -135,6 +145,7 @@ return [
         'America/Lima' => 'Peruaanske tiid (Lima)',
         'America/Los_Angeles' => 'Pasifik-tiid (Los Angeles)',
         'America/Louisville' => 'Eastern-tiid (Louisville)',
+        'America/Kentucky/Louisville' => 'Eastern-tiid (Louisville)',
         'America/Lower_Princes' => 'Atlantic-tiid (Beneden Prinsen Kwartier)',
         'America/Maceio' => 'Brazyljaanske tiid (Maceió)',
         'America/Managua' => 'Central-tiid (Managua)',
@@ -144,6 +155,7 @@ return [
         'America/Matamoros' => 'Central-tiid (Matamoros)',
         'America/Mazatlan' => 'Mexico-tiid (Mazatlán)',
         'America/Mendoza' => 'Argentynske tiid (Mendoza)',
+        'America/Argentina/Mendoza' => 'Argentynske tiid (Mendoza)',
         'America/Menominee' => 'Central-tiid (Menominee)',
         'America/Merida' => 'Central-tiid (Mérida)',
         'America/Metlakatla' => 'Alaska-tiid (Metlakatla)',
@@ -152,19 +164,16 @@ return [
         'America/Moncton' => 'Atlantic-tiid (Moncton)',
         'America/Monterrey' => 'Central-tiid (Monterrey)',
         'America/Montevideo' => 'Uruguayaanske tiid (Montevideo)',
-        'America/Montreal' => 'Canada-tiid (Montreal)',
         'America/Montserrat' => 'Atlantic-tiid (Montserrat)',
         'America/Nassau' => 'Eastern-tiid (Nassau)',
         'America/New_York' => 'Eastern-tiid (New York)',
-        'America/Nipigon' => 'Eastern-tiid (Nipigon)',
         'America/Nome' => 'Alaska-tiid (Nome)',
         'America/Noronha' => 'Fernando de Noronha-tiid',
         'America/North_Dakota/Beulah' => 'Central-tiid (Beulah, Noard-Dakota)',
         'America/North_Dakota/Center' => 'Central-tiid (Center, Noard-Dakota)',
         'America/North_Dakota/New_Salem' => 'Central-tiid (New Salem, Noard-Dakota)',
-        'America/Ojinaga' => 'Mountain-tiid (Ojinaga)',
+        'America/Ojinaga' => 'Central-tiid (Ojinaga)',
         'America/Panama' => 'Eastern-tiid (Panama)',
-        'America/Pangnirtung' => 'Eastern-tiid (Pangnirtung)',
         'America/Paramaribo' => 'Surinaamske tiid (Paramaribo)',
         'America/Phoenix' => 'Mountain-tiid (Phoenix)',
         'America/Port-au-Prince' => 'Eastern-tiid (Port-au-Prince)',
@@ -172,18 +181,16 @@ return [
         'America/Porto_Velho' => 'Amazone-tiid (Pôrto Velho)',
         'America/Puerto_Rico' => 'Atlantic-tiid (Puerto Rico)',
         'America/Punta_Arenas' => 'Sileenske tiid (Punta Arenas)',
-        'America/Rainy_River' => 'Central-tiid (Rainy River)',
         'America/Rankin_Inlet' => 'Central-tiid (Rankin Inlet)',
         'America/Recife' => 'Brazyljaanske tiid (Recife)',
         'America/Regina' => 'Central-tiid (Regina)',
         'America/Resolute' => 'Central-tiid (Resolute)',
         'America/Rio_Branco' => 'Acre-tiid (Rio Branco)',
-        'America/Santa_Isabel' => 'Mexico-tiid (Santa Isabel)',
-        'America/Santarem' => 'Brazyljaanske tiid (Santarem)',
+        'America/Santarem' => 'Brazyljaanske tiid (Santarém)',
         'America/Santiago' => 'Sileenske tiid (Santiago)',
         'America/Santo_Domingo' => 'Atlantic-tiid (Santo Domingo)',
         'America/Sao_Paulo' => 'Brazyljaanske tiid (São Paulo)',
-        'America/Scoresbysund' => 'East-Groenlânske tiid (Ittoqqortoormiit)',
+        'America/Scoresbysund' => 'Grienlân-tiid (Ittoqqortoormiit)',
         'America/Sitka' => 'Alaska-tiid (Sitka)',
         'America/St_Barthelemy' => 'Atlantic-tiid (Saint-Barthélemy)',
         'America/St_Johns' => 'Newfoundlânske-tiid (St. John’s)',
@@ -194,7 +201,6 @@ return [
         'America/Swift_Current' => 'Central-tiid (Swift Current)',
         'America/Tegucigalpa' => 'Central-tiid (Tegucigalpa)',
         'America/Thule' => 'Atlantic-tiid (Thule)',
-        'America/Thunder_Bay' => 'Eastern-tiid (Thunder Bay)',
         'America/Tijuana' => 'Pasifik-tiid (Tijuana)',
         'America/Toronto' => 'Eastern-tiid (Toronto)',
         'America/Tortola' => 'Atlantic-tiid (Tortola)',
@@ -202,8 +208,7 @@ return [
         'America/Whitehorse' => 'Canada-tiid (Whitehorse)',
         'America/Winnipeg' => 'Central-tiid (Winnipeg)',
         'America/Yakutat' => 'Alaska-tiid (Yakutat)',
-        'America/Yellowknife' => 'Mountain-tiid (Yellowknife)',
-        'Antarctica/Casey' => 'Antarctica-tiid (Casey)',
+        'Antarctica/Casey' => 'West-Australyske tiid (Casey)',
         'Antarctica/Davis' => 'Davis tiid',
         'Antarctica/DumontDUrville' => 'Dumont-d’Urville tiid',
         'Antarctica/Macquarie' => 'East-Australyske tiid (Macquarie)',
@@ -211,29 +216,29 @@ return [
         'Antarctica/McMurdo' => 'Nij-Seelânske tiid (McMurdo)',
         'Antarctica/Palmer' => 'Sileenske tiid (Palmer)',
         'Antarctica/Rothera' => 'Rothera tiid',
-        'Antarctica/Syowa' => 'Syowa tiid',
+        'Antarctica/Syowa' => 'Syowa tiid (Showa)',
         'Antarctica/Troll' => 'Greenwich Mean Time (Troll)',
         'Antarctica/Vostok' => 'Vostok tiid',
         'Arctic/Longyearbyen' => 'Midden-Europeeske tiid (Longyearbyen)',
         'Asia/Aden' => 'Arabyske tiid (Aden)',
-        'Asia/Almaty' => 'East-Kazachse tiid (Alma-Ata)',
+        'Asia/Almaty' => 'Kazachstan-tiid (Alma-Ata)',
         'Asia/Amman' => 'East-Europeeske tiid (Amman)',
-        'Asia/Anadyr' => 'Anadyr-tiid',
-        'Asia/Aqtau' => 'West-Kazachse tiid (Aqtau)',
-        'Asia/Aqtobe' => 'West-Kazachse tiid (Aqtöbe)',
+        'Asia/Anadyr' => 'Petropavlovsk-Kamtsjatski-tiid (Anadyr)',
+        'Asia/Aqtau' => 'Kazachstan-tiid (Aqtau)',
+        'Asia/Aqtobe' => 'Kazachstan-tiid (Aqtöbe)',
         'Asia/Ashgabat' => 'Turkmeense tiid (Asjchabad)',
-        'Asia/Atyrau' => 'West-Kazachse tiid (Atyrau)',
+        'Asia/Atyrau' => 'Kazachstan-tiid (Atyrau)',
         'Asia/Baghdad' => 'Arabyske tiid (Bagdad)',
         'Asia/Bahrain' => 'Arabyske tiid (Bahrein)',
         'Asia/Baku' => 'Azerbeidzjaanske tiid (Bakoe)',
         'Asia/Bangkok' => 'Yndochinese tiid (Bangkok)',
-        'Asia/Barnaul' => 'Ruslân-tiid (Barnaul)',
+        'Asia/Barnaul' => 'Krasnojarsk-tiid (Barnaul)',
         'Asia/Beirut' => 'East-Europeeske tiid (Beiroet)',
         'Asia/Bishkek' => 'Kirgizyske tiid (Bisjkek)',
         'Asia/Brunei' => 'Bruneise tiid',
         'Asia/Calcutta' => 'Yndiaaske tiid (Calcutta)',
+        'Asia/Kolkata' => 'Yndiaaske tiid (Calcutta)',
         'Asia/Chita' => 'Jakoetsk-tiid (Chita)',
-        'Asia/Choibalsan' => 'Ulaanbaatar tiid (Choibalsan)',
         'Asia/Colombo' => 'Yndiaaske tiid (Colombo)',
         'Asia/Damascus' => 'East-Europeeske tiid (Damascus)',
         'Asia/Dhaka' => 'Bengalese tiid (Dhaka)',
@@ -244,7 +249,7 @@ return [
         'Asia/Gaza' => 'East-Europeeske tiid (Gaza)',
         'Asia/Hebron' => 'East-Europeeske tiid (Hebron)',
         'Asia/Hong_Kong' => 'Hongkongse tiid',
-        'Asia/Hovd' => 'Hovd tiid',
+        'Asia/Hovd' => 'Hovd tiid (Khovd)',
         'Asia/Irkutsk' => 'Irkoetsk-tiid',
         'Asia/Jakarta' => 'West-Yndonezyske tiid (Jakarta)',
         'Asia/Jayapura' => 'East-Yndonezyske tiid (Jayapura)',
@@ -253,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'Petropavlovsk-Kamtsjatski-tiid (Kamtsjatka)',
         'Asia/Karachi' => 'Pakistaanske tiid (Karachi)',
         'Asia/Katmandu' => 'Nepalese tiid (Kathmandu)',
+        'Asia/Kathmandu' => 'Nepalese tiid (Kathmandu)',
         'Asia/Khandyga' => 'Jakoetsk-tiid (Khandyga)',
         'Asia/Krasnoyarsk' => 'Krasnojarsk-tiid',
         'Asia/Kuala_Lumpur' => 'Maleisyske tiid (Kuala Lumpur)',
@@ -265,19 +271,21 @@ return [
         'Asia/Muscat' => 'Golf standerttiid (Muscat)',
         'Asia/Nicosia' => 'East-Europeeske tiid (Nicosia)',
         'Asia/Novokuznetsk' => 'Krasnojarsk-tiid (Novokuznetsk)',
-        'Asia/Novosibirsk' => 'Novosibirsk-tiid',
+        'Asia/Novosibirsk' => 'Krasnojarsk-tiid (Novosibirsk)',
         'Asia/Omsk' => 'Omsk-tiid',
-        'Asia/Oral' => 'West-Kazachse tiid (Oral)',
+        'Asia/Oral' => 'Kazachstan-tiid (Oral)',
         'Asia/Phnom_Penh' => 'Yndochinese tiid (Phnom-Penh)',
         'Asia/Pontianak' => 'West-Yndonezyske tiid (Pontianak)',
         'Asia/Pyongyang' => 'Koreaanske tiid (Pyongyang)',
         'Asia/Qatar' => 'Arabyske tiid (Qatar)',
-        'Asia/Qostanay' => 'East-Kazachse tiid (Qostanay)',
-        'Asia/Qyzylorda' => 'West-Kazachse tiid (Qyzylorda)',
+        'Asia/Qostanay' => 'Kazachstan-tiid (Qostanay)',
+        'Asia/Qyzylorda' => 'Kazachstan-tiid (Qyzylorda)',
         'Asia/Rangoon' => 'Myanmarese tiid (Yangon)',
+        'Asia/Yangon' => 'Myanmarese tiid (Yangon)',
         'Asia/Riyadh' => 'Arabyske tiid (Riyad)',
         'Asia/Saigon' => 'Yndochinese tiid (Ho Chi Minhstad)',
-        'Asia/Sakhalin' => 'Sachalin-tiid',
+        'Asia/Ho_Chi_Minh' => 'Yndochinese tiid (Ho Chi Minhstad)',
+        'Asia/Sakhalin' => 'Magadan-tiid (Sachalin)',
         'Asia/Samarkand' => 'Oezbeekse tiid (Samarkand)',
         'Asia/Seoul' => 'Koreaanske tiid (Seoul)',
         'Asia/Shanghai' => 'Sineeske tiid (Sjanghai)',
@@ -289,9 +297,9 @@ return [
         'Asia/Tehran' => 'Iraanske tiid (Teheran)',
         'Asia/Thimphu' => 'Bhutaanske tiid (Thimphu)',
         'Asia/Tokyo' => 'Japanske tiid (Tokio)',
-        'Asia/Tomsk' => 'Ruslân-tiid (Tomsk)',
+        'Asia/Tomsk' => 'Krasnojarsk-tiid (Tomsk)',
         'Asia/Ulaanbaatar' => 'Ulaanbaatar tiid',
-        'Asia/Urumqi' => 'Sina-tiid (Urumqi)',
+        'Asia/Urumqi' => 'Sina-tiid (Ürümqi)',
         'Asia/Ust-Nera' => 'Vladivostok-tiid (Ust-Nera)',
         'Asia/Vientiane' => 'Yndochinese tiid (Vientiane)',
         'Asia/Vladivostok' => 'Vladivostok-tiid',
@@ -303,6 +311,7 @@ return [
         'Atlantic/Canary' => 'West-Europeeske tiid (Kanaryske Eilannen)',
         'Atlantic/Cape_Verde' => 'Kaapverdyske tiid (Kaapverdië)',
         'Atlantic/Faeroe' => 'West-Europeeske tiid (Faeröer)',
+        'Atlantic/Faroe' => 'West-Europeeske tiid (Faeröer)',
         'Atlantic/Madeira' => 'West-Europeeske tiid (Madeira)',
         'Atlantic/Reykjavik' => 'Greenwich Mean Time (Reykjavik)',
         'Atlantic/South_Georgia' => 'Sûd-Georgyske tiid (Sûd-Georgia)',
@@ -311,7 +320,6 @@ return [
         'Australia/Adelaide' => 'Midden-Australyske tiid (Adelaide)',
         'Australia/Brisbane' => 'East-Australyske tiid (Brisbane)',
         'Australia/Broken_Hill' => 'Midden-Australyske tiid (Broken Hill)',
-        'Australia/Currie' => 'East-Australyske tiid (Currie)',
         'Australia/Darwin' => 'Midden-Australyske tiid (Darwin)',
         'Australia/Eucla' => 'Midden-Australyske westelijke tiid (Eucla)',
         'Australia/Hobart' => 'East-Australyske tiid (Hobart)',
@@ -320,12 +328,10 @@ return [
         'Australia/Melbourne' => 'East-Australyske tiid (Melbourne)',
         'Australia/Perth' => 'West-Australyske tiid (Perth)',
         'Australia/Sydney' => 'East-Australyske tiid (Sydney)',
-        'CST6CDT' => 'Central-tiid',
-        'EST5EDT' => 'Eastern-tiid',
         'Etc/GMT' => 'Greenwich Mean Time',
         'Europe/Amsterdam' => 'Midden-Europeeske tiid (Amsterdam)',
         'Europe/Andorra' => 'Midden-Europeeske tiid (Andorra)',
-        'Europe/Astrakhan' => 'Moskou-tiid (Astrakhan)',
+        'Europe/Astrakhan' => 'Samara-tiid (Astrakhan)',
         'Europe/Athens' => 'East-Europeeske tiid (Athene)',
         'Europe/Belgrade' => 'Midden-Europeeske tiid (Belgrado)',
         'Europe/Berlin' => 'Midden-Europeeske tiid (Berlyn)',
@@ -333,10 +339,10 @@ return [
         'Europe/Brussels' => 'Midden-Europeeske tiid (Brussel)',
         'Europe/Bucharest' => 'East-Europeeske tiid (Boekarest)',
         'Europe/Budapest' => 'Midden-Europeeske tiid (Boedapest)',
-        'Europe/Busingen' => 'Midden-Europeeske tiid (Busingen)',
-        'Europe/Chisinau' => 'East-Europeeske tiid (Chisinau)',
+        'Europe/Busingen' => 'Midden-Europeeske tiid (Büsingen)',
+        'Europe/Chisinau' => 'East-Europeeske tiid (Chișinău)',
         'Europe/Copenhagen' => 'Midden-Europeeske tiid (Kopenhagen)',
-        'Europe/Dublin' => 'Greenwich Mean Time (Dublin)',
+        'Europe/Dublin' => 'Ierlân-tiid (Dublin)',
         'Europe/Gibraltar' => 'Midden-Europeeske tiid (Gibraltar)',
         'Europe/Guernsey' => 'Greenwich Mean Time (Guernsey)',
         'Europe/Helsinki' => 'East-Europeeske tiid (Helsinki)',
@@ -344,8 +350,9 @@ return [
         'Europe/Istanbul' => 'Turkije-tiid (Istanboel)',
         'Europe/Jersey' => 'Greenwich Mean Time (Jersey)',
         'Europe/Kaliningrad' => 'East-Europeeske tiid (Kaliningrad)',
-        'Europe/Kiev' => 'East-Europeeske tiid (Kiev)',
-        'Europe/Kirov' => 'Ruslân-tiid (Kirov)',
+        'Europe/Kiev' => 'East-Europeeske tiid (Kyiv)',
+        'Europe/Kyiv' => 'East-Europeeske tiid (Kyiv)',
+        'Europe/Kirov' => 'Moskou-tiid (Kirov)',
         'Europe/Lisbon' => 'West-Europeeske tiid (Lissabon)',
         'Europe/Ljubljana' => 'Midden-Europeeske tiid (Ljubljana)',
         'Europe/London' => 'Greenwich Mean Time (Londen)',
@@ -365,37 +372,33 @@ return [
         'Europe/Samara' => 'Samara-tiid',
         'Europe/San_Marino' => 'Midden-Europeeske tiid (San Marino)',
         'Europe/Sarajevo' => 'Midden-Europeeske tiid (Sarajevo)',
-        'Europe/Saratov' => 'Moskou-tiid (Saratov)',
+        'Europe/Saratov' => 'Samara-tiid (Saratov)',
         'Europe/Simferopol' => 'Moskou-tiid (Simferopol)',
         'Europe/Skopje' => 'Midden-Europeeske tiid (Skopje)',
         'Europe/Sofia' => 'East-Europeeske tiid (Sofia)',
         'Europe/Stockholm' => 'Midden-Europeeske tiid (Stockholm)',
         'Europe/Tallinn' => 'East-Europeeske tiid (Tallinn)',
         'Europe/Tirane' => 'Midden-Europeeske tiid (Tirana)',
-        'Europe/Ulyanovsk' => 'Moskou-tiid (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'East-Europeeske tiid (Oezjhorod)',
+        'Europe/Ulyanovsk' => 'Samara-tiid (Ulyanovsk)',
         'Europe/Vaduz' => 'Midden-Europeeske tiid (Vaduz)',
         'Europe/Vatican' => 'Midden-Europeeske tiid (Fatikaanstêd)',
         'Europe/Vienna' => 'Midden-Europeeske tiid (Wenen)',
         'Europe/Vilnius' => 'East-Europeeske tiid (Vilnius)',
-        'Europe/Volgograd' => 'Wolgograd-tiid',
+        'Europe/Volgograd' => 'Moskou-tiid (Wolgograd)',
         'Europe/Warsaw' => 'Midden-Europeeske tiid (Warschau)',
         'Europe/Zagreb' => 'Midden-Europeeske tiid (Zagreb)',
-        'Europe/Zaporozhye' => 'East-Europeeske tiid (Zaporizja)',
         'Europe/Zurich' => 'Midden-Europeeske tiid (Zürich)',
         'Indian/Antananarivo' => 'East-Afrikaanske tiid (Antananarivo)',
         'Indian/Chagos' => 'Yndyske Oceaan-tiid (Chagosarchipel)',
         'Indian/Christmas' => 'Krysteilânske tiid',
         'Indian/Cocos' => 'Kokoseilânske tiid (Cocoseilannen)',
-        'Indian/Comoro' => 'East-Afrikaanske tiid (Comoro)',
+        'Indian/Comoro' => 'East-Afrikaanske tiid (Comores)',
         'Indian/Kerguelen' => 'Frânske Súdlike en Antarctyske tiid (Kerguelen)',
         'Indian/Mahe' => 'Seychelse tiid (Mahé)',
         'Indian/Maldives' => 'Maldivyske tiid (Maldiven)',
         'Indian/Mauritius' => 'Mauritiaanske tiid (Mauritius)',
         'Indian/Mayotte' => 'East-Afrikaanske tiid (Mayotte)',
         'Indian/Reunion' => 'Réunionse tiid',
-        'MST7MDT' => 'Mountain-tiid',
-        'PST8PDT' => 'Pasifik-tiid',
         'Pacific/Apia' => 'Samoa-tiid (Apia)',
         'Pacific/Auckland' => 'Nij-Seelânske tiid (Auckland)',
         'Pacific/Bougainville' => 'Papoea-Nij-Guineeske tiid (Bougainville)',
@@ -403,6 +406,7 @@ return [
         'Pacific/Easter' => 'Peaskeeilânske tiid',
         'Pacific/Efate' => 'Vanuatuaanske tiid (Efate)',
         'Pacific/Enderbury' => 'Phoenixeilânske tiid (Enderbury-eilân)',
+        'Pacific/Kanton' => 'Phoenixeilânske tiid (Enderbury-eilân)',
         'Pacific/Fakaofo' => 'Tokelau-eilânske tiid (Fakaofo)',
         'Pacific/Fiji' => 'Fijyske tiid (Fiji)',
         'Pacific/Funafuti' => 'Tuvaluaanske tiid (Funafuti)',
@@ -410,8 +414,7 @@ return [
         'Pacific/Gambier' => 'Gambiereilânske tiid (Gambiereilannen)',
         'Pacific/Guadalcanal' => 'Salomonseilânske tiid (Guadalcanal)',
         'Pacific/Guam' => 'Chamorro-tiid (Guam)',
-        'Pacific/Honolulu' => 'Hawaii-Aleoetyske tiid (Honolulu)',
-        'Pacific/Johnston' => 'Hawaii-Aleoetyske tiid (Johnston)',
+        'Pacific/Honolulu' => 'Hawaii-Aleoetyske standerttiid (Honolulu)',
         'Pacific/Kiritimati' => 'Line-eilânske tiid (Kiritimati)',
         'Pacific/Kosrae' => 'Kosraese tiid',
         'Pacific/Kwajalein' => 'Marshalleilânske tiid (Kwajalein)',
@@ -426,6 +429,7 @@ return [
         'Pacific/Palau' => 'Belause tiid (Palau)',
         'Pacific/Pitcairn' => 'Pitcairneillânske tiid',
         'Pacific/Ponape' => 'Pohnpei tiid',
+        'Pacific/Pohnpei' => 'Pohnpei tiid',
         'Pacific/Port_Moresby' => 'Papoea-Nij-Guineeske tiid (Port Moresby)',
         'Pacific/Rarotonga' => 'Cookeilânse tiid (Rarotonga)',
         'Pacific/Saipan' => 'Chamorro-tiid (Saipan)',
@@ -433,9 +437,9 @@ return [
         'Pacific/Tarawa' => 'Gilberteilânske tiid (Tarawa)',
         'Pacific/Tongatapu' => 'Tongaanske tiid (Tongatapu)',
         'Pacific/Truk' => 'Chuukse tiid',
+        'Pacific/Chuuk' => 'Chuukse tiid',
         'Pacific/Wake' => 'Wake-eilânske tiid',
-        'Pacific/Wallis' => 'Wallis en Futunase tiid',
-    ],
-    'Meta' => [
+        'Pacific/Wallis' => 'Wallis en Futunase tiid (Wallis & Futuna)',
     ],
+    'Meta' => [],
 ];
