@@ -343,7 +343,7 @@ return [
         'Europe/Busingen' => 'مرکزی یوٗرپی ٹایِم (بوسِنگین)',
         'Europe/Chisinau' => 'مشرقی یوٗرپی ٹایِم (چِسیٖنو)',
         'Europe/Copenhagen' => 'مرکزی یوٗرپی ٹایِم (کوپن ہیگن)',
-        'Europe/Dublin' => 'گریٖن وِچ میٖن ٹایِم (ڈَبلِن)',
+        'Europe/Dublin' => 'اَیَرلینڑ وَکھ (ڈَبلِن)',
         'Europe/Gibraltar' => 'مرکزی یوٗرپی ٹایِم (گِبرالٹَر)',
         'Europe/Guernsey' => 'گریٖن وِچ میٖن ٹایِم (گویرنسے)',
         'Europe/Helsinki' => 'مشرقی یوٗرپی ٹایِم (حؠلسِنکی)',
