@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'Чыгыш Африка убактысы (Аддис-Абеба)',
         'Africa/Algiers' => 'Борбордук Европа убактысы (Алжир)',
         'Africa/Asmera' => 'Чыгыш Африка убактысы (Асмара)',
+        'Africa/Asmara' => 'Чыгыш Африка убактысы (Асмара)',
         'Africa/Bamako' => 'Гринвич боюнча орточо убакыт (Бамако)',
         'Africa/Bangui' => 'Батыш Африка убактысы (Баги)',
         'Africa/Banjul' => 'Гринвич боюнча орточо убакыт (Банжул)',
@@ -78,19 +79,24 @@ return [
         'America/Bogota' => 'Колумбия убактысы (Богота)',
         'America/Boise' => 'Түндүк Америка, тоо убактысы (Бойсе)',
         'America/Buenos_Aires' => 'Аргентина убактысы (Буэнос-Айрес)',
+        'America/Argentina/Buenos_Aires' => 'Аргентина убактысы (Буэнос-Айрес)',
         'America/Cambridge_Bay' => 'Түндүк Америка, тоо убактысы (Кэмбриж Бей)',
         'America/Campo_Grande' => 'Амазон убактысы (Кампо Гранде)',
         'America/Cancun' => 'Түндүк Америка, чыгыш убактысы (Канкун)',
         'America/Caracas' => 'Венесуэла убактысы (Каракас)',
         'America/Catamarca' => 'Аргентина убактысы (Катамарка)',
+        'America/Argentina/Catamarca' => 'Аргентина убактысы (Катамарка)',
         'America/Cayenne' => 'Француз Гвиана убактысы (Кайен)',
         'America/Cayman' => 'Түндүк Америка, чыгыш убактысы (Кайман)',
         'America/Chicago' => 'Түндүк Америка, борбордук убакыт (Чикаго)',
         'America/Chihuahua' => 'Түндүк Америка, борбордук убакыт (Чихуахуа)',
         'America/Ciudad_Juarez' => 'Түндүк Америка, тоо убактысы (Сьюдад-Хуарес)',
         'America/Coral_Harbour' => 'Түндүк Америка, чыгыш убактысы (Атикокан)',
+        'America/Atikokan' => 'Түндүк Америка, чыгыш убактысы (Атикокан)',
         'America/Cordoba' => 'Аргентина убактысы (Кордова)',
+        'America/Argentina/Cordoba' => 'Аргентина убактысы (Кордова)',
         'America/Costa_Rica' => 'Түндүк Америка, борбордук убакыт (Коста-Рика)',
+        'America/Coyhaique' => 'Чили убактысы (Койайке)',
         'America/Creston' => 'Түндүк Америка, тоо убактысы (Крестон)',
         'America/Cuiaba' => 'Амазон убактысы (Куйаба)',
         'America/Curacao' => 'Атлантика убактысы (Кюрасао)',
@@ -106,7 +112,8 @@ return [
         'America/Fort_Nelson' => 'Түндүк Америка, тоо убактысы (Форт Нельсон)',
         'America/Fortaleza' => 'Бразилия убактысы (Форталеза)',
         'America/Glace_Bay' => 'Атлантика убактысы (Глейс Бей)',
-        'America/Godthab' => 'Батыш Гренландия убактысы (Нуук)',
+        'America/Godthab' => 'Гренландия убактысы (Нуук)',
+        'America/Nuuk' => 'Гренландия убактысы (Нуук)',
         'America/Goose_Bay' => 'Атлантика убактысы (Гус Бей)',
         'America/Grand_Turk' => 'Түндүк Америка, чыгыш убактысы (Гранд Түрк)',
         'America/Grenada' => 'Атлантика убактысы (Гренада)',
@@ -125,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'Түндүк Америка, чыгыш убактысы (Винсен, Индиана)',
         'America/Indiana/Winamac' => 'Түндүк Америка, чыгыш убактысы (Уинамак, Индиана)',
         'America/Indianapolis' => 'Түндүк Америка, чыгыш убактысы (Индианаполис)',
+        'America/Indiana/Indianapolis' => 'Түндүк Америка, чыгыш убактысы (Индианаполис)',
         'America/Inuvik' => 'Түндүк Америка, тоо убактысы (Инувик)',
         'America/Iqaluit' => 'Түндүк Америка, чыгыш убактысы (Икалуит)',
         'America/Jamaica' => 'Түндүк Америка, чыгыш убактысы (Ямайка)',
         'America/Jujuy' => 'Аргентина убактысы (Жужуй)',
+        'America/Argentina/Jujuy' => 'Аргентина убактысы (Жужуй)',
         'America/Juneau' => 'Аляска убактысы (Жуно)',
         'America/Kentucky/Monticello' => 'Түндүк Америка, чыгыш убактысы (Монтичелло, Кентукки)',
         'America/Kralendijk' => 'Атлантика убактысы (Кралендейк)',
@@ -136,6 +145,7 @@ return [
         'America/Lima' => 'Перу убактысы (Лима)',
         'America/Los_Angeles' => 'Түндүк Америка, Тынч океан убактысы (Лос-Анжелес)',
         'America/Louisville' => 'Түндүк Америка, чыгыш убактысы (Луизвилл)',
+        'America/Kentucky/Louisville' => 'Түндүк Америка, чыгыш убактысы (Луизвилл)',
         'America/Lower_Princes' => 'Атлантика убактысы (Лоуэр Принсес Куате)',
         'America/Maceio' => 'Бразилия убактысы (Масейо)',
         'America/Managua' => 'Түндүк Америка, борбордук убакыт (Манагуа)',
@@ -145,6 +155,7 @@ return [
         'America/Matamoros' => 'Түндүк Америка, борбордук убакыт (Матаморос)',
         'America/Mazatlan' => 'Мексика, Тынч океан убактысы (Мазатлан)',
         'America/Mendoza' => 'Аргентина убактысы (Мендоза)',
+        'America/Argentina/Mendoza' => 'Аргентина убактысы (Мендоза)',
         'America/Menominee' => 'Түндүк Америка, борбордук убакыт (Меномини)',
         'America/Merida' => 'Түндүк Америка, борбордук убакыт (Мерида)',
         'America/Metlakatla' => 'Аляска убактысы (Метлакатла)',
@@ -156,7 +167,6 @@ return [
         'America/Montserrat' => 'Атлантика убактысы (Монсерат)',
         'America/Nassau' => 'Түндүк Америка, чыгыш убактысы (Нассау)',
         'America/New_York' => 'Түндүк Америка, чыгыш убактысы (Нью-Йорк)',
-        'America/Nipigon' => 'Түндүк Америка, чыгыш убактысы (Нипигон)',
         'America/Nome' => 'Аляска убактысы (Ном)',
         'America/Noronha' => 'Фернандо де Норонья убактысы (Норониа)',
         'America/North_Dakota/Beulah' => 'Түндүк Америка, борбордук убакыт (Беула, Түндүк Дакота)',
@@ -164,7 +174,6 @@ return [
         'America/North_Dakota/New_Salem' => 'Түндүк Америка, борбордук убакыт (Нью-Салем, Түндүк Дакота)',
         'America/Ojinaga' => 'Түндүк Америка, борбордук убакыт (Охинага)',
         'America/Panama' => 'Түндүк Америка, чыгыш убактысы (Панама)',
-        'America/Pangnirtung' => 'Түндүк Америка, чыгыш убактысы (Пангиртуң)',
         'America/Paramaribo' => 'Суринаме убактысы (Парамарибо)',
         'America/Phoenix' => 'Түндүк Америка, тоо убактысы (Феникс)',
         'America/Port-au-Prince' => 'Түндүк Америка, чыгыш убактысы (Порт-о-Пренс)',
@@ -172,18 +181,16 @@ return [
         'America/Porto_Velho' => 'Амазон убактысы (Порто Велио)',
         'America/Puerto_Rico' => 'Атлантика убактысы (Пуэрто-Рико)',
         'America/Punta_Arenas' => 'Чили убактысы (Пунта-Аренас)',
-        'America/Rainy_River' => 'Түндүк Америка, борбордук убакыт (Рейни Ривер)',
         'America/Rankin_Inlet' => 'Түндүк Америка, борбордук убакыт (Рэнкин Инлет)',
         'America/Recife' => 'Бразилия убактысы (Ресифи)',
         'America/Regina' => 'Түндүк Америка, борбордук убакыт (Регина)',
         'America/Resolute' => 'Түндүк Америка, борбордук убакыт (Резолут)',
         'America/Rio_Branco' => 'Бразилия убактысы (Рио Бранко)',
-        'America/Santa_Isabel' => 'Түндүк-чыгыш Мексика убактысы (Санта Изабел)',
         'America/Santarem' => 'Бразилия убактысы (Сантарем)',
         'America/Santiago' => 'Чили убактысы (Сантиаго)',
         'America/Santo_Domingo' => 'Атлантика убактысы (Санто Доминго)',
         'America/Sao_Paulo' => 'Бразилия убактысы (Сао Пауло)',
-        'America/Scoresbysund' => 'Чыгыш Гренландия убактысы (Иттоккортоормиит)',
+        'America/Scoresbysund' => 'Гренландия убактысы (Иттоккортоормиит)',
         'America/Sitka' => 'Аляска убактысы (Ситка)',
         'America/St_Barthelemy' => 'Атлантика убактысы (Сент-Бартелеми)',
         'America/St_Johns' => 'Нюфаундлэнд убактысы (Сент Жонс)',
@@ -194,7 +201,6 @@ return [
         'America/Swift_Current' => 'Түндүк Америка, борбордук убакыт (Свифт Каррент)',
         'America/Tegucigalpa' => 'Түндүк Америка, борбордук убакыт (Тегусигальпа)',
         'America/Thule' => 'Атлантика убактысы (Туле)',
-        'America/Thunder_Bay' => 'Түндүк Америка, чыгыш убактысы (Сандер Бей)',
         'America/Tijuana' => 'Түндүк Америка, Тынч океан убактысы (Тихуана)',
         'America/Toronto' => 'Түндүк Америка, чыгыш убактысы (Торонто)',
         'America/Tortola' => 'Атлантика убактысы (Тортола)',
@@ -202,8 +208,7 @@ return [
         'America/Whitehorse' => 'Юкон убактысы (Уайтхорс)',
         'America/Winnipeg' => 'Түндүк Америка, борбордук убакыт (Уиннипег)',
         'America/Yakutat' => 'Аляска убактысы (Якутат)',
-        'America/Yellowknife' => 'Түндүк Америка, тоо убактысы (Йеллоунайф)',
-        'Antarctica/Casey' => 'Антарктида убактысы (Кейси)',
+        'Antarctica/Casey' => 'Австралия батыш убактысы (Кейси)',
         'Antarctica/Davis' => 'Дэвис убактысы',
         'Antarctica/DumontDUrville' => 'Дюмон-д-Урвил убактысы',
         'Antarctica/Macquarie' => 'Австралия чыгыш убактысы (Маккуори)',
@@ -216,24 +221,24 @@ return [
         'Antarctica/Vostok' => 'Восток убактысы',
         'Arctic/Longyearbyen' => 'Борбордук Европа убактысы (Лонгйербиен)',
         'Asia/Aden' => 'Арабия убактысы (Аден)',
-        'Asia/Almaty' => 'Чыгыш Казакстан убактысы (Алматы)',
+        'Asia/Almaty' => 'Казакстан убактысы (Алматы)',
         'Asia/Amman' => 'Чыгыш Европа убактысы (Амман)',
         'Asia/Anadyr' => 'Россия убактысы (Анадыр)',
-        'Asia/Aqtau' => 'Батыш Казакстан убактысы (Актау)',
-        'Asia/Aqtobe' => 'Батыш Казакстан убактысы (Актобе)',
+        'Asia/Aqtau' => 'Казакстан убактысы (Актау)',
+        'Asia/Aqtobe' => 'Казакстан убактысы (Актобе)',
         'Asia/Ashgabat' => 'Түркмөнстан убактысы (Ашхабад)',
-        'Asia/Atyrau' => 'Батыш Казакстан убактысы (Атырау)',
+        'Asia/Atyrau' => 'Казакстан убактысы (Атырау)',
         'Asia/Baghdad' => 'Арабия убактысы (Багдад)',
         'Asia/Bahrain' => 'Арабия убактысы (Бахрейн)',
         'Asia/Baku' => 'Азербайжан убактысы (Баку)',
         'Asia/Bangkok' => 'Индокытай убактысы (Бангкок)',
-        'Asia/Barnaul' => 'Россия убактысы (Барнаул)',
+        'Asia/Barnaul' => 'Красноярск убактысы (Барнаул)',
         'Asia/Beirut' => 'Чыгыш Европа убактысы (Бейрут)',
         'Asia/Bishkek' => 'Кыргызстан убактысы (Бишкек)',
         'Asia/Brunei' => 'Бруней Даруссалам убактысы',
         'Asia/Calcutta' => 'Индия убактысы (Калькутта)',
+        'Asia/Kolkata' => 'Индия убактысы (Калькутта)',
         'Asia/Chita' => 'Якутск убактысы (Чита)',
-        'Asia/Choibalsan' => 'Улан Батор убактысы (Чойбалсан)',
         'Asia/Colombo' => 'Индия убактысы (Коломбо)',
         'Asia/Damascus' => 'Чыгыш Европа убактысы (Дамаск)',
         'Asia/Dhaka' => 'Бангладеш убактысы (Дакка)',
@@ -253,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'Россия убактысы (Камчатка)',
         'Asia/Karachi' => 'Пакистан убактысы (Карачи)',
         'Asia/Katmandu' => 'Непал убактысы (Катманду)',
+        'Asia/Kathmandu' => 'Непал убактысы (Катманду)',
         'Asia/Khandyga' => 'Якутск убактысы (Кандыга)',
         'Asia/Krasnoyarsk' => 'Красноярск убактысы',
         'Asia/Kuala_Lumpur' => 'Малайзия убактысы (Куала Лумпур)',
@@ -265,19 +271,21 @@ return [
         'Asia/Muscat' => 'Булуңдун стандарттык убакыты (Мускат)',
         'Asia/Nicosia' => 'Чыгыш Европа убактысы (Никосия)',
         'Asia/Novokuznetsk' => 'Красноярск убактысы (Новокузнецк)',
-        'Asia/Novosibirsk' => 'Новосибирск убактысы',
+        'Asia/Novosibirsk' => 'Красноярск убактысы (Новосибирск)',
         'Asia/Omsk' => 'Омск убактысы',
-        'Asia/Oral' => 'Батыш Казакстан убактысы (Орал)',
+        'Asia/Oral' => 'Казакстан убактысы (Орал)',
         'Asia/Phnom_Penh' => 'Индокытай убактысы (Пномпень)',
         'Asia/Pontianak' => 'Батыш Индонезия убактысы (Понтианак)',
         'Asia/Pyongyang' => 'Корея убактысы (Пхеньян)',
         'Asia/Qatar' => 'Арабия убактысы (Катар)',
-        'Asia/Qostanay' => 'Чыгыш Казакстан убактысы (Костанай)',
-        'Asia/Qyzylorda' => 'Батыш Казакстан убактысы (Кызылорда)',
+        'Asia/Qostanay' => 'Казакстан убактысы (Костанай)',
+        'Asia/Qyzylorda' => 'Казакстан убактысы (Кызылорда)',
         'Asia/Rangoon' => 'Мйанмар убактысы (Рангун)',
+        'Asia/Yangon' => 'Мйанмар убактысы (Рангун)',
         'Asia/Riyadh' => 'Арабия убактысы (Рийад)',
         'Asia/Saigon' => 'Индокытай убактысы (Хо Ши Мин)',
-        'Asia/Sakhalin' => 'Сахалин убактысы',
+        'Asia/Ho_Chi_Minh' => 'Индокытай убактысы (Хо Ши Мин)',
+        'Asia/Sakhalin' => 'Магадан убактысы (Сахалин)',
         'Asia/Samarkand' => 'Өзбекстан убактысы (Самарканд)',
         'Asia/Seoul' => 'Корея убактысы (Сеул)',
         'Asia/Shanghai' => 'Кытай убактысы (Шанхай)',
@@ -289,7 +297,7 @@ return [
         'Asia/Tehran' => 'Иран убактысы (Тегеран)',
         'Asia/Thimphu' => 'Бутан убактысы (Тимпу)',
         'Asia/Tokyo' => 'Жапон убактысы (Токио)',
-        'Asia/Tomsk' => 'Россия убактысы (Томск)',
+        'Asia/Tomsk' => 'Красноярск убактысы (Томск)',
         'Asia/Ulaanbaatar' => 'Улан Батор убактысы',
         'Asia/Urumqi' => 'Кытай убактысы (Үрүмчү)',
         'Asia/Ust-Nera' => 'Владивосток убактысы (Усть-Нера)',
@@ -303,6 +311,7 @@ return [
         'Atlantic/Canary' => 'Батыш Европа убактысы (Канари)',
         'Atlantic/Cape_Verde' => 'Капе Верде убактысы',
         'Atlantic/Faeroe' => 'Батыш Европа убактысы (Фарер)',
+        'Atlantic/Faroe' => 'Батыш Европа убактысы (Фарер)',
         'Atlantic/Madeira' => 'Батыш Европа убактысы (Мадейра)',
         'Atlantic/Reykjavik' => 'Гринвич боюнча орточо убакыт (Рейкьявик)',
         'Atlantic/South_Georgia' => 'Түштүк Жоржия убактысы',
@@ -311,7 +320,6 @@ return [
         'Australia/Adelaide' => 'Австралия борбордук убактысы (Аделаида)',
         'Australia/Brisbane' => 'Австралия чыгыш убактысы (Брисбен)',
         'Australia/Broken_Hill' => 'Австралия борбордук убактысы (Броукен Хил)',
-        'Australia/Currie' => 'Австралия чыгыш убактысы (Керри)',
         'Australia/Darwin' => 'Австралия борбордук убактысы (Дарвин)',
         'Australia/Eucla' => 'Австралия борбордук батыш убактысы (Юкла)',
         'Australia/Hobart' => 'Австралия чыгыш убактысы (Хобарт)',
@@ -320,13 +328,11 @@ return [
         'Australia/Melbourne' => 'Австралия чыгыш убактысы (Мельбурн)',
         'Australia/Perth' => 'Австралия батыш убактысы (Перт)',
         'Australia/Sydney' => 'Австралия чыгыш убактысы (Сидней)',
-        'CST6CDT' => 'Түндүк Америка, борбордук убакыт',
-        'EST5EDT' => 'Түндүк Америка, чыгыш убактысы',
         'Etc/GMT' => 'Гринвич боюнча орточо убакыт',
         'Etc/UTC' => 'Бирдиктүү дүйнөлүк убакыт',
         'Europe/Amsterdam' => 'Борбордук Европа убактысы (Амстердам)',
         'Europe/Andorra' => 'Борбордук Европа убактысы (Андорра)',
-        'Europe/Astrakhan' => 'Москва убактысы (Астрахань)',
+        'Europe/Astrakhan' => 'Россия убактысы (Астрахань)',
         'Europe/Athens' => 'Чыгыш Европа убактысы (Афины)',
         'Europe/Belgrade' => 'Борбордук Европа убактысы (Белград)',
         'Europe/Berlin' => 'Борбордук Европа убактысы (Берлин)',
@@ -337,7 +343,7 @@ return [
         'Europe/Busingen' => 'Борбордук Европа убактысы (Бузинген)',
         'Europe/Chisinau' => 'Чыгыш Европа убактысы (Кишинев)',
         'Europe/Copenhagen' => 'Борбордук Европа убактысы (Копенгаген)',
-        'Europe/Dublin' => 'Гринвич боюнча орточо убакыт (Дублин)',
+        'Europe/Dublin' => 'Ирландия убактысы (Дублин)',
         'Europe/Gibraltar' => 'Борбордук Европа убактысы (Гибралтар)',
         'Europe/Guernsey' => 'Гринвич боюнча орточо убакыт (Гернси)',
         'Europe/Helsinki' => 'Чыгыш Европа убактысы (Хельсинки)',
@@ -346,7 +352,8 @@ return [
         'Europe/Jersey' => 'Гринвич боюнча орточо убакыт (Жерси)',
         'Europe/Kaliningrad' => 'Чыгыш Европа убактысы (Калининград)',
         'Europe/Kiev' => 'Чыгыш Европа убактысы (Киев)',
-        'Europe/Kirov' => 'Россия убактысы (Киров)',
+        'Europe/Kyiv' => 'Чыгыш Европа убактысы (Киев)',
+        'Europe/Kirov' => 'Москва убактысы (Киров)',
         'Europe/Lisbon' => 'Батыш Европа убактысы (Лиссабон)',
         'Europe/Ljubljana' => 'Борбордук Европа убактысы (Любляна)',
         'Europe/London' => 'Гринвич боюнча орточо убакыт (Лондон)',
@@ -366,23 +373,21 @@ return [
         'Europe/Samara' => 'Россия убактысы (Самара)',
         'Europe/San_Marino' => 'Борбордук Европа убактысы (Сан Марино)',
         'Europe/Sarajevo' => 'Борбордук Европа убактысы (Сараево)',
-        'Europe/Saratov' => 'Москва убактысы (Саратов)',
+        'Europe/Saratov' => 'Россия убактысы (Саратов)',
         'Europe/Simferopol' => 'Москва убактысы (Симферополь)',
         'Europe/Skopje' => 'Борбордук Европа убактысы (Скопйе)',
         'Europe/Sofia' => 'Чыгыш Европа убактысы (София)',
         'Europe/Stockholm' => 'Борбордук Европа убактысы (Стокгольм)',
         'Europe/Tallinn' => 'Чыгыш Европа убактысы (Таллин)',
         'Europe/Tirane' => 'Борбордук Европа убактысы (Тирана)',
-        'Europe/Ulyanovsk' => 'Москва убактысы (Ульяновск)',
-        'Europe/Uzhgorod' => 'Чыгыш Европа убактысы (Ужгород)',
+        'Europe/Ulyanovsk' => 'Россия убактысы (Ульяновск)',
         'Europe/Vaduz' => 'Борбордук Европа убактысы (Фадуц)',
         'Europe/Vatican' => 'Борбордук Европа убактысы (Ватикан)',
         'Europe/Vienna' => 'Борбордук Европа убактысы (Вена)',
         'Europe/Vilnius' => 'Чыгыш Европа убактысы (Вильнюс)',
-        'Europe/Volgograd' => 'Волгоград убактысы',
+        'Europe/Volgograd' => 'Москва убактысы (Волгоград)',
         'Europe/Warsaw' => 'Борбордук Европа убактысы (Варшава)',
         'Europe/Zagreb' => 'Борбордук Европа убактысы (Загреб)',
-        'Europe/Zaporozhye' => 'Чыгыш Европа убактысы (Запорожье)',
         'Europe/Zurich' => 'Борбордук Европа убактысы (Цюрих)',
         'Indian/Antananarivo' => 'Чыгыш Африка убактысы (Антананариво)',
         'Indian/Chagos' => 'Инди океан убактысы (Чагос)',
@@ -395,15 +400,14 @@ return [
         'Indian/Mauritius' => 'Маврикий убактысы',
         'Indian/Mayotte' => 'Чыгыш Африка убактысы (Майотт)',
         'Indian/Reunion' => 'Реюнион убактысы',
-        'MST7MDT' => 'Түндүк Америка, тоо убактысы',
-        'PST8PDT' => 'Түндүк Америка, Тынч океан убактысы',
         'Pacific/Apia' => 'Апиа убактысы',
         'Pacific/Auckland' => 'Жаңы Зеландия убактысы (Оклэнд)',
         'Pacific/Bougainville' => 'Папуа-Жаңы Гвинея убакыты (Бугенвиль)',
         'Pacific/Chatham' => 'Чатам убактысы (Чатем)',
         'Pacific/Easter' => 'Истер аралынын убактысы',
         'Pacific/Efate' => 'Вануату убактысы (Эфат)',
-        'Pacific/Enderbury' => 'Феникс аралдарынын убактысы (Эндербери)',
+        'Pacific/Enderbury' => 'Феникс аралдарынын убактысы (Кантон)',
+        'Pacific/Kanton' => 'Феникс аралдарынын убактысы (Кантон)',
         'Pacific/Fakaofo' => 'Токелау убактысы (Факаофо)',
         'Pacific/Fiji' => 'Фижи убактысы',
         'Pacific/Funafuti' => 'Тувалу убактысы (Фунафути)',
@@ -411,8 +415,7 @@ return [
         'Pacific/Gambier' => 'Гамбие убактысы',
         'Pacific/Guadalcanal' => 'Соломон аралдарынын убактысы (Гуадалканал)',
         'Pacific/Guam' => 'Чаморро убактысы (Гуам)',
-        'Pacific/Honolulu' => 'Гавайи-Алеут убактысы (Гонолулу)',
-        'Pacific/Johnston' => 'Гавайи-Алеут убактысы (Жонстон)',
+        'Pacific/Honolulu' => 'Гавайи-Алеут кышкы убактысы (Гонолулу)',
         'Pacific/Kiritimati' => 'Лайн аралдарынын убактысы (Киритимати)',
         'Pacific/Kosrae' => 'Косрае убактысы (Козрае)',
         'Pacific/Kwajalein' => 'Маршалл аралдарынын убактысы (Куажалейн)',
@@ -427,6 +430,7 @@ return [
         'Pacific/Palau' => 'Палау убактысы',
         'Pacific/Pitcairn' => 'Питкэрнг убактысы',
         'Pacific/Ponape' => 'Понапе убактысы (Понпей)',
+        'Pacific/Pohnpei' => 'Понапе убактысы (Понпей)',
         'Pacific/Port_Moresby' => 'Папуа-Жаңы Гвинея убакыты (Порт Моэрсби)',
         'Pacific/Rarotonga' => 'Кук аралдарынын убактысы (Раготонга)',
         'Pacific/Saipan' => 'Чаморро убактысы (Сайпан)',
@@ -434,9 +438,9 @@ return [
         'Pacific/Tarawa' => 'Гилберт убактысы (Тарава)',
         'Pacific/Tongatapu' => 'Тонга убактысы (Тонгатапу)',
         'Pacific/Truk' => 'Чуук убактысы',
+        'Pacific/Chuuk' => 'Чуук убактысы',
         'Pacific/Wake' => 'Уейк аралдарынын убактысы',
         'Pacific/Wallis' => 'Уолис жана Футуна убактысы',
     ],
-    'Meta' => [
-    ],
+    'Meta' => [],
 ];
