@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'Rytų Afrikos laikas (Adis Abeba)',
         'Africa/Algiers' => 'Vidurio Europos laikas (Alžyras)',
         'Africa/Asmera' => 'Rytų Afrikos laikas (Asmara)',
+        'Africa/Asmara' => 'Rytų Afrikos laikas (Asmara)',
         'Africa/Bamako' => 'Grinvičo laikas (Bamakas)',
         'Africa/Bangui' => 'Vakarų Afrikos laikas (Bangis)',
         'Africa/Banjul' => 'Grinvičo laikas (Bandžulis)',
@@ -75,22 +76,27 @@ return [
         'America/Belize' => 'Šiaurės Amerikos centro laikas (Belizas)',
         'America/Blanc-Sablon' => 'Atlanto laikas (Blanč Sablonas)',
         'America/Boa_Vista' => 'Amazonės laikas (Bua Vista)',
-        'America/Bogota' => 'Kolumbijos laikas (Bogota)',
+        'America/Bogota' => 'Kolumbijos laikas (Bogotá)',
         'America/Boise' => 'Šiaurės Amerikos kalnų laikas (Boisis)',
         'America/Buenos_Aires' => 'Argentinos laikas (Buenos Airės)',
+        'America/Argentina/Buenos_Aires' => 'Argentinos laikas (Buenos Airės)',
         'America/Cambridge_Bay' => 'Šiaurės Amerikos kalnų laikas (Keimbridž Bėjus)',
         'America/Campo_Grande' => 'Amazonės laikas (Kampo Grandė)',
         'America/Cancun' => 'Šiaurės Amerikos rytų laikas (Kankūnas)',
         'America/Caracas' => 'Venesuelos laikas (Karakasas)',
         'America/Catamarca' => 'Argentinos laikas (Katamarka)',
+        'America/Argentina/Catamarca' => 'Argentinos laikas (Katamarka)',
         'America/Cayenne' => 'Prancūzijos Gvianos laikas (Kajenas)',
         'America/Cayman' => 'Šiaurės Amerikos rytų laikas (Kaimanas)',
         'America/Chicago' => 'Šiaurės Amerikos centro laikas (Čikaga)',
         'America/Chihuahua' => 'Šiaurės Amerikos centro laikas (Čihuahua)',
         'America/Ciudad_Juarez' => 'Šiaurės Amerikos kalnų laikas (Siudad Chuaresas)',
         'America/Coral_Harbour' => 'Šiaurės Amerikos rytų laikas (Atikokanas)',
+        'America/Atikokan' => 'Šiaurės Amerikos rytų laikas (Atikokanas)',
         'America/Cordoba' => 'Argentinos laikas (Kordoba)',
+        'America/Argentina/Cordoba' => 'Argentinos laikas (Kordoba)',
         'America/Costa_Rica' => 'Šiaurės Amerikos centro laikas (Kosta Rika)',
+        'America/Coyhaique' => 'Čilės laikas (Kojhaikė)',
         'America/Creston' => 'Šiaurės Amerikos kalnų laikas (Krestonas)',
         'America/Cuiaba' => 'Amazonės laikas (Kujaba)',
         'America/Curacao' => 'Atlanto laikas (Kiurasao)',
@@ -106,7 +112,8 @@ return [
         'America/Fort_Nelson' => 'Šiaurės Amerikos kalnų laikas (Fort Nelsonas)',
         'America/Fortaleza' => 'Brazilijos laikas (Fortaleza)',
         'America/Glace_Bay' => 'Atlanto laikas (Gleis Bėjus)',
-        'America/Godthab' => 'Grenlandijos vakarų laikas (Nūkas)',
+        'America/Godthab' => 'Laikas: Grenlandija (Nūkas)',
+        'America/Nuuk' => 'Laikas: Grenlandija (Nūkas)',
         'America/Goose_Bay' => 'Atlanto laikas (Gus Bėjus)',
         'America/Grand_Turk' => 'Šiaurės Amerikos rytų laikas (Grand Terkas)',
         'America/Grenada' => 'Atlanto laikas (Grenada)',
@@ -125,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'Šiaurės Amerikos rytų laikas (Vinsenas, Indiana)',
         'America/Indiana/Winamac' => 'Šiaurės Amerikos rytų laikas (Vinamakas, Indiana)',
         'America/Indianapolis' => 'Šiaurės Amerikos rytų laikas (Indianapolis)',
+        'America/Indiana/Indianapolis' => 'Šiaurės Amerikos rytų laikas (Indianapolis)',
         'America/Inuvik' => 'Šiaurės Amerikos kalnų laikas (Inuvikas)',
         'America/Iqaluit' => 'Šiaurės Amerikos rytų laikas (Ikaluitas)',
         'America/Jamaica' => 'Šiaurės Amerikos rytų laikas (Jamaika)',
         'America/Jujuy' => 'Argentinos laikas (Chuchujus)',
+        'America/Argentina/Jujuy' => 'Argentinos laikas (Chuchujus)',
         'America/Juneau' => 'Aliaskos laikas (Džunas)',
         'America/Kentucky/Monticello' => 'Šiaurės Amerikos rytų laikas (Montiselas, Kentukis)',
         'America/Kralendijk' => 'Atlanto laikas (Kralendeikas)',
@@ -136,6 +145,7 @@ return [
         'America/Lima' => 'Peru laikas (Lima)',
         'America/Los_Angeles' => 'Šiaurės Amerikos Ramiojo vandenyno laikas (Los Andželas)',
         'America/Louisville' => 'Šiaurės Amerikos rytų laikas (Luisvilis)',
+        'America/Kentucky/Louisville' => 'Šiaurės Amerikos rytų laikas (Luisvilis)',
         'America/Lower_Princes' => 'Atlanto laikas (Žemutinis Prinses Kvorteris)',
         'America/Maceio' => 'Brazilijos laikas (Masejo)',
         'America/Managua' => 'Šiaurės Amerikos centro laikas (Managva)',
@@ -145,6 +155,7 @@ return [
         'America/Matamoros' => 'Šiaurės Amerikos centro laikas (Matamorosas)',
         'America/Mazatlan' => 'Meksikos Ramiojo vandenyno laikas (Masatlanas)',
         'America/Mendoza' => 'Argentinos laikas (Mendosa)',
+        'America/Argentina/Mendoza' => 'Argentinos laikas (Mendosa)',
         'America/Menominee' => 'Šiaurės Amerikos centro laikas (Menominis)',
         'America/Merida' => 'Šiaurės Amerikos centro laikas (Merida)',
         'America/Metlakatla' => 'Aliaskos laikas (Metlakatla)',
@@ -156,7 +167,6 @@ return [
         'America/Montserrat' => 'Atlanto laikas (Montseratas)',
         'America/Nassau' => 'Šiaurės Amerikos rytų laikas (Nasau)',
         'America/New_York' => 'Šiaurės Amerikos rytų laikas (Niujorkas)',
-        'America/Nipigon' => 'Šiaurės Amerikos rytų laikas (Nipigonas)',
         'America/Nome' => 'Aliaskos laikas (Nomas)',
         'America/Noronha' => 'Fernando de Noronjos laikas (Noronja)',
         'America/North_Dakota/Beulah' => 'Šiaurės Amerikos centro laikas (Bjula, Šiaurės Dakota)',
@@ -164,7 +174,6 @@ return [
         'America/North_Dakota/New_Salem' => 'Šiaurės Amerikos centro laikas (Niu Seilemas, Šiaurės Dakota)',
         'America/Ojinaga' => 'Šiaurės Amerikos centro laikas (Ochinaga)',
         'America/Panama' => 'Šiaurės Amerikos rytų laikas (Panama)',
-        'America/Pangnirtung' => 'Šiaurės Amerikos rytų laikas (Pangnirtungas)',
         'America/Paramaribo' => 'Surinamo laikas (Paramaribas)',
         'America/Phoenix' => 'Šiaurės Amerikos kalnų laikas (Finiksas)',
         'America/Port-au-Prince' => 'Šiaurės Amerikos rytų laikas (Port o Prensas)',
@@ -172,18 +181,16 @@ return [
         'America/Porto_Velho' => 'Amazonės laikas (Porto Veljas)',
         'America/Puerto_Rico' => 'Atlanto laikas (Puerto Rikas)',
         'America/Punta_Arenas' => 'Čilės laikas (Punta Arenasas)',
-        'America/Rainy_River' => 'Šiaurės Amerikos centro laikas (Reini Riveris)',
         'America/Rankin_Inlet' => 'Šiaurės Amerikos centro laikas (Rankin Inletas)',
         'America/Recife' => 'Brazilijos laikas (Resifė)',
         'America/Regina' => 'Šiaurės Amerikos centro laikas (Redžina)',
         'America/Resolute' => 'Šiaurės Amerikos centro laikas (Resolutas)',
         'America/Rio_Branco' => 'Ako laikas (Rio Brankas)',
-        'America/Santa_Isabel' => 'Šiaurės Vakarų Meksikos laikas (Santa Izabelė)',
         'America/Santarem' => 'Brazilijos laikas (Santarenas)',
         'America/Santiago' => 'Čilės laikas (Santjagas)',
         'America/Santo_Domingo' => 'Atlanto laikas (Santo Domingas)',
         'America/Sao_Paulo' => 'Brazilijos laikas (San Paulas)',
-        'America/Scoresbysund' => 'Grenlandijos rytų laikas (Itokortormitas)',
+        'America/Scoresbysund' => 'Laikas: Grenlandija (Itokortormitas)',
         'America/Sitka' => 'Aliaskos laikas (Sitka)',
         'America/St_Barthelemy' => 'Atlanto laikas (Sen Bartelemi)',
         'America/St_Johns' => 'Niufaundlendo laikas (Sent Džonsas)',
@@ -194,7 +201,6 @@ return [
         'America/Swift_Current' => 'Šiaurės Amerikos centro laikas (Svift Karentas)',
         'America/Tegucigalpa' => 'Šiaurės Amerikos centro laikas (Tegusigalpa)',
         'America/Thule' => 'Atlanto laikas (Kanakas)',
-        'America/Thunder_Bay' => 'Šiaurės Amerikos rytų laikas (Tander Bėjus)',
         'America/Tijuana' => 'Šiaurės Amerikos Ramiojo vandenyno laikas (Tichuana)',
         'America/Toronto' => 'Šiaurės Amerikos rytų laikas (Torontas)',
         'America/Tortola' => 'Atlanto laikas (Tortola)',
@@ -202,8 +208,7 @@ return [
         'America/Whitehorse' => 'Jukono laikas (Vaithorsas)',
         'America/Winnipeg' => 'Šiaurės Amerikos centro laikas (Vinipegas)',
         'America/Yakutat' => 'Aliaskos laikas (Jakutatas)',
-        'America/Yellowknife' => 'Šiaurės Amerikos kalnų laikas (Jelounaifas)',
-        'Antarctica/Casey' => 'Keisio laikas (Keisis)',
+        'Antarctica/Casey' => 'Vakarų Australijos laikas (Keisis)',
         'Antarctica/Davis' => 'Deiviso laikas (Deivisas)',
         'Antarctica/DumontDUrville' => 'Diumono d’Urvilio laikas (Diumonas d’Urvilis)',
         'Antarctica/Macquarie' => 'Rytų Australijos laikas (Makvoris)',
@@ -216,24 +221,24 @@ return [
         'Antarctica/Vostok' => 'Vostoko laikas (Vostokas)',
         'Arctic/Longyearbyen' => 'Vidurio Europos laikas (Longjyrbienas)',
         'Asia/Aden' => 'Arabijos laikas (Adenas)',
-        'Asia/Almaty' => 'Rytų Kazachstano laikas (Alma Ata)',
+        'Asia/Almaty' => 'Kazachstano laikas (Alma Ata)',
         'Asia/Amman' => 'Rytų Europos laikas (Amanas)',
-        'Asia/Anadyr' => 'Anadyrės laikas (Anadyris)',
-        'Asia/Aqtau' => 'Vakarų Kazachstano laikas (Aktau)',
-        'Asia/Aqtobe' => 'Vakarų Kazachstano laikas (Aktiubinskas)',
+        'Asia/Anadyr' => 'Kamčiatkos Petropavlovsko laikas (Anadyris)',
+        'Asia/Aqtau' => 'Kazachstano laikas (Aktau)',
+        'Asia/Aqtobe' => 'Kazachstano laikas (Aktiubinskas)',
         'Asia/Ashgabat' => 'Turkmėnistano laikas (Ašchabadas)',
-        'Asia/Atyrau' => 'Vakarų Kazachstano laikas (Atyrau)',
+        'Asia/Atyrau' => 'Kazachstano laikas (Atyrau)',
         'Asia/Baghdad' => 'Arabijos laikas (Bagdadas)',
         'Asia/Bahrain' => 'Arabijos laikas (Bahreinas)',
         'Asia/Baku' => 'Azerbaidžano laikas (Baku)',
         'Asia/Bangkok' => 'Indokinijos laikas (Bankokas)',
-        'Asia/Barnaul' => 'Laikas: Rusija (Barnaulas)',
+        'Asia/Barnaul' => 'Krasnojarsko laikas (Barnaulas)',
         'Asia/Beirut' => 'Rytų Europos laikas (Beirutas)',
         'Asia/Bishkek' => 'Kirgistano laikas (Biškekas)',
         'Asia/Brunei' => 'Brunėjaus Darusalamo laikas (Brunėjus)',
         'Asia/Calcutta' => 'Indijos laikas (Kolkata)',
+        'Asia/Kolkata' => 'Indijos laikas (Kolkata)',
         'Asia/Chita' => 'Jakutsko laikas (Čita)',
-        'Asia/Choibalsan' => 'Ulan Batoro laikas (Čoibalsanas)',
         'Asia/Colombo' => 'Indijos laikas (Kolombas)',
         'Asia/Damascus' => 'Rytų Europos laikas (Damaskas)',
         'Asia/Dhaka' => 'Bangladešo laikas (Daka)',
@@ -253,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'Kamčiatkos Petropavlovsko laikas (Kamčiatka)',
         'Asia/Karachi' => 'Pakistano laikas (Karačis)',
         'Asia/Katmandu' => 'Nepalo laikas (Katmandu)',
+        'Asia/Kathmandu' => 'Nepalo laikas (Katmandu)',
         'Asia/Khandyga' => 'Jakutsko laikas (Chandyga)',
         'Asia/Krasnoyarsk' => 'Krasnojarsko laikas (Krasnojarskas)',
         'Asia/Kuala_Lumpur' => 'Malaizijos laikas (Kvala Lumpūras)',
@@ -265,19 +271,21 @@ return [
         'Asia/Muscat' => 'Persijos įlankos laikas (Maskatas)',
         'Asia/Nicosia' => 'Rytų Europos laikas (Nikosija)',
         'Asia/Novokuznetsk' => 'Krasnojarsko laikas (Novokuzneckas)',
-        'Asia/Novosibirsk' => 'Novosibirsko laikas (Novosibirskas)',
+        'Asia/Novosibirsk' => 'Krasnojarsko laikas (Novosibirskas)',
         'Asia/Omsk' => 'Omsko laikas (Omskas)',
-        'Asia/Oral' => 'Vakarų Kazachstano laikas (Uralskas)',
+        'Asia/Oral' => 'Kazachstano laikas (Uralskas)',
         'Asia/Phnom_Penh' => 'Indokinijos laikas (Pnompenis)',
         'Asia/Pontianak' => 'Vakarų Indonezijos laikas (Pontianakas)',
         'Asia/Pyongyang' => 'Korėjos laikas (Pchenjanas)',
         'Asia/Qatar' => 'Arabijos laikas (Kataras)',
-        'Asia/Qostanay' => 'Rytų Kazachstano laikas (Kostanajus)',
-        'Asia/Qyzylorda' => 'Vakarų Kazachstano laikas (Kzyl-Orda)',
+        'Asia/Qostanay' => 'Kazachstano laikas (Kostanajus)',
+        'Asia/Qyzylorda' => 'Kazachstano laikas (Kzyl-Orda)',
         'Asia/Rangoon' => 'Mianmaro laikas (Rangūnas)',
+        'Asia/Yangon' => 'Mianmaro laikas (Rangūnas)',
         'Asia/Riyadh' => 'Arabijos laikas (Rijadas)',
         'Asia/Saigon' => 'Indokinijos laikas (Hošiminas)',
-        'Asia/Sakhalin' => 'Sachalino laikas (Sachalinas)',
+        'Asia/Ho_Chi_Minh' => 'Indokinijos laikas (Hošiminas)',
+        'Asia/Sakhalin' => 'Magadano laikas (Sachalinas)',
         'Asia/Samarkand' => 'Uzbekistano laikas (Samarkandas)',
         'Asia/Seoul' => 'Korėjos laikas (Seulas)',
         'Asia/Shanghai' => 'Kinijos laikas (Šanchajus)',
@@ -289,7 +297,7 @@ return [
         'Asia/Tehran' => 'Irano laikas (Teheranas)',
         'Asia/Thimphu' => 'Butano laikas (Timpu)',
         'Asia/Tokyo' => 'Japonijos laikas (Tokijas)',
-        'Asia/Tomsk' => 'Laikas: Rusija (Tomskas)',
+        'Asia/Tomsk' => 'Krasnojarsko laikas (Tomskas)',
         'Asia/Ulaanbaatar' => 'Ulan Batoro laikas (Ulan Batoras)',
         'Asia/Urumqi' => 'Laikas: Kinija (Urumči)',
         'Asia/Ust-Nera' => 'Vladivostoko laikas (Ust Nera)',
@@ -303,6 +311,7 @@ return [
         'Atlantic/Canary' => 'Vakarų Europos laikas (Kanarų salos)',
         'Atlantic/Cape_Verde' => 'Žaliojo Kyšulio laikas (Žaliasis Kyšulys)',
         'Atlantic/Faeroe' => 'Vakarų Europos laikas (Farerai)',
+        'Atlantic/Faroe' => 'Vakarų Europos laikas (Farerai)',
         'Atlantic/Madeira' => 'Vakarų Europos laikas (Madeira)',
         'Atlantic/Reykjavik' => 'Grinvičo laikas (Reikjavikas)',
         'Atlantic/South_Georgia' => 'Pietų Džordžijos laikas (Pietų Džordžija)',
@@ -311,7 +320,6 @@ return [
         'Australia/Adelaide' => 'Centrinės Australijos laikas (Adelaidė)',
         'Australia/Brisbane' => 'Rytų Australijos laikas (Brisbanas)',
         'Australia/Broken_Hill' => 'Centrinės Australijos laikas (Broken Hilis)',
-        'Australia/Currie' => 'Rytų Australijos laikas (Karis)',
         'Australia/Darwin' => 'Centrinės Australijos laikas (Darvinas)',
         'Australia/Eucla' => 'Centrinės vakarų Australijos laikas (Jukla)',
         'Australia/Hobart' => 'Rytų Australijos laikas (Hobartas)',
@@ -320,13 +328,11 @@ return [
         'Australia/Melbourne' => 'Rytų Australijos laikas (Melburnas)',
         'Australia/Perth' => 'Vakarų Australijos laikas (Pertas)',
         'Australia/Sydney' => 'Rytų Australijos laikas (Sidnėjus)',
-        'CST6CDT' => 'Šiaurės Amerikos centro laikas',
-        'EST5EDT' => 'Šiaurės Amerikos rytų laikas',
         'Etc/GMT' => 'Grinvičo laikas',
         'Etc/UTC' => 'pasaulio suderintasis laikas',
         'Europe/Amsterdam' => 'Vidurio Europos laikas (Amsterdamas)',
         'Europe/Andorra' => 'Vidurio Europos laikas (Andora)',
-        'Europe/Astrakhan' => 'Maskvos laikas (Astrachanė)',
+        'Europe/Astrakhan' => 'Samaros laikas (Astrachanė)',
         'Europe/Athens' => 'Rytų Europos laikas (Atėnai)',
         'Europe/Belgrade' => 'Vidurio Europos laikas (Belgradas)',
         'Europe/Berlin' => 'Vidurio Europos laikas (Berlynas)',
@@ -337,16 +343,17 @@ return [
         'Europe/Busingen' => 'Vidurio Europos laikas (Biusingenas)',
         'Europe/Chisinau' => 'Rytų Europos laikas (Kišiniovas)',
         'Europe/Copenhagen' => 'Vidurio Europos laikas (Kopenhaga)',
-        'Europe/Dublin' => 'Grinvičo laikas (Dublinas)',
+        'Europe/Dublin' => 'Laikas: Airija (Dublinas)',
         'Europe/Gibraltar' => 'Vidurio Europos laikas (Gibraltaras)',
         'Europe/Guernsey' => 'Grinvičo laikas (Gernsis)',
         'Europe/Helsinki' => 'Rytų Europos laikas (Helsinkis)',
         'Europe/Isle_of_Man' => 'Grinvičo laikas (Meno sala)',
-        'Europe/Istanbul' => 'Laikas: Turkija (Stambulas)',
+        'Europe/Istanbul' => 'Turkijos laikas (Stambulas)',
         'Europe/Jersey' => 'Grinvičo laikas (Džersis)',
         'Europe/Kaliningrad' => 'Rytų Europos laikas (Kaliningradas)',
         'Europe/Kiev' => 'Rytų Europos laikas (Kijevas)',
-        'Europe/Kirov' => 'Laikas: Rusija (Kirovas)',
+        'Europe/Kyiv' => 'Rytų Europos laikas (Kijevas)',
+        'Europe/Kirov' => 'Maskvos laikas (Kirovas)',
         'Europe/Lisbon' => 'Vakarų Europos laikas (Lisabona)',
         'Europe/Ljubljana' => 'Vidurio Europos laikas (Liubliana)',
         'Europe/London' => 'Grinvičo laikas (Londonas)',
@@ -366,23 +373,21 @@ return [
         'Europe/Samara' => 'Samaros laikas (Samara)',
         'Europe/San_Marino' => 'Vidurio Europos laikas (San Marinas)',
         'Europe/Sarajevo' => 'Vidurio Europos laikas (Sarajevas)',
-        'Europe/Saratov' => 'Maskvos laikas (Saratovas)',
+        'Europe/Saratov' => 'Samaros laikas (Saratovas)',
         'Europe/Simferopol' => 'Maskvos laikas (Simferopolis)',
         'Europe/Skopje' => 'Vidurio Europos laikas (Skopjė)',
         'Europe/Sofia' => 'Rytų Europos laikas (Sofija)',
         'Europe/Stockholm' => 'Vidurio Europos laikas (Stokholmas)',
         'Europe/Tallinn' => 'Rytų Europos laikas (Talinas)',
         'Europe/Tirane' => 'Vidurio Europos laikas (Tirana)',
-        'Europe/Ulyanovsk' => 'Maskvos laikas (Uljanovskas)',
-        'Europe/Uzhgorod' => 'Rytų Europos laikas (Užhorodas)',
+        'Europe/Ulyanovsk' => 'Samaros laikas (Uljanovskas)',
         'Europe/Vaduz' => 'Vidurio Europos laikas (Vaducas)',
         'Europe/Vatican' => 'Vidurio Europos laikas (Vatikanas)',
         'Europe/Vienna' => 'Vidurio Europos laikas (Viena)',
         'Europe/Vilnius' => 'Rytų Europos laikas (Vilnius)',
-        'Europe/Volgograd' => 'Volgogrado laikas (Volgogradas)',
+        'Europe/Volgograd' => 'Maskvos laikas (Volgogradas)',
         'Europe/Warsaw' => 'Vidurio Europos laikas (Varšuva)',
         'Europe/Zagreb' => 'Vidurio Europos laikas (Zagrebas)',
-        'Europe/Zaporozhye' => 'Rytų Europos laikas (Zaporožė)',
         'Europe/Zurich' => 'Vidurio Europos laikas (Ciurichas)',
         'Indian/Antananarivo' => 'Rytų Afrikos laikas (Antananaryvas)',
         'Indian/Chagos' => 'Indijos vandenyno laikas (Čagosas)',
@@ -395,15 +400,14 @@ return [
         'Indian/Mauritius' => 'Mauricijaus laikas (Mauricijus)',
         'Indian/Mayotte' => 'Rytų Afrikos laikas (Majotas)',
         'Indian/Reunion' => 'Reunjono laikas (Reunjonas)',
-        'MST7MDT' => 'Šiaurės Amerikos kalnų laikas',
-        'PST8PDT' => 'Šiaurės Amerikos Ramiojo vandenyno laikas',
         'Pacific/Apia' => 'Apijos laikas (Apija)',
         'Pacific/Auckland' => 'Naujosios Zelandijos laikas (Oklandas)',
         'Pacific/Bougainville' => 'Papua Naujosios Gvinėjos laikas (Bugenvilis)',
         'Pacific/Chatham' => 'Čatamo laikas (Čatamas)',
         'Pacific/Easter' => 'Velykų Salos laikas (Velykų sala)',
         'Pacific/Efate' => 'Vanuatu laikas (Efatė)',
-        'Pacific/Enderbury' => 'Fenikso Salų laikas (Enderburis)',
+        'Pacific/Enderbury' => 'Fenikso Salų laikas (Kantono sala)',
+        'Pacific/Kanton' => 'Fenikso Salų laikas (Kantono sala)',
         'Pacific/Fakaofo' => 'Tokelau laikas (Fakaofas)',
         'Pacific/Fiji' => 'Fidžio laikas (Fidžis)',
         'Pacific/Funafuti' => 'Tuvalu laikas (Funafutis)',
@@ -411,8 +415,7 @@ return [
         'Pacific/Gambier' => 'Gambyro laikas (Gambyras)',
         'Pacific/Guadalcanal' => 'Saliamono Salų laikas (Gvadalkanalis)',
         'Pacific/Guam' => 'Čamoro laikas (Guamas)',
-        'Pacific/Honolulu' => 'Havajų-Aleutų laikas (Honolulu)',
-        'Pacific/Johnston' => 'Havajų-Aleutų laikas (Džonstonas)',
+        'Pacific/Honolulu' => 'Havajų–Aleutų žiemos laikas (Honolulu)',
         'Pacific/Kiritimati' => 'Laino Salų laikas (Kiritimatis)',
         'Pacific/Kosrae' => 'Kosrajė laikas',
         'Pacific/Kwajalein' => 'Maršalo Salų laikas (Kvadžaleinas)',
@@ -427,6 +430,7 @@ return [
         'Pacific/Palau' => 'Palau laikas',
         'Pacific/Pitcairn' => 'Pitkerno laikas (Pitkerno sala)',
         'Pacific/Ponape' => 'Ponapės laikas',
+        'Pacific/Pohnpei' => 'Ponapės laikas',
         'Pacific/Port_Moresby' => 'Papua Naujosios Gvinėjos laikas (Port Morsbis)',
         'Pacific/Rarotonga' => 'Kuko Salų laikas (Rarotonga)',
         'Pacific/Saipan' => 'Čamoro laikas (Saipanas)',
@@ -434,6 +438,7 @@ return [
         'Pacific/Tarawa' => 'Gilberto Salų laikas (Tarava)',
         'Pacific/Tongatapu' => 'Tongos laikas (Tongatapu)',
         'Pacific/Truk' => 'Čuko laikas (Čukas)',
+        'Pacific/Chuuk' => 'Čuko laikas (Čukas)',
         'Pacific/Wake' => 'Veiko Salos laikas (Veiko sala)',
         'Pacific/Wallis' => 'Voliso ir Futūnos laikas (Volisas)',
     ],
