@@ -343,7 +343,7 @@ return [
         'Europe/Busingen' => 'මධ්‍යම යුරෝපීය වේලාව (බුසින්ජෙන්)',
         'Europe/Chisinau' => 'නැගෙනහිර යුරෝපීය වේලාව (චිසිනෝ)',
         'Europe/Copenhagen' => 'මධ්‍යම යුරෝපීය වේලාව (කෝපන්හේගන්)',
-        'Europe/Dublin' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ඩබ්ලින්)',
+        'Europe/Dublin' => 'අයර්ලන්තය වේලාව (ඩබ්ලින්)',
         'Europe/Gibraltar' => 'මධ්‍යම යුරෝපීය වේලාව (ජිබ්රෝල්ටා)',
         'Europe/Guernsey' => 'ග්‍රිනිච් මධ්‍යම වේලාව (ගුවන්සේ)',
         'Europe/Helsinki' => 'නැගෙනහිර යුරෝපීය වේලාව (හෙල්සින්කි)',
