@@ -13,6 +13,7 @@ namespace Symfony\Component\JsonStreamer\Tests\DependencyInjection;
 
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\DependencyInjection\ContainerBuilder;
+use Symfony\Component\DependencyInjection\Exception\InvalidArgumentException;
 use Symfony\Component\JsonStreamer\DependencyInjection\StreamablePass;
 
 class StreamablePassTest extends TestCase
@@ -23,19 +24,19 @@ class StreamablePassTest extends TestCase
 
         $container->register('json_streamer.stream_writer');
         $container->register('.json_streamer.cache_warmer.streamer')->setArguments([null]);
-        $container->register('.json_streamer.cache_warmer.lazy_ghost')->setArguments([null]);
 
-        $container->register('streamable')->setClass('Foo')->addTag('json_streamer.streamable', ['object' => true, 'list' => true]);
-        $container->register('abstractStreamable')->setClass('Bar')->addTag('json_streamer.streamable', ['object' => true, 'list' => true])->setAbstract(true);
+        $container->register('streamable')->setClass('Foo')->addTag('json_streamer.streamable', ['object' => true, 'list' => true])->addTag('container.excluded');
         $container->register('notStreamable')->setClass('Baz');
 
         $pass = new StreamablePass();
         $pass->process($container);
 
         $streamerCacheWarmer = $container->getDefinition('.json_streamer.cache_warmer.streamer');
-        $lazyGhostCacheWarmer = $container->getDefinition('.json_streamer.cache_warmer.lazy_ghost');
 
         $this->assertSame(['Foo' => ['object' => true, 'list' => true]], $streamerCacheWarmer->getArgument(0));
-        $this->assertSame(['Foo'], $lazyGhostCacheWarmer->getArgument(0));
+
+        $container->register('abstractStreamable')->setClass('Bar')->addTag('json_streamer.streamable', ['object' => true, 'list' => true])->addTag('container.excluded')->setAbstract(true);
+        $this->expectException(InvalidArgumentException::class);
+        $pass->process($container);
     }
 }
