@@ -12,7 +12,7 @@
 namespace Symfony\Component\JsonStreamer\Tests;
 
 use PHPUnit\Framework\TestCase;
-use Symfony\Component\DependencyInjection\Container;
+use Psr\Container\ContainerInterface;
 use Symfony\Component\JsonStreamer\JsonStreamReader;
 use Symfony\Component\JsonStreamer\Tests\Fixtures\Enum\DummyBackedEnum;
 use Symfony\Component\JsonStreamer\Tests\Fixtures\Mapping\SyntheticPropertyMetadataLoader;
@@ -32,29 +32,22 @@ use Symfony\Component\TypeInfo\TypeIdentifier;
 class JsonStreamReaderTest extends TestCase
 {
     private string $streamReadersDir;
-    private string $lazyGhostsDir;
 
     protected function setUp(): void
     {
         parent::setUp();
 
         $this->streamReadersDir = \sprintf('%s/symfony_json_streamer_test/stream_reader', sys_get_temp_dir());
-        $this->lazyGhostsDir = \sprintf('%s/symfony_json_streamer_test/lazy_ghost', sys_get_temp_dir());
 
         if (is_dir($this->streamReadersDir)) {
             array_map('unlink', glob($this->streamReadersDir.'/*'));
             rmdir($this->streamReadersDir);
         }
-
-        if (is_dir($this->lazyGhostsDir)) {
-            array_map('unlink', glob($this->lazyGhostsDir.'/*'));
-            rmdir($this->lazyGhostsDir);
-        }
     }
 
     public function testReadScalar()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, null, 'null', Type::nullable(Type::int()));
         $this->assertRead($reader, true, 'true', Type::bool());
@@ -66,7 +59,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadCollection()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead(
             $reader,
@@ -95,7 +88,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObject()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(ClassicDummy::class, $read);
@@ -106,7 +99,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObjectWithGenerics()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithGenerics::class, $read);
@@ -117,7 +110,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObjectWithStreamedName()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithNameAttributes::class, $read);
@@ -128,12 +121,11 @@ class JsonStreamReaderTest extends TestCase
     public function testReadObjectWithValueTransformer()
     {
         $reader = JsonStreamReader::create(
-            valueTransformers: [
+            [
                 StringToBooleanValueTransformer::class => new StringToBooleanValueTransformer(),
                 DivideStringAndCastToIntValueTransformer::class => new DivideStringAndCastToIntValueTransformer(),
             ],
-            streamReadersDir: $this->streamReadersDir,
-            lazyGhostsDir: $this->lazyGhostsDir,
+            $this->streamReadersDir,
         );
 
         $this->assertRead($reader, function (mixed $read) {
@@ -147,7 +139,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObjectWithPhpDoc()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithPhpDoc::class, $read);
@@ -159,7 +151,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObjectWithNullableProperties()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithNullableProperties::class, $read);
@@ -170,39 +162,18 @@ class JsonStreamReaderTest extends TestCase
 
     public function testReadObjectWithDateTimes()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithDateTimes::class, $read);
             $this->assertEquals(new \DateTimeImmutable('2024-11-20'), $read->interface);
             $this->assertEquals(new \DateTimeImmutable('2025-11-20'), $read->immutable);
-            $this->assertEquals(new \DateTimeImmutable('2026-11-20'), $read->union);
-        }, '{"interface":"2024-11-20","immutable":"2025-11-20","union":"2026-11-20"}', Type::object(DummyWithDateTimes::class));
-
-        $this->assertRead($reader, function (mixed $read) {
-            $this->assertInstanceOf(DummyWithDateTimes::class, $read);
-            $this->assertEquals(new \DateTimeImmutable('2024-11-20'), $read->interface);
-            $this->assertEquals(new \DateTimeImmutable('2025-11-20'), $read->immutable);
-            $this->assertEquals(10, $read->union);
-        }, '{"interface":"2024-11-20","immutable":"2025-11-20","union":10}', Type::object(DummyWithDateTimes::class));
-    }
-
-    public function testReadUnion()
-    {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
-
-        $this->assertRead($reader, function (mixed $read) {
-            $this->assertInstanceOf(DummyWithNameAttributes::class, $read);
-            $this->assertSame(10, $read->id);
-            $this->assertSame('dummy', $read->name);
-        }, '{"@id": 10, "name": "dummy"}', Type::union(Type::int(), Type::list(Type::enum(DummyBackedEnum::class)), Type::object(DummyWithNameAttributes::class)));
-
-        $this->assertRead($reader, [DummyBackedEnum::ONE, DummyBackedEnum::TWO], '[1, 2]', Type::union(Type::int(), Type::list(Type::enum(DummyBackedEnum::class)), Type::object(DummyWithNameAttributes::class)));
+        }, '{"interface":"2024-11-20","immutable":"2025-11-20"}', Type::object(DummyWithDateTimes::class));
     }
 
     public function testReadObjectWithSyntheticProperties()
     {
-        $reader = new JsonStreamReader(new Container(), new SyntheticPropertyMetadataLoader(), $this->streamReadersDir, $this->lazyGhostsDir);
+        $reader = new JsonStreamReader($this->createMock(ContainerInterface::class), new SyntheticPropertyMetadataLoader(), $this->streamReadersDir);
 
         $this->assertRead($reader, function (mixed $read) {
             $this->assertInstanceOf(DummyWithSyntheticProperties::class, $read);
@@ -212,7 +183,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testCreateStreamReaderFile()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         $reader->read('true', Type::bool());
 
@@ -222,7 +193,7 @@ class JsonStreamReaderTest extends TestCase
 
     public function testCreateStreamReaderFileOnlyIfNotExists()
     {
-        $reader = JsonStreamReader::create(streamReadersDir: $this->streamReadersDir, lazyGhostsDir: $this->lazyGhostsDir);
+        $reader = JsonStreamReader::create([], $this->streamReadersDir);
 
         if (!file_exists($this->streamReadersDir)) {
             mkdir($this->streamReadersDir, recursive: true);
