@@ -83,10 +83,11 @@ class LockTest extends TestCase
     public function testAcquireBlockingRetryWithPersistingStoreInterface()
     {
         $key = new Key(__METHOD__);
-        $store = $this->createStub(PersistingStoreInterface::class);
+        $store = $this->createMock(PersistingStoreInterface::class);
         $lock = new Lock($key, $store);
 
         $store
+            ->expects($this->any())
             ->method('save')
             ->willReturnCallback(static function () {
                 if (1 === random_int(0, 1)) {
@@ -215,7 +216,6 @@ class LockTest extends TestCase
         $lock = new Lock($key, $store, 10);
 
         $store
-            ->expects($this->exactly(2))
             ->method('exists')
             ->with($key)
             ->willReturn(true, false);
@@ -403,7 +403,7 @@ class LockTest extends TestCase
     public function testExpiration($ttls, $expected)
     {
         $key = new Key(__METHOD__);
-        $store = $this->createStub(PersistingStoreInterface::class);
+        $store = $this->createMock(PersistingStoreInterface::class);
         $lock = new Lock($key, $store, 10);
 
         foreach ($ttls as $ttl) {
@@ -420,7 +420,7 @@ class LockTest extends TestCase
     public function testExpirationStoreInterface($ttls, $expected)
     {
         $key = new Key(__METHOD__);
-        $store = $this->createStub(PersistingStoreInterface::class);
+        $store = $this->createMock(PersistingStoreInterface::class);
         $lock = new Lock($key, $store, 10);
 
         foreach ($ttls as $ttl) {
@@ -563,10 +563,11 @@ class LockTest extends TestCase
     public function testAcquireReadBlockingWithSharedLockStoreInterface()
     {
         $key = new Key(__METHOD__);
-        $store = $this->createStub(SharedLockStoreInterface::class);
+        $store = $this->createMock(SharedLockStoreInterface::class);
         $lock = new Lock($key, $store);
 
         $store
+            ->expects($this->any())
             ->method('saveRead')
             ->willReturnCallback(static function () {
                 if (1 === random_int(0, 1)) {
@@ -600,10 +601,11 @@ class LockTest extends TestCase
     public function testAcquireReadBlockingWithPersistingStoreInterface()
     {
         $key = new Key(__METHOD__);
-        $store = $this->createStub(PersistingStoreInterface::class);
+        $store = $this->createMock(PersistingStoreInterface::class);
         $lock = new Lock($key, $store);
 
         $store
+            ->expects($this->any())
             ->method('save')
             ->willReturnCallback(static function () {
                 if (1 === random_int(0, 1)) {
