@@ -11,15 +11,15 @@
 
 namespace Symfony\Component\Lock\Tests\Store;
 
+use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Lock\Store\StoreFactory;
 use Symfony\Component\Lock\Store\ZookeeperStore;
 
 /**
  * @author Alexandre Daubois <alex.daubois@gmail.com>
- *
- * @requires extension zookeeper
  */
+#[RequiresPhpExtension('zookeeper')]
 class ZookeeperStoreFactoryTest extends TestCase
 {
     public function testCreateZooKeeperStore()
