@@ -15,15 +15,12 @@ use Doctrine\DBAL\Configuration;
 use Doctrine\DBAL\Connection as DBALConnection;
 use Doctrine\DBAL\Exception as DBALException;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Platforms\MariaDB1060Platform;
 use Doctrine\DBAL\Platforms\MariaDBPlatform;
-use Doctrine\DBAL\Platforms\MySQL57Platform;
 use Doctrine\DBAL\Platforms\MySQL80Platform;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
 use Doctrine\DBAL\Platforms\OraclePlatform;
-use Doctrine\DBAL\Platforms\PostgreSQL100Platform;
-use Doctrine\DBAL\Platforms\PostgreSQL94Platform;
 use Doctrine\DBAL\Platforms\PostgreSQLPlatform;
-use Doctrine\DBAL\Platforms\SQLServer2012Platform;
 use Doctrine\DBAL\Platforms\SQLServerPlatform;
 use Doctrine\DBAL\Query\ForUpdate\ConflictResolutionMode;
 use Doctrine\DBAL\Query\QueryBuilder;
@@ -44,8 +41,8 @@ class ConnectionTest extends TestCase
 {
     public function testGetAMessageWillChangeItsStatus()
     {
-        $queryBuilder = $this->getQueryBuilderStub();
-        $driverConnection = $this->getDBALConnection();
+        $queryBuilder = $this->getQueryBuilderMock();
+        $driverConnection = $this->getDBALConnectionMock();
         $stmt = $this->getResultMock([
             'id' => 1,
             'body' => '{"message":"Hi"}',
@@ -80,8 +77,8 @@ class ConnectionTest extends TestCase
 
     public function testGetWithNoPendingMessageWillReturnNull()
     {
-        $queryBuilder = $this->getQueryBuilderStub();
-        $driverConnection = $this->getDBALConnection(true);
+        $queryBuilder = $this->getQueryBuilderMock();
+        $driverConnection = $this->getDBALConnectionMock();
         $stmt = $this->getResultMock(false);
 
         $queryBuilder
@@ -109,12 +106,8 @@ class ConnectionTest extends TestCase
 
     public function testGetWithSkipLockedWithForUpdateMethod()
     {
-        if (!method_exists(QueryBuilder::class, 'forUpdate')) {
-            $this->markTestSkipped('This test is for when forUpdate method exists.');
-        }
-
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection(true);
+        $driverConnection = $this->getDBALConnectionMock();
         $stmt = $this->getResultMock(false);
 
         $queryBuilder
@@ -124,7 +117,6 @@ class ConnectionTest extends TestCase
             ->method('getParameterTypes')
             ->willReturn([]);
         $queryBuilder
-            ->expects($this->once())
             ->method('forUpdate')
             ->with(ConflictResolutionMode::SKIP_LOCKED)
             ->willReturn($queryBuilder);
@@ -136,44 +128,6 @@ class ConnectionTest extends TestCase
             ->willReturn($queryBuilder);
         $driverConnection->expects($this->never())
             ->method('update');
-        $driverConnection
-            ->method('executeQuery')
-            ->willReturnCallback(function (string $sql) use ($stmt) {
-                $this->assertStringContainsString('SKIP LOCKED', $sql);
-
-                return $stmt;
-            })
-        ;
-
-        $connection = new Connection(['skip_locked' => true], $driverConnection);
-        $doctrineEnvelope = $connection->get();
-        $this->assertNull($doctrineEnvelope);
-    }
-
-    public function testGetWithSkipLockedWithoutForUpdateMethod()
-    {
-        if (method_exists(QueryBuilder::class, 'forUpdate')) {
-            $this->markTestSkipped('This test is for when forUpdate method does not exist.');
-        }
-
-        $queryBuilder = $this->getQueryBuilderStub();
-        $driverConnection = $this->getDBALConnection();
-        $stmt = $this->getResultMock(false);
-
-        $queryBuilder
-            ->method('getParameters')
-            ->willReturn([]);
-        $queryBuilder
-            ->method('getParameterTypes')
-            ->willReturn([]);
-        $queryBuilder
-            ->method('getSQL')
-            ->willReturn('SELECT');
-        $driverConnection->expects($this->once())
-            ->method('createQueryBuilder')
-            ->willReturn($queryBuilder);
-        $driverConnection->expects($this->never())
-            ->method('update');
         $driverConnection
             ->method('executeQuery')
             ->with($this->callback(function ($sql) {
@@ -189,7 +143,7 @@ class ConnectionTest extends TestCase
     public function testItThrowsATransportExceptionIfItCannotAcknowledgeMessage()
     {
         $this->expectException(TransportException::class);
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
         $driverConnection->method('delete')->willThrowException($this->createStub(DBALException::class));
 
         $connection = new Connection([], $driverConnection);
@@ -199,7 +153,7 @@ class ConnectionTest extends TestCase
     public function testItThrowsATransportExceptionIfItCannotRejectMessage()
     {
         $this->expectException(TransportException::class);
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
         $driverConnection->method('delete')->willThrowException($this->createStub(DBALException::class));
 
         $connection = new Connection([], $driverConnection);
@@ -209,7 +163,7 @@ class ConnectionTest extends TestCase
     public function testSend()
     {
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection(true);
+        $driverConnection = $this->getDBALConnectionMock();
 
         $driverConnection->expects($this->once())
             ->method('createQueryBuilder')
@@ -258,7 +212,7 @@ class ConnectionTest extends TestCase
     public function testSendLastInsertIdReturnsInteger()
     {
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection(true);
+        $driverConnection = $this->getDBALConnectionMock();
 
         $driverConnection->expects($this->once())
             ->method('createQueryBuilder')
@@ -307,7 +261,7 @@ class ConnectionTest extends TestCase
     public function testKeepalive()
     {
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection(true);
+        $driverConnection = $this->getDBALConnectionMock();
 
         $connection = new Connection(['redeliver_timeout' => 30, 'table_name' => 'messenger_messages'], $driverConnection);
 
@@ -351,7 +305,7 @@ class ConnectionTest extends TestCase
     public function testKeepaliveRollback()
     {
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection(true);
+        $driverConnection = $this->getDBALConnectionMock();
 
         $connection = new Connection(['redeliver_timeout' => 30, 'table_name' => 'messenger_messages'], $driverConnection);
 
@@ -383,7 +337,7 @@ class ConnectionTest extends TestCase
 
         $driverConnection->expects($this->once())
             ->method('executeStatement')
-            ->willThrowException($this->createStub(DBALException::class));
+            ->willThrowException($this->createMock(DBALException::class));
 
         $driverConnection->expects($this->never())
             ->method('commit');
@@ -398,7 +352,7 @@ class ConnectionTest extends TestCase
 
     public function testKeepaliveThrowsExceptionWhenRedeliverTimeoutIsLessThenInterval()
     {
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
 
         $connection = new Connection(['redeliver_timeout' => 30], $driverConnection);
 
@@ -408,21 +362,17 @@ class ConnectionTest extends TestCase
         $connection->keepalive('1', 60);
     }
 
-    private function getDBALConnection(bool $mock = false)
+    private function getDBALConnectionMock()
     {
-        $driverConnection = $mock ? $this->createMock(DBALConnection::class) : $this->createStub(DBALConnection::class);
-        $platform = $this->createStub(AbstractPlatform::class);
+        $driverConnection = $this->createMock(DBALConnection::class);
+        $platform = $this->createMock(AbstractPlatform::class);
 
-        if (!method_exists(QueryBuilder::class, 'forUpdate')) {
-            $platform->method('getWriteLockSQL')->willReturn('FOR UPDATE SKIP LOCKED');
-        }
-
-        $configuration = $this->createStub(Configuration::class);
+        $configuration = $this->createMock(Configuration::class);
         $driverConnection->method('getDatabasePlatform')->willReturn($platform);
         $driverConnection->method('getConfiguration')->willReturn($configuration);
 
-        $schemaManager = $this->createStub(AbstractSchemaManager::class);
-        $schemaConfig = $this->createStub(SchemaConfig::class);
+        $schemaManager = $this->createMock(AbstractSchemaManager::class);
+        $schemaConfig = $this->createMock(SchemaConfig::class);
         $schemaConfig->method('getMaxIdentifierLength')->willReturn(63);
         $schemaConfig->method('getDefaultTableOptions')->willReturn([]);
         $schemaManager->method('createSchemaConfig')->willReturn($schemaConfig);
@@ -449,24 +399,6 @@ class ConnectionTest extends TestCase
         return $queryBuilder;
     }
 
-    private function getQueryBuilderStub()
-    {
-        $queryBuilder = $this->createStub(QueryBuilder::class);
-
-        $queryBuilder->method('select')->willReturn($queryBuilder);
-        $queryBuilder->method('update')->willReturn($queryBuilder);
-        $queryBuilder->method('from')->willReturn($queryBuilder);
-        $queryBuilder->method('set')->willReturn($queryBuilder);
-        $queryBuilder->method('where')->willReturn($queryBuilder);
-        $queryBuilder->method('andWhere')->willReturn($queryBuilder);
-        $queryBuilder->method('orderBy')->willReturn($queryBuilder);
-        $queryBuilder->method('setMaxResults')->willReturn($queryBuilder);
-        $queryBuilder->method('setParameter')->willReturn($queryBuilder);
-        $queryBuilder->method('setParameters')->willReturn($queryBuilder);
-
-        return $queryBuilder;
-    }
-
     private function getResultMock($expectedResult): Result&MockObject
     {
         $stmt = $this->createMock(Result::class);
@@ -579,7 +511,7 @@ class ConnectionTest extends TestCase
     public function testFind()
     {
         $queryBuilder = $this->getQueryBuilderMock();
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
         $id = 1;
         $stmt = $this->getResultMock([
             'id' => $id,
@@ -591,7 +523,6 @@ class ConnectionTest extends TestCase
             ->method('createQueryBuilder')
             ->willReturn($queryBuilder);
         $queryBuilder
-            ->expects($this->once())
             ->method('where')
             ->with('m.id = ? and m.queue_name = ?')
             ->willReturn($queryBuilder);
@@ -614,8 +545,8 @@ class ConnectionTest extends TestCase
 
     public function testFindAll()
     {
-        $queryBuilder = $this->getQueryBuilderStub();
-        $driverConnection = $this->getDBALConnection();
+        $queryBuilder = $this->getQueryBuilderMock();
+        $driverConnection = $this->getDBALConnectionMock();
         $message1 = [
             'id' => 1,
             'body' => '{"message":"Hi"}',
@@ -670,7 +601,7 @@ class ConnectionTest extends TestCase
         $driverConnection->method('getDatabasePlatform')->willReturn($platform);
         $driverConnection->method('createQueryBuilder')->willReturnCallback(fn () => new QueryBuilder($driverConnection));
 
-        $result = $this->createStub(Result::class);
+        $result = $this->createMock(Result::class);
         $result->method('fetchAssociative')->willReturn(false);
 
         $driverConnection->expects($this->once())->method('beginTransaction');
@@ -691,19 +622,12 @@ class ConnectionTest extends TestCase
     public static function providePlatformSql(): iterable
     {
         yield 'MySQL' => [
-            class_exists(MySQLPlatform::class) ? new MySQLPlatform() : new MySQL57Platform(),
+            new MySQLPlatform(),
             'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
         ];
 
-        if (class_exists(MySQL80Platform::class) && !method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'MySQL8 & DBAL<3.8' => [
-                new MySQL80Platform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
-            ];
-        }
-
-        if (class_exists(MySQL80Platform::class) && method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'MySQL8 & DBAL>=3.8' => [
+        if (class_exists(MySQL80Platform::class)) {
+            yield 'MySQL8' => [
                 new MySQL80Platform(),
                 'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
             ];
@@ -714,115 +638,41 @@ class ConnectionTest extends TestCase
             'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
         ];
 
-        if (interface_exists(DBALException::class)) {
-            // DBAL 4+
-            $mariaDbPlatformClass = 'Doctrine\DBAL\Platforms\MariaDB1060Platform';
-        } else {
-            $mariaDbPlatformClass = 'Doctrine\DBAL\Platforms\MariaDb1060Platform';
-        }
+        yield 'MariaDB106' => [
+            new MariaDB1060Platform(),
+            'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
+        ];
 
-        if (class_exists($mariaDbPlatformClass)) {
-            yield 'MariaDB106' => [
-                new $mariaDbPlatformClass(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
-            ];
-        }
+        yield 'Postgres' => [
+            new PostgreSQLPlatform(),
+            'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
+        ];
 
-        if (class_exists(MySQL57Platform::class)) {
-            yield 'Postgres & DBAL<4' => [
-                new PostgreSQLPlatform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
-            ];
-        } else {
-            yield 'Postgres & DBAL>=4' => [
-                new PostgreSQLPlatform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
-            ];
-        }
+        yield 'SQL Server' => [
+            new SQLServerPlatform(),
+            'SELECT m.* FROM messenger_messages m WITH (UPDLOCK, ROWLOCK, READPAST) WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC OFFSET 0 ROWS FETCH NEXT 1 ROWS ONLY  ',
+        ];
 
-        if (class_exists(PostgreSQL94Platform::class)) {
-            yield 'Postgres94' => [
-                new PostgreSQL94Platform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
-            ];
-        }
-
-        if (class_exists(PostgreSQL100Platform::class) && !method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'Postgres10 & DBAL<3.8' => [
-                new PostgreSQL100Platform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE',
-            ];
-        }
-
-        if (class_exists(PostgreSQL100Platform::class) && method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'Postgres10 & DBAL>=3.8' => [
-                new PostgreSQL100Platform(),
-                'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC LIMIT 1 FOR UPDATE SKIP LOCKED',
-            ];
-        }
-
-        if (!method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'SQL Server & DBAL<3.8' => [
-                class_exists(SQLServerPlatform::class) && !class_exists(SQLServer2012Platform::class) ? new SQLServerPlatform() : new SQLServer2012Platform(),
-                'SELECT m.* FROM messenger_messages m WITH (UPDLOCK, ROWLOCK) WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC OFFSET 0 ROWS FETCH NEXT 1 ROWS ONLY  ',
-            ];
-        }
-
-        if (method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'SQL Server & DBAL>=3.8' => [
-                class_exists(SQLServerPlatform::class) && !class_exists(SQLServer2012Platform::class) ? new SQLServerPlatform() : new SQLServer2012Platform(),
-                'SELECT m.* FROM messenger_messages m WITH (UPDLOCK, ROWLOCK, READPAST) WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC OFFSET 0 ROWS FETCH NEXT 1 ROWS ONLY  ',
-            ];
-        }
-
-        if (!method_exists(QueryBuilder::class, 'forUpdate')) {
-            yield 'Oracle & DBAL<3.8' => [
-                new OraclePlatform(),
-                \sprintf('SELECT w.id AS "id", w.body AS "body", w.headers AS "headers", w.queue_name AS "queue_name", w.created_at AS "created_at", w.available_at AS "available_at", w.delivered_at AS "delivered_at" FROM messenger_messages w WHERE w.id IN (SELECT a.id FROM (SELECT m.id FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC) a WHERE ROWNUM <= 1) FOR UPDATE%s', method_exists(QueryBuilder::class, 'forUpdate') ? ' SKIP LOCKED' : ''),
-            ];
-        } elseif (class_exists(MySQL57Platform::class)) {
-            yield 'Oracle & 3.8<=DBAL<4' => [
-                new OraclePlatform(),
-                'SELECT w.id AS "id", w.body AS "body", w.headers AS "headers", w.queue_name AS "queue_name", w.created_at AS "created_at", w.available_at AS "available_at", w.delivered_at AS "delivered_at" FROM messenger_messages w WHERE w.id IN (SELECT a.id FROM (SELECT m.id FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC) a WHERE ROWNUM <= 1) FOR UPDATE SKIP LOCKED',
-            ];
-        } else {
-            yield 'Oracle & DBAL>=4' => [
-                new OraclePlatform(),
-                'SELECT w.id AS "id", w.body AS "body", w.headers AS "headers", w.queue_name AS "queue_name", w.created_at AS "created_at", w.available_at AS "available_at", w.delivered_at AS "delivered_at" FROM messenger_messages w WHERE w.id IN (SELECT m.id FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC FETCH NEXT 1 ROWS ONLY) FOR UPDATE SKIP LOCKED',
-            ];
-        }
+        yield 'Oracle' => [
+            new OraclePlatform(),
+            'SELECT w.id AS "id", w.body AS "body", w.headers AS "headers", w.queue_name AS "queue_name", w.created_at AS "created_at", w.available_at AS "available_at", w.delivered_at AS "delivered_at" FROM messenger_messages w WHERE w.id IN (SELECT m.id FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY available_at ASC FETCH NEXT 1 ROWS ONLY) FOR UPDATE SKIP LOCKED',
+        ];
     }
 
     public function testConfigureSchema()
     {
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
         $schema = new Schema();
 
         $connection = new Connection(['table_name' => 'queue_table'], $driverConnection);
         $connection->configureSchema($schema, $driverConnection, fn () => true);
         $this->assertTrue($schema->hasTable('queue_table'));
-
-        // Ensure the covering index for the SELECT query exists
-        $table = $schema->getTable('queue_table');
-        $hasCoveringIndex = false;
-        foreach ($table->getIndexes() as $index) {
-            // Doctrine DBAL 4+: use getIndexedColumns(); fallback to getColumns() for older versions
-            $columns = method_exists($index, 'getIndexedColumns')
-                ? array_map(static fn ($ic) => $ic->getColumnName()->toString(), $index->getIndexedColumns())
-                : $index->getColumns();
-
-            if ($columns === ['queue_name', 'available_at', 'delivered_at', 'id']) {
-                $hasCoveringIndex = true;
-                break;
-            }
-        }
-        $this->assertTrue($hasCoveringIndex, 'Expected covering index on [queue_name, available_at, delivered_at, id] not found');
     }
 
     public function testConfigureSchemaDifferentDbalConnection()
     {
-        $driverConnection = $this->getDBALConnection();
-        $driverConnection2 = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
+        $driverConnection2 = $this->getDBALConnectionMock();
         $schema = new Schema();
 
         $connection = new Connection([], $driverConnection);
@@ -832,7 +682,7 @@ class ConnectionTest extends TestCase
 
     public function testConfigureSchemaTableExists()
     {
-        $driverConnection = $this->getDBALConnection();
+        $driverConnection = $this->getDBALConnectionMock();
         $schema = new Schema();
         $schema->createTable('messenger_messages');
 
@@ -851,7 +701,7 @@ class ConnectionTest extends TestCase
             return new QueryBuilder($driverConnection);
         });
 
-        $result = $this->createStub(Result::class);
+        $result = $this->createMock(Result::class);
         $result->method('fetchAllAssociative')->willReturn([]);
 
         $driverConnection
@@ -868,7 +718,7 @@ class ConnectionTest extends TestCase
     public static function provideFindAllSqlGeneratedByPlatform(): iterable
     {
         yield 'MySQL' => [
-            class_exists(MySQLPlatform::class) ? new MySQLPlatform() : new MySQL57Platform(),
+            new MySQLPlatform(),
             'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) LIMIT 50',
         ];
 
@@ -878,32 +728,23 @@ class ConnectionTest extends TestCase
         ];
 
         yield 'SQL Server' => [
-            class_exists(SQLServerPlatform::class) && !class_exists(SQLServer2012Platform::class) ? new SQLServerPlatform() : new SQLServer2012Platform(),
+            new SQLServerPlatform(),
             'SELECT m.* FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) ORDER BY (SELECT 0) OFFSET 0 ROWS FETCH NEXT 50 ROWS ONLY',
         ];
 
-        if (!class_exists(MySQL57Platform::class)) {
-            // DBAL >= 4
-            yield 'Oracle' => [
-                new OraclePlatform(),
-                'SELECT m.id AS "id", m.body AS "body", m.headers AS "headers", m.queue_name AS "queue_name", m.created_at AS "created_at", m.available_at AS "available_at", m.delivered_at AS "delivered_at" FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) FETCH NEXT 50 ROWS ONLY',
-            ];
-        } else {
-            // DBAL < 4
-            yield 'Oracle' => [
-                new OraclePlatform(),
-                'SELECT a.* FROM (SELECT m.id AS "id", m.body AS "body", m.headers AS "headers", m.queue_name AS "queue_name", m.created_at AS "created_at", m.available_at AS "available_at", m.delivered_at AS "delivered_at" FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?)) a WHERE ROWNUM <= 50',
-            ];
-        }
+        yield 'Oracle' => [
+            new OraclePlatform(),
+            'SELECT m.id AS "id", m.body AS "body", m.headers AS "headers", m.queue_name AS "queue_name", m.created_at AS "created_at", m.available_at AS "available_at", m.delivered_at AS "delivered_at" FROM messenger_messages m WHERE (m.queue_name = ?) AND (m.delivered_at is null OR m.delivered_at < ?) AND (m.available_at <= ?) FETCH NEXT 50 ROWS ONLY',
+        ];
     }
 
     public function testConfigureSchemaOracleSequenceNameSuffixed()
     {
-        $driverConnection = $this->createStub(DBALConnection::class);
+        $driverConnection = $this->createMock(DBALConnection::class);
         $driverConnection->method('getDatabasePlatform')->willReturn(new OraclePlatform());
 
         // Mock the result returned by executeQuery to be an Oracle version 12.1.0 or higher.
-        $result = $this->createStub(Result::class);
+        $result = $this->createMock(Result::class);
         $result->method('fetchOne')->willReturn('12.1.0');
         $driverConnection->method('executeQuery')->willReturn($result);
 
