@@ -30,7 +30,7 @@ class PostgreSqlConnectionTest extends TestCase
         $this->expectException(\BadMethodCallException::class);
         $this->expectExceptionMessage('Cannot serialize '.PostgreSqlConnection::class);
 
-        $driverConnection = $this->createStub(Connection::class);
+        $driverConnection = $this->createMock(Connection::class);
         $driverConnection->method('executeStatement')->willReturn(1);
 
         $connection = new PostgreSqlConnection([], $driverConnection);
@@ -42,7 +42,7 @@ class PostgreSqlConnectionTest extends TestCase
         $this->expectException(\BadMethodCallException::class);
         $this->expectExceptionMessage('Cannot unserialize '.PostgreSqlConnection::class);
 
-        $driverConnection = $this->createStub(Connection::class);
+        $driverConnection = $this->createMock(Connection::class);
         $driverConnection->method('executeStatement')->willReturn(1);
 
         $connection = new PostgreSqlConnection([], $driverConnection);
@@ -55,23 +55,18 @@ class PostgreSqlConnectionTest extends TestCase
         $driverConnection->method('executeStatement')->willReturn(1);
 
         $driverConnection
+            ->expects(self::any())
             ->method('getDatabasePlatform')
             ->willReturn(new PostgreSQLPlatform());
 
         $driverConnection
+            ->expects(self::any())
             ->method('createQueryBuilder')
             ->willReturn(new QueryBuilder($driverConnection));
 
         $wrappedConnection = new class {
             private int $notifyCalls = 0;
 
-            public function pgsqlGetNotify()
-            {
-                ++$this->notifyCalls;
-
-                return false;
-            }
-
             public function getNotify()
             {
                 ++$this->notifyCalls;
@@ -90,10 +85,11 @@ class PostgreSqlConnectionTest extends TestCase
             ->method('getNativeConnection')
             ->willReturn($wrappedConnection);
 
-        $driverResult = $this->createStub(DriverResult::class);
+        $driverResult = $this->createMock(DriverResult::class);
         $driverResult->method('fetchAssociative')
             ->willReturn(false);
         $driverConnection
+            ->expects(self::any())
             ->method('executeQuery')
             ->willReturn(new Result($driverResult, $driverConnection));
 
@@ -103,18 +99,43 @@ class PostgreSqlConnectionTest extends TestCase
         $connection->get();
         $connection->get();
 
-        $this->assertTrue($connection->isListening());
-
         $this->assertSame(2, $wrappedConnection->countNotifyCalls());
+    }
 
-        $connection->__destruct();
+    public function testGetExtraSetupSql()
+    {
+        $driverConnection = $this->createMock(Connection::class);
+        $driverConnection->method('executeStatement')->willReturn(1);
+        $connection = new PostgreSqlConnection(['table_name' => 'queue_table'], $driverConnection);
 
-        $this->assertFalse($connection->isListening());
+        $table = new Table('queue_table');
+        $table->addOption('_symfony_messenger_table_name', 'queue_table');
+        $sql = implode("\n", $connection->getExtraSetupSqlForTable($table));
+
+        $this->assertStringContainsString('CREATE TRIGGER', $sql);
+
+        // We MUST NOT use transaction, that will mess with the PDO in PHP 8
+        $this->assertStringNotContainsString('BEGIN;', $sql);
+        $this->assertStringNotContainsString('COMMIT;', $sql);
+    }
+
+    public function testTransformTableNameWithSchemaToValidProcedureName()
+    {
+        $driverConnection = $this->createMock(Connection::class);
+        $driverConnection->method('executeStatement')->willReturn(1);
+        $connection = new PostgreSqlConnection(['table_name' => 'schema.queue_table'], $driverConnection);
+
+        $table = new Table('schema.queue_table');
+        $table->addOption('_symfony_messenger_table_name', 'schema.queue_table');
+        $sql = implode("\n", $connection->getExtraSetupSqlForTable($table));
+
+        $this->assertStringContainsString('CREATE OR REPLACE FUNCTION schema.notify_queue_table', $sql);
+        $this->assertStringContainsString('FOR EACH ROW EXECUTE PROCEDURE schema.notify_queue_table()', $sql);
     }
 
     public function testGetExtraSetupSqlWrongTable()
     {
-        $driverConnection = $this->createStub(Connection::class);
+        $driverConnection = $this->createMock(Connection::class);
         $driverConnection->method('executeStatement')->willReturn(1);
         $connection = new PostgreSqlConnection(['table_name' => 'queue_table'], $driverConnection);
 
@@ -122,12 +143,4 @@ class PostgreSqlConnectionTest extends TestCase
         // don't set the _symfony_messenger_table_name option
         $this->assertSame([], $connection->getExtraSetupSqlForTable($table));
     }
-
-    public function testIsListeningReturnsFalseWhenGetHasNotBeenCalled()
-    {
-        $driverConnection = $this->createStub(\Doctrine\DBAL\Connection::class);
-        $connection = new PostgreSqlConnection(['table_name' => 'queue_table'], $driverConnection);
-
-        $this->assertFalse($connection->isListening());
-    }
 }
