@@ -11,6 +11,8 @@
 
 namespace Symfony\Component\Messenger\Bridge\Doctrine\Transport;
 
+use Doctrine\DBAL\Schema\Table;
+
 /**
  * Uses PostgreSQL LISTEN/NOTIFY to push messages to workers.
  *
@@ -65,9 +67,7 @@ final class PostgreSqlConnection extends Connection
         /** @var \PDO $nativeConnection */
         $nativeConnection = $this->driverConnection->getNativeConnection();
 
-        $notification = \PHP_VERSION_ID >= 80400
-            ? $nativeConnection->getNotify(\PDO::FETCH_ASSOC, $this->configuration['get_notify_timeout'])
-            : $nativeConnection->pgsqlGetNotify(\PDO::FETCH_ASSOC, $this->configuration['get_notify_timeout']);
+        $notification = $nativeConnection->getNotify(\PDO::FETCH_ASSOC, $this->configuration['get_notify_timeout']);
         if (
             // no notifications, or for another table or queue
             (false === $notification || $notification['message'] !== $this->configuration['table_name'] || $notification['payload'] !== $this->configuration['queue_name'])
@@ -82,6 +82,63 @@ final class PostgreSqlConnection extends Connection
         return parent::get();
     }
 
+    public function setup(): void
+    {
+        parent::setup();
+
+        $this->executeStatement(implode("\n", $this->getTriggerSql()));
+    }
+
+    /**
+     * @return string[]
+     */
+    public function getExtraSetupSqlForTable(Table $createdTable): array
+    {
+        if (!$createdTable->hasOption(self::TABLE_OPTION_NAME)) {
+            return [];
+        }
+
+        if ($createdTable->getOption(self::TABLE_OPTION_NAME) !== $this->configuration['table_name']) {
+            return [];
+        }
+
+        return $this->getTriggerSql();
+    }
+
+    private function getTriggerSql(): array
+    {
+        $functionName = $this->createTriggerFunctionName();
+
+        return [
+            // create trigger function
+            \sprintf(<<<'SQL'
+                CREATE OR REPLACE FUNCTION %1$s() RETURNS TRIGGER AS $$
+                    BEGIN
+                        PERFORM pg_notify('%2$s', NEW.queue_name::text);
+                        RETURN NEW;
+                    END;
+                $$ LANGUAGE plpgsql;
+                SQL,
+                $functionName,
+                $this->configuration['table_name']
+            ),
+            // register trigger
+            \sprintf('DROP TRIGGER IF EXISTS notify_trigger ON %s;', $this->configuration['table_name']),
+            \sprintf('CREATE TRIGGER notify_trigger AFTER INSERT OR UPDATE ON %1$s FOR EACH ROW EXECUTE PROCEDURE %2$s();', $this->configuration['table_name'], $functionName),
+        ];
+    }
+
+    private function createTriggerFunctionName(): string
+    {
+        $tableConfig = explode('.', $this->configuration['table_name']);
+
+        if (1 === \count($tableConfig)) {
+            return \sprintf('notify_%1$s', $tableConfig[0]);
+        }
+
+        return \sprintf('%1$s.notify_%2$s', $tableConfig[0], $tableConfig[1]);
+    }
+
     private function unlisten(): void
     {
         $this->executeStatement(\sprintf('UNLISTEN "%s"', $this->configuration['table_name']));
