@@ -23,13 +23,10 @@ use Symfony\Component\Messenger\Transport\Serialization\SerializerInterface;
  */
 class RedisSender implements SenderInterface
 {
-    private Connection $connection;
-    private SerializerInterface $serializer;
-
-    public function __construct(Connection $connection, SerializerInterface $serializer)
-    {
-        $this->connection = $connection;
-        $this->serializer = $serializer;
+    public function __construct(
+        private Connection $connection,
+        private SerializerInterface $serializer,
+    ) {
     }
 
     public function send(Envelope $envelope): Envelope
