@@ -18,9 +18,11 @@ namespace Symfony\Component\Messenger\Exception;
  * and the message should be retried, a handler can throw such an exception.
  *
  * @author Jérémy Derussé <jeremy@derusse.com>
- *
- * @method int|null getRetryDelay() The time to wait in milliseconds
  */
 interface RecoverableExceptionInterface extends \Throwable
 {
+    /**
+     * Returns the time to wait before potentially retrying, in millisecond.
+     */
+    public function getRetryDelay(): ?int;
 }
