@@ -16,10 +16,16 @@ namespace Symfony\Component\Messenger\Exception;
  *
  * @author Jeroen <https://github.com/Jeroeny>
  */
-interface WrappedExceptionsInterface
+interface WrappedExceptionsInterface extends \Throwable
 {
     /**
+     * @template TException of \Throwable
+     *
+     * @param class-string<TException>|null $class
+     *
      * @return \Throwable[]
+     *
+     * @psalm-return ($class is null ? \Throwable[] : TException[])
      */
     public function getWrappedExceptions(?string $class = null, bool $recursive = false): array;
 }
