@@ -18,14 +18,12 @@ namespace Symfony\Component\Messenger\Stamp;
  */
 final class TransportMessageIdStamp implements StampInterface
 {
-    private mixed $id;
-
     /**
      * @param mixed $id some "identifier" of the message in a transport
      */
-    public function __construct(mixed $id)
-    {
-        $this->id = $id;
+    public function __construct(
+        private mixed $id,
+    ) {
     }
 
     public function getId(): mixed
