@@ -15,22 +15,19 @@ use Symfony\Component\Validator\Constraints\GroupSequence;
 
 /**
  * @author Maxime Steinhausser <maxime.steinhausser@gmail.com>
- *
- * @experimental in 4.3
  */
 final class ValidationStamp implements StampInterface
 {
-    private $groups;
-
     /**
      * @param string[]|GroupSequence $groups
      */
-    public function __construct($groups)
-    {
-        $this->groups = $groups;
+    public function __construct(
+        private array|GroupSequence $groups,
+    ) {
     }
 
-    public function getGroups()
+    /** @return string[]|GroupSequence */
+    public function getGroups(): array|GroupSequence
     {
         return $this->groups;
     }
