@@ -12,10 +12,15 @@
 namespace Symfony\Component\Notifier\Bridge\Sinch\Tests;
 
 use Symfony\Component\Notifier\Bridge\Sinch\SinchTransportFactory;
-use Symfony\Component\Notifier\Test\TransportFactoryTestCase;
+use Symfony\Component\Notifier\Test\AbstractTransportFactoryTestCase;
+use Symfony\Component\Notifier\Test\IncompleteDsnTestTrait;
+use Symfony\Component\Notifier\Test\MissingRequiredOptionTestTrait;
 
-final class SinchTransportFactoryTest extends TransportFactoryTestCase
+final class SinchTransportFactoryTest extends AbstractTransportFactoryTestCase
 {
+    use IncompleteDsnTestTrait;
+    use MissingRequiredOptionTestTrait;
+
     public function createFactory(): SinchTransportFactory
     {
         return new SinchTransportFactory();
@@ -45,4 +50,10 @@ final class SinchTransportFactoryTest extends TransportFactoryTestCase
         yield ['somethingElse://accountSid:authToken@default?from=0611223344'];
         yield ['somethingElse://accountSid:authToken@default']; // missing "from" option
     }
+
+    public static function incompleteDsnProvider(): iterable
+    {
+        yield ['sinch://accountSid@default?from=0611223344'];
+        yield ['sinch://:authToken@default?from=0611223344'];
+    }
 }
