@@ -17,15 +17,11 @@ use Symfony\Component\Notifier\Message\ChatMessage;
 use Symfony\Component\Notifier\Message\SmsMessage;
 use Symfony\Component\Notifier\Test\TransportTestCase;
 use Symfony\Component\Notifier\Tests\Transport\DummyMessage;
-use Symfony\Component\Notifier\Transport\TransportInterface;
 use Symfony\Contracts\HttpClient\HttpClientInterface;
 
 final class SinchTransportTest extends TransportTestCase
 {
-    /**
-     * @return SinchTransport
-     */
-    public static function createTransport(HttpClientInterface $client = null): TransportInterface
+    public static function createTransport(?HttpClientInterface $client = null): SinchTransport
     {
         return new SinchTransport('accountSid', 'authToken', 'sender', $client ?? new MockHttpClient());
     }
