@@ -20,7 +20,6 @@ use Symfony\Component\PropertyInfo\PropertyInitializableExtractorInterface;
 use Symfony\Component\PropertyInfo\PropertyTypeExtractorInterface;
 use Symfony\Component\PropertyInfo\Tests\Fixtures\DummyExtractor;
 use Symfony\Component\PropertyInfo\Tests\Fixtures\NullExtractor;
-use Symfony\Component\PropertyInfo\Type as LegacyType;
 use Symfony\Component\TypeInfo\Type;
 
 /**
@@ -60,14 +59,6 @@ class AbstractPropertyInfoExtractorTest extends TestCase
         $this->assertEquals(Type::int(), $this->propertyInfo->getType('Foo', 'bar', []));
     }
 
-    /**
-     * @group legacy
-     */
-    public function testGetTypes()
-    {
-        $this->assertEquals([new LegacyType(LegacyType::BUILTIN_TYPE_INT)], $this->propertyInfo->getTypes('Foo', 'bar', []));
-    }
-
     public function testIsReadable()
     {
         $this->assertTrue($this->propertyInfo->isReadable('Foo', 'bar', []));
