@@ -108,8 +108,7 @@ class UrlGenerator implements UrlGeneratorInterface, ConfigurableRequirementsInt
 
         if (null !== $locale) {
             do {
-                $route = $this->routes->get($name.'.'.$locale);
-                if ($route && ($route->getDefault('_canonical_route') === $name || $this->routes->getAlias($name.'.'.$locale))) {
+                if (null !== ($route = $this->routes->get($name.'.'.$locale)) && $route->getDefault('_canonical_route') === $name) {
                     break;
                 }
             } while (false !== $locale = strstr($locale, '_', true));
@@ -150,8 +149,7 @@ class UrlGenerator implements UrlGeneratorInterface, ConfigurableRequirementsInt
                 $queryParameters = $parameters['_query'];
                 unset($parameters['_query']);
             } else {
-                trigger_deprecation('symfony/routing', '7.4', 'Parameter "_query" is reserved for passing an array of query parameters. Passing a scalar value is deprecated and will throw an exception in Symfony 8.0.');
-                // throw new InvalidParameterException('Parameter "_query" must be an array of query parameters.');
+                throw new InvalidParameterException('Parameter "_query" must be an array of query parameters.');
             }
         }
 
@@ -273,7 +271,7 @@ class UrlGenerator implements UrlGeneratorInterface, ConfigurableRequirementsInt
 
         // add a query string if needed
         $extra = array_udiff_assoc(array_diff_key($parameters, $variables), $defaults, fn ($a, $b) => $a == $b ? 0 : 1);
-        $extra = array_replace($extra, $queryParameters);
+        $extra = array_merge($extra, $queryParameters);
 
         array_walk_recursive($extra, $caster = static function (&$v) use (&$caster) {
             if (\is_object($v)) {
