@@ -12,11 +12,8 @@
 namespace Symfony\Component\Routing\Tests\Loader;
 
 use PHPUnit\Framework\Attributes\DataProvider;
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Config\FileLocator;
-use Symfony\Component\Config\FileLocatorInterface;
 use Symfony\Component\Config\Loader\LoaderResolver;
 use Symfony\Component\Config\Resource\FileResource;
 use Symfony\Component\Config\Resource\ResourceInterface;
@@ -31,7 +28,7 @@ class PhpFileLoaderTest extends TestCase
 {
     public function testSupports()
     {
-        $loader = new PhpFileLoader($this->createStub(FileLocatorInterface::class));
+        $loader = new PhpFileLoader($this->createMock(FileLocator::class));
 
         $this->assertTrue($loader->supports('foo.php'), '->supports() returns true if the resource is loadable');
         $this->assertFalse($loader->supports('foo.foo'), '->supports() returns true if the resource is loadable');
@@ -261,20 +258,6 @@ class PhpFileLoaderTest extends TestCase
         $this->assertSame('AppBundle:Baz:view', $route->getDefault('_controller'));
     }
 
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testTriggersDeprecationWhenAccessingLoaderInternalScope()
-    {
-        $locator = new FileLocator([__DIR__.'/../Fixtures']);
-        $loader = new PhpFileLoader($locator);
-
-        $this->expectUserDeprecationMessageMatches('{^Since symfony/routing 7.4: Accessing the internal scope of the loader in config files is deprecated, use only its public API instead in ".+" on line \d+\.$}');
-
-        $routes = $loader->load('legacy_internal_scope.php');
-
-        $this->assertInstanceOf(RouteCollection::class, $routes);
-    }
-
     public function testRoutingI18nConfigurator()
     {
         $locator = new FileLocator([__DIR__.'/../Fixtures']);
