@@ -21,8 +21,6 @@ use Symfony\Component\Security\Core\User\UserInterface;
  */
 class RememberMeToken extends AbstractToken
 {
-    private ?string $secret = null;
-
     /**
      * @throws \InvalidArgumentException
      */
@@ -32,11 +30,6 @@ class RememberMeToken extends AbstractToken
     ) {
         parent::__construct($user->getRoles());
 
-        if (\func_num_args() > 2) {
-            trigger_deprecation('symfony/security-core', '7.2', 'The "$secret" argument of "%s()" is deprecated.', __METHOD__);
-            $this->secret = func_get_arg(2);
-        }
-
         if (!$firewallName) {
             throw new InvalidArgumentException('$firewallName must not be empty.');
         }
@@ -49,25 +42,14 @@ class RememberMeToken extends AbstractToken
         return $this->firewallName;
     }
 
-    /**
-     * @deprecated since Symfony 7.2
-     */
-    public function getSecret(): string
-    {
-        trigger_deprecation('symfony/security-core', '7.2', 'The "%s()" method is deprecated.', __METHOD__);
-
-        return $this->secret ??= base64_encode(random_bytes(8));
-    }
-
     public function __serialize(): array
     {
-        // $this->firewallName should be kept at index 1 for compatibility with payloads generated before Symfony 8
-        return [$this->secret, $this->firewallName, parent::__serialize()];
+        return [null, $this->firewallName, parent::__serialize()];
     }
 
     public function __unserialize(array $data): void
     {
-        [$this->secret, $this->firewallName, $parentData] = $data;
+        [, $this->firewallName, $parentData] = $data;
         $parentData = \is_array($parentData) ? $parentData : unserialize($parentData);
         parent::__unserialize($parentData);
     }
