@@ -24,12 +24,8 @@ use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
  */
 abstract class Voter implements VoterInterface, CacheableVoterInterface
 {
-    /**
-     * @param Vote|null $vote Should be used to explain the vote
-     */
-    public function vote(TokenInterface $token, mixed $subject, array $attributes/* , ?Vote $vote = null */): int
+    public function vote(TokenInterface $token, mixed $subject, array $attributes, ?Vote $vote = null): int
     {
-        $vote = 3 < \func_num_args() ? func_get_arg(3) : null;
         // abstain vote by default in case none of the attributes are supported
         $voteResult = self::ACCESS_ABSTAIN;
 
@@ -108,5 +104,5 @@ abstract class Voter implements VoterInterface, CacheableVoterInterface
      * @param TSubject   $subject
      * @param Vote|null  $vote      Should be used to explain the vote
      */
-    abstract protected function voteOnAttribute(string $attribute, mixed $subject, TokenInterface $token/* , ?Vote $vote = null */): bool;
+    abstract protected function voteOnAttribute(string $attribute, mixed $subject, TokenInterface $token, ?Vote $vote = null): bool;
 }
