@@ -19,10 +19,7 @@ namespace Symfony\Component\Security\Core\Exception;
  */
 class AccountExpiredException extends AccountStatusException
 {
-    /**
-     * {@inheritdoc}
-     */
-    public function getMessageKey()
+    public function getMessageKey(): string
     {
         return 'Account has expired.';
     }
