@@ -13,7 +13,6 @@ namespace Symfony\Component\Security\Core\Test;
 
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
-use Symfony\Component\Security\Core\Authentication\Token\NullToken;
 use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
 use Symfony\Component\Security\Core\Authorization\AccessDecisionManager;
 use Symfony\Component\Security\Core\Authorization\Strategy\AccessDecisionStrategyInterface;
@@ -28,14 +27,17 @@ use Symfony\Component\Security\Core\Authorization\Voter\VoterInterface;
 abstract class AccessDecisionStrategyTestCase extends TestCase
 {
     /**
+     * @dataProvider provideStrategyTests
+     *
      * @param VoterInterface[] $voters
      */
     #[DataProvider('provideStrategyTests')]
     final public function testDecide(AccessDecisionStrategyInterface $strategy, array $voters, bool $expected)
     {
+        $token = $this->createMock(TokenInterface::class);
         $manager = new AccessDecisionManager($voters, $strategy);
 
-        $this->assertSame($expected, $manager->decide(new NullToken(), ['ROLE_FOO']));
+        $this->assertSame($expected, $manager->decide($token, ['ROLE_FOO']));
     }
 
     /**
