@@ -1,20 +1,24 @@
 <?php
 
+/*
+ * This file is part of the Symfony package.
+ *
+ * (c) Fabien Potencier <fabien@symfony.com>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
 namespace Symfony\Component\Security\Core\Tests\Authentication\Token\Fixtures;
 
 use Symfony\Component\Security\Core\User\UserInterface;
 
 final class CustomUser implements UserInterface
 {
-    /** @var string */
-    private $username;
-    /** @var array */
-    private $roles;
-
-    public function __construct(string $username, array $roles)
-    {
-        $this->username = $username;
-        $this->roles = $roles;
+    public function __construct(
+        private string $username,
+        private array $roles,
+    ) {
     }
 
     public function getUserIdentifier(): string
@@ -31,13 +35,4 @@ final class CustomUser implements UserInterface
     {
         return null;
     }
-
-    public function getSalt(): ?string
-    {
-        return null;
-    }
-
-    public function eraseCredentials(): void
-    {
-    }
 }
