@@ -34,10 +34,7 @@ class InMemoryUserChecker implements UserCheckerInterface
         }
     }
 
-    /**
-     * @param ?TokenInterface $token
-     */
-    public function checkPostAuth(UserInterface $user /* , ?TokenInterface $token = null */): void
+    public function checkPostAuth(UserInterface $user, ?TokenInterface $token = null): void
     {
     }
 }
