@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\Security\Csrf\Tests;
 
-use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\RequestStack;
@@ -28,50 +27,32 @@ class CsrfTokenManagerTest extends TestCase
 {
     public function testGetNonExistingTokenEmptyNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('', $this->getEmptyNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getEmptyNamespaceMocks());
     }
 
     public function testGetNonExistingTokenHttpsNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getHttpsNamespaceMocks());
     }
 
     public function testGetNonExistingTokenCustomNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getCustomNamespaceMocks());
     }
 
     public function testGetNonExistingTokenRequestStack()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('https-', $this->getRequestStackMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getRequestStackMocks());
     }
 
     public function testGetNonExistingTokenClosure()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('generated-', $this->getClosureMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getClosureMocks());
     }
 
     public function testGetNonExistingTokenRequestStackEmptyNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertGetNonExistingToken('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertGetNonExistingToken(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertGetNonExistingToken($namespace, $manager, $storage, $generator): void
@@ -98,50 +79,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testUseExistingTokenIfAvailableEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getEmptyNamespaceMocks());
     }
 
     public function testUseExistingTokenIfAvailableHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getHttpsNamespaceMocks());
     }
 
     public function testUseExistingTokenIfAvailableCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getCustomNamespaceMocks());
     }
 
     public function testUseExistingTokenIfAvailableRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getRequestStackMocks());
     }
 
     public function testUseExistingTokenIfAvailableClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getClosureMocks());
     }
 
     public function testUseExistingTokenIfAvailableRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertUseExistingTokenIfAvailable('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertUseExistingTokenIfAvailable(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertUseExistingTokenIfAvailable($namespace, $manager, $storage): void
@@ -165,65 +128,45 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testRandomizeTheTokenEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getEmptyNamespaceMocks());
     }
 
     public function testRandomizeTheTokenHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getHttpsNamespaceMocks());
     }
 
     public function testRandomizeTheTokenCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getCustomNamespaceMocks());
     }
 
     public function testRandomizeTheTokenRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getRequestStackMocks());
     }
 
     public function testRandomizeTheTokenClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getClosureMocks());
     }
 
     public function testRandomizeTheTokenRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createStub(TokenStorageInterface::class);
-
-        $this->assertRandomizeTheToken('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertRandomizeTheToken(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertRandomizeTheToken($namespace, $manager, $storage): void
     {
+        $storage->expects($this->any())
+            ->method('hasToken')
+            ->with($namespace.'token_id')
+            ->willReturn(true);
 
-        if ($storage instanceof MockObject) {
-            $storage
-                ->method('hasToken')
-                ->with($namespace . 'token_id')
-                ->willReturn(true);
-            $storage
-                ->method('getToken')
-                ->with($namespace . 'token_id')
-                ->willReturn('TOKEN');
-        }
+        $storage->expects($this->any())
+            ->method('getToken')
+            ->with($namespace.'token_id')
+            ->willReturn('TOKEN');
 
         $values = [];
         $lengths = [];
@@ -239,50 +182,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testRefreshTokenAlwaysReturnsNewTokenEmptyNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('', $this->getEmptyNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getEmptyNamespaceMocks());
     }
 
     public function testRefreshTokenAlwaysReturnsNewTokenHttpsNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getHttpsNamespaceMocks());
     }
 
     public function testRefreshTokenAlwaysReturnsNewTokenCustomNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getCustomNamespaceMocks());
     }
 
     public function testRefreshTokenAlwaysReturnsNewTokenRequestStack()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('https-', $this->getRequestStackMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getRequestStackMocks());
     }
 
     public function testRefreshTokenAlwaysReturnsNewTokenClosure()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('generated-', $this->getClosureMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getClosureMocks());
     }
 
     public function testRefreshTokenAlwaysReturnsNewTokenRequestStackEmptyNamespace()
     {
-        $generator = $this->createMock(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRefreshTokenAlwaysReturnsNewToken('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage, $generator);
+        $this->assertRefreshTokenAlwaysReturnsNewToken(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertRefreshTokenAlwaysReturnsNewToken($namespace, $manager, $storage, $generator): void
@@ -307,50 +232,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testMatchingTokenIsValidEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getEmptyNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getHttpsNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getCustomNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getRequestStackMocks());
     }
 
     public function testMatchingTokenIsValidClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getClosureMocks());
     }
 
     public function testMatchingTokenIsValidRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValid('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValid(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertMatchingTokenIsValid($namespace, $manager, $storage)
@@ -372,50 +279,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testMatchingTokenIsValidWithLegacyTokenEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getEmptyNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidWithLegacyTokenHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getHttpsNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidWithLegacyTokenCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getCustomNamespaceMocks());
     }
 
     public function testMatchingTokenIsValidWithLegacyTokenRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getRequestStackMocks());
     }
 
     public function testMatchingTokenIsValidWithLegacyTokenClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getClosureMocks());
     }
 
     public function testMatchingTokenIsValidWithLegacyTokenRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertMatchingTokenIsValidWithLegacyToken('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertMatchingTokenIsValidWithLegacyToken(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertMatchingTokenIsValidWithLegacyToken($namespace, $manager, $storage): void
@@ -435,50 +324,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testNonMatchingTokenIsNotValidEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getEmptyNamespaceMocks());
     }
 
     public function testNonMatchingTokenIsNotValidHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getHttpsNamespaceMocks());
     }
 
     public function testNonMatchingTokenIsNotValidCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getCustomNamespaceMocks());
     }
 
     public function testNonMatchingTokenIsNotValidRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getRequestStackMocks());
     }
 
     public function testNonMatchingTokenIsNotValidClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getClosureMocks());
     }
 
     public function testNonMatchingTokenIsNotValidRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonMatchingTokenIsNotValid('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonMatchingTokenIsNotValid(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertNonMatchingTokenIsNotValid($namespace, $manager, $storage): void
@@ -498,50 +369,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testNonExistingTokenIsNotValidEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getEmptyNamespaceMocks());
     }
 
     public function testNonExistingTokenIsNotValidHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getHttpsNamespaceMocks());
     }
 
     public function testNonExistingTokenIsNotValidCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getCustomNamespaceMocks());
     }
 
     public function testNonExistingTokenIsNotValidRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getRequestStackMocks());
     }
 
     public function testNonExistingTokenIsNotValidClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getClosureMocks());
     }
 
     public function testNonExistingTokenIsNotValidRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertNonExistingTokenIsNotValid('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertNonExistingTokenIsNotValid(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertNonExistingTokenIsNotValid($namespace, $manager, $storage): void
@@ -559,8 +412,8 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testTokenShouldNotTriggerDivisionByZero()
     {
-        $storage = $this->createMock(TokenStorageInterface::class);
-        $manager = new CsrfTokenManager($this->createStub(TokenGeneratorInterface::class), $storage);
+        [$generator, $storage] = $this->getGeneratorAndStorage();
+        $manager = new CsrfTokenManager($generator, $storage);
 
         // Scenario: the token that was returned is abc.def.ghi, and gets modified in the browser to abc..ghi
 
@@ -579,50 +432,32 @@ class CsrfTokenManagerTest extends TestCase
 
     public function testRemoveTokenEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('', $this->getEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getEmptyNamespaceMocks());
     }
 
     public function testRemoveTokenHttpsNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('https-', $this->getHttpsNamespaceMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getHttpsNamespaceMocks());
     }
 
     public function testRemoveTokenCustomNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('aNamespace-', $this->getCustomNamespaceMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getCustomNamespaceMocks());
     }
 
     public function testRemoveTokenRequestStack()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('https-', $this->getRequestStackMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getRequestStackMocks());
     }
 
     public function testRemoveTokenClosure()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('generated-', $this->getClosureMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getClosureMocks());
     }
 
     public function testRemoveTokenRequestStackEmptyNamespace()
     {
-        $generator = $this->createStub(TokenGeneratorInterface::class);
-        $storage = $this->createMock(TokenStorageInterface::class);
-
-        $this->assertRemoveToken('', $this->getRequestStackWithEmptyNamespaceMocks($generator, $storage), $storage);
+        $this->assertRemoveToken(...$this->getRequestStackWithEmptyNamespaceMocks());
     }
 
     private function assertRemoveToken($namespace, $manager, $storage): void
@@ -639,50 +474,69 @@ class CsrfTokenManagerTest extends TestCase
     {
         $generator = $this->createMock(TokenGeneratorInterface::class);
         $generator->expects($this->once())->method('generateToken')->willReturn('random');
+        $storage = $this->createMock(TokenStorageInterface::class);
 
         $requestStack = new RequestStack();
         $requestStack->push(new Request([], [], [], [], [], ['HTTPS' => 'on']));
 
-        $manager = new CsrfTokenManager($generator, $this->createStub(TokenStorageInterface::class));
+        $manager = new CsrfTokenManager($generator, $storage);
 
         $token = $manager->getToken('foo');
         $this->assertSame('foo', $token->getId());
     }
 
-    private function getEmptyNamespaceMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getEmptyNamespaceMocks(): array
     {
-        return new CsrfTokenManager($generator, $storage, '');
+        [$generator, $storage] = $this->getGeneratorAndStorage();
+
+        return ['', new CsrfTokenManager($generator, $storage, ''), $storage, $generator];
     }
 
-    private function getHttpsNamespaceMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getHttpsNamespaceMocks(): array
     {
-        return new CsrfTokenManager($generator, $storage);
+        [$generator, $storage] = $this->getGeneratorAndStorage();
+
+        return ['https-', new CsrfTokenManager($generator, $storage), $storage, $generator];
     }
 
-    private function getCustomNamespaceMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getCustomNamespaceMocks(): array
     {
-        return new CsrfTokenManager($generator, $storage, 'aNamespace-');
+        [$generator, $storage] = $this->getGeneratorAndStorage();
+
+        return ['aNamespace-', new CsrfTokenManager($generator, $storage, 'aNamespace-'), $storage, $generator];
     }
 
-    private function getRequestStackMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getRequestStackMocks(): array
     {
         $requestStack = new RequestStack();
         $requestStack->push(new Request([], [], [], [], [], ['HTTPS' => 'on']));
+        [$generator, $storage] = $this->getGeneratorAndStorage();
 
-        return new CsrfTokenManager($generator, $storage, $requestStack);
+        return ['https-', new CsrfTokenManager($generator, $storage, $requestStack), $storage, $generator];
     }
 
-    private function getClosureMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getClosureMocks(): array
     {
-        return new CsrfTokenManager($generator, $storage, fn () => 'generated-');
+        [$generator, $storage] = $this->getGeneratorAndStorage();
+
+        return ['generated-', new CsrfTokenManager($generator, $storage, fn () => 'generated-'), $storage, $generator];
     }
 
-    private function getRequestStackWithEmptyNamespaceMocks(TokenGeneratorInterface $generator, TokenStorageInterface $storage): CsrfTokenManager
+    private function getRequestStackWithEmptyNamespaceMocks(): array
     {
         $requestStack = new RequestStack();
         $requestStack->push(new Request());
+        [$generator, $storage] = $this->getGeneratorAndStorage();
 
-        return new CsrfTokenManager($generator, $storage, $requestStack);
+        return ['', new CsrfTokenManager($generator, $storage, $requestStack), $storage, $generator];
+    }
+
+    private function getGeneratorAndStorage(): array
+    {
+        return [
+            $this->createMock(TokenGeneratorInterface::class),
+            $this->createMock(TokenStorageInterface::class),
+        ];
     }
 
     protected function setUp(): void
