@@ -20,13 +20,10 @@ use Symfony\Contracts\EventDispatcher\Event;
  */
 final class InteractiveLoginEvent extends Event
 {
-    private $request;
-    private $authenticationToken;
-
-    public function __construct(Request $request, TokenInterface $authenticationToken)
-    {
-        $this->request = $request;
-        $this->authenticationToken = $authenticationToken;
+    public function __construct(
+        private Request $request,
+        private TokenInterface $authenticationToken,
+    ) {
     }
 
     public function getRequest(): Request
