@@ -11,24 +11,23 @@
 
 namespace Symfony\Component\Security\Http\Tests\EventListener;
 
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpFoundation\Request;
-use Symfony\Component\HttpFoundation\Session\Session;
-use Symfony\Component\HttpFoundation\Session\Storage\MockArraySessionStorage;
+use Symfony\Component\HttpFoundation\Session\SessionInterface;
 use Symfony\Component\Security\Core\Authentication\Token\NullToken;
-use Symfony\Component\Security\Core\Authentication\Token\PreAuthenticatedToken;
 use Symfony\Component\Security\Core\Authentication\Token\UsernamePasswordToken;
 use Symfony\Component\Security\Core\User\InMemoryUser;
+use Symfony\Component\Security\Http\Authenticator\AuthenticatorInterface;
 use Symfony\Component\Security\Http\Authenticator\Passport\Badge\UserBadge;
 use Symfony\Component\Security\Http\Authenticator\Passport\SelfValidatingPassport;
 use Symfony\Component\Security\Http\Event\LoginSuccessEvent;
 use Symfony\Component\Security\Http\EventListener\SessionStrategyListener;
 use Symfony\Component\Security\Http\Session\SessionAuthenticationStrategyInterface;
-use Symfony\Component\Security\Http\Tests\Fixtures\DummyAuthenticator;
 
 class SessionStrategyListenerTest extends TestCase
 {
-    private SessionAuthenticationStrategyInterface $sessionAuthenticationStrategy;
+    private MockObject&SessionAuthenticationStrategyInterface $sessionAuthenticationStrategy;
     private SessionStrategyListener $listener;
     private Request $request;
     private NullToken $token;
@@ -38,7 +37,7 @@ class SessionStrategyListenerTest extends TestCase
         $this->sessionAuthenticationStrategy = $this->createMock(SessionAuthenticationStrategyInterface::class);
         $this->listener = new SessionStrategyListener($this->sessionAuthenticationStrategy);
         $this->request = new Request();
-        $this->token = new NullToken();
+        $this->token = $this->createMock(NullToken::class);
     }
 
     public function testRequestWithSession()
@@ -70,10 +69,16 @@ class SessionStrategyListenerTest extends TestCase
         $this->configurePreviousSession();
         $this->sessionAuthenticationStrategy->expects($this->never())->method('onAuthentication');
 
-        $token = new UsernamePasswordToken(new InMemoryUser('test', 'password'), 'main');
-        $previousToken = new UsernamePasswordToken(new InMemoryUser('test', 'password'), 'main');
+        $token = $this->createMock(NullToken::class);
+        $token->expects($this->once())
+            ->method('getUserIdentifier')
+            ->willReturn('test');
+        $previousToken = $this->createMock(NullToken::class);
+        $previousToken->expects($this->once())
+            ->method('getUserIdentifier')
+            ->willReturn('test');
 
-        $event = new LoginSuccessEvent(new DummyAuthenticator(), new SelfValidatingPassport(new UserBadge('test', function () {})), $token, $this->request, null, 'main_firewall', $previousToken);
+        $event = new LoginSuccessEvent($this->createMock(AuthenticatorInterface::class), new SelfValidatingPassport(new UserBadge('test', function () {})), $token, $this->request, null, 'main_firewall', $previousToken);
 
         $this->listener->onSuccessfulLogin($event);
     }
@@ -82,25 +87,33 @@ class SessionStrategyListenerTest extends TestCase
     {
         $this->configurePreviousSession();
 
-        $token = new PreAuthenticatedToken(new InMemoryUser('test', 'password'), 'main');
-        $previousToken = new UsernamePasswordToken(new InMemoryUser('test', 'password'), 'main');
+        $token = $this->createMock(NullToken::class);
+        $token->expects($this->once())
+            ->method('getUserIdentifier')
+            ->willReturn('test');
+        $previousToken = $this->createMock(UsernamePasswordToken::class);
+        $previousToken->expects($this->once())
+            ->method('getUserIdentifier')
+            ->willReturn('test');
 
         $this->sessionAuthenticationStrategy->expects($this->once())->method('onAuthentication')->with($this->request, $token);
 
-        $event = new LoginSuccessEvent(new DummyAuthenticator(), new SelfValidatingPassport(new UserBadge('test', function () {})), $token, $this->request, null, 'main_firewall', $previousToken);
+        $event = new LoginSuccessEvent($this->createMock(AuthenticatorInterface::class), new SelfValidatingPassport(new UserBadge('test', function () {})), $token, $this->request, null, 'main_firewall', $previousToken);
 
         $this->listener->onSuccessfulLogin($event);
     }
 
     private function createEvent($firewallName)
     {
-        return new LoginSuccessEvent(new DummyAuthenticator(), new SelfValidatingPassport(new UserBadge('test', fn ($username) => new InMemoryUser($username, null))), $this->token, $this->request, null, $firewallName);
+        return new LoginSuccessEvent($this->createMock(AuthenticatorInterface::class), new SelfValidatingPassport(new UserBadge('test', fn ($username) => new InMemoryUser($username, null))), $this->token, $this->request, null, $firewallName);
     }
 
     private function configurePreviousSession()
     {
-        $sessionStorage = new MockArraySessionStorage('test_session_name');
-        $session = new Session($sessionStorage);
+        $session = $this->createMock(SessionInterface::class);
+        $session->expects($this->any())
+            ->method('getName')
+            ->willReturn('test_session_name');
         $this->request->setSession($session);
         $this->request->cookies->set('test_session_name', 'session_cookie_val');
     }
