@@ -11,11 +11,11 @@
 
 namespace Symfony\Component\Security\Http\Tests\RememberMe;
 
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpFoundation\Cookie;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpFoundation\RequestStack;
-use Symfony\Component\Security\Core\Authentication\RememberMe\InMemoryTokenProvider;
 use Symfony\Component\Security\Core\Authentication\RememberMe\PersistentToken;
 use Symfony\Component\Security\Core\Authentication\RememberMe\TokenProviderInterface;
 use Symfony\Component\Security\Core\Authentication\RememberMe\TokenVerifierInterface;
@@ -29,41 +29,41 @@ use Symfony\Component\Security\Http\RememberMe\ResponseListener;
 
 class PersistentRememberMeHandlerTest extends TestCase
 {
-    private TokenProviderInterface $tokenProvider;
+    private MockObject&TokenProviderInterface $tokenProvider;
     private InMemoryUserProvider $userProvider;
     private RequestStack $requestStack;
     private Request $request;
+    private PersistentRememberMeHandler $handler;
 
     protected function setUp(): void
     {
-        $this->tokenProvider = new InMemoryTokenProvider();
+        $this->tokenProvider = $this->createMock(TokenProviderInterface::class);
         $this->userProvider = new InMemoryUserProvider();
         $this->userProvider->createUser(new InMemoryUser('wouter', null));
         $this->requestStack = new RequestStack();
         $this->request = Request::create('/login');
         $this->requestStack->push($this->request);
+        $this->handler = new PersistentRememberMeHandler($this->tokenProvider, $this->userProvider, $this->requestStack, []);
     }
 
     public function testCreateRememberMeCookie()
     {
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider->expects($this->once())
+        $this->tokenProvider->expects($this->once())
             ->method('createNewToken')
             ->with($this->callback(fn ($token) => $token instanceof PersistentToken && 'wouter' === $token->getUserIdentifier()));
 
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->createRememberMeCookie(new InMemoryUser('wouter', null));
+        $this->handler->createRememberMeCookie(new InMemoryUser('wouter', null));
     }
 
     public function testClearRememberMeCookie()
     {
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider->expects($this->once())
+        $this->tokenProvider->expects($this->once())
             ->method('deleteTokenBySeries')
             ->with('series1');
 
-        $this->request->cookies->set('REMEMBERME', (new RememberMeDetails(InMemoryUser::class, 'wouter', 0, 'series1:tokenvalue', false))->toString());
+        $this->request->cookies->set('REMEMBERME', (new RememberMeDetails('wouter', 0, 'series1:tokenvalue'))->toString());
 
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->clearRememberMeCookie();
+        $this->handler->clearRememberMeCookie();
 
         $this->assertTrue($this->request->attributes->has(ResponseListener::COOKIE_ATTR_NAME));
 
@@ -74,13 +74,12 @@ class PersistentRememberMeHandlerTest extends TestCase
 
     public function testClearRememberMeCookieMalformedCookie()
     {
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider->expects($this->exactly(0))
+        $this->tokenProvider->expects($this->exactly(0))
             ->method('deleteTokenBySeries');
 
         $this->request->cookies->set('REMEMBERME', 'malformed');
 
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->clearRememberMeCookie();
+        $this->handler->clearRememberMeCookie();
 
         $this->assertTrue($this->request->attributes->has(ResponseListener::COOKIE_ATTR_NAME));
 
@@ -97,18 +96,16 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', $lastUsed = new \DateTimeImmutable('-10 min'));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
-            ->willReturnMap([
-                ['series1', $persistentToken],
-            ])
+            ->with('series1')
+            ->willReturn($persistentToken)
         ;
 
-        $tokenProvider->expects($this->once())->method('updateToken')->with('series1');
+        $this->tokenProvider->expects($this->once())->method('updateToken')->with('series1');
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue', false);
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie($rememberMeDetails);
+        $rememberMeDetails = new RememberMeDetails('wouter', 360, 'series1:tokenvalue');
+        $this->handler->consumeRememberMeCookie($rememberMeDetails);
 
         // assert that the cookie has been updated with a new base64 encoded token value
         $this->assertTrue($this->request->attributes->has(ResponseListener::COOKIE_ATTR_NAME));
@@ -133,19 +130,17 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('-10 min'));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
-            ->expects($this->once())
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
             ->with('series1')
             ->willReturn($persistentToken)
         ;
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'jeremy', 360, 'series1:tokenvalue', false);
+        $rememberMeDetails = new RememberMeDetails('jeremy', 360, 'series1:tokenvalue');
 
         $this->expectException(AuthenticationException::class);
         $this->expectExceptionMessage('The cookie\'s hash is invalid.');
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie($rememberMeDetails);
+        $this->handler->consumeRememberMeCookie($rememberMeDetails);
     }
 
     public function testConsumeRememberMeCookieInvalidValue()
@@ -156,13 +151,17 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('-10 min'));
         }
 
-        $this->tokenProvider->createNewToken($persistentToken);
+        $this->tokenProvider->expects($this->any())
+            ->method('loadTokenBySeries')
+            ->with('series1')
+            ->willReturn($persistentToken)
+        ;
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue:somethingelse', false);
+        $rememberMeDetails = new RememberMeDetails('wouter', 360, 'series1:tokenvalue:somethingelse');
 
         $this->expectException(AuthenticationException::class);
         $this->expectExceptionMessage('This token was already used. The account is possibly compromised.');
-        (new PersistentRememberMeHandler($this->tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie($rememberMeDetails);
+        $this->handler->consumeRememberMeCookie($rememberMeDetails);
     }
 
     public function testConsumeRememberMeCookieValidByValidatorWithoutUpdate()
@@ -176,16 +175,19 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('30 seconds'));
         }
 
-        $this->tokenProvider->createNewToken($persistentToken);
+        $this->tokenProvider->expects($this->any())
+            ->method('loadTokenBySeries')
+            ->with('series1')
+            ->willReturn($persistentToken)
+        ;
 
-        $verifier
-            ->expects($this->once())
+        $verifier->expects($this->any())
             ->method('verifyToken')
             ->with($persistentToken, 'oldTokenValue')
             ->willReturn(true)
         ;
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:oldTokenValue', false);
+        $rememberMeDetails = new RememberMeDetails('wouter', 360, 'series1:oldTokenValue');
         $handler->consumeRememberMeCookie($rememberMeDetails);
 
         $this->assertFalse($this->request->attributes->has(ResponseListener::COOKIE_ATTR_NAME));
@@ -199,18 +201,16 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue1', new \DateTimeImmutable('-10 min'));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
-            ->willReturnMap([
-                ['series1', $persistentToken],
-            ]);
+            ->with('series1')
+            ->willReturn($persistentToken);
 
-        $tokenProvider->expects($this->never())->method('updateToken')->with('series1');
+        $this->tokenProvider->expects($this->never())->method('updateToken')->with('series1');
 
         $this->expectException(CookieTheftException::class);
 
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie(new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue', false));
+        $this->handler->consumeRememberMeCookie(new RememberMeDetails('wouter', 360, 'series1:tokenvalue'));
     }
 
     public function testConsumeRememberMeCookieExpired()
@@ -221,19 +221,17 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('@'.(time() - (31536000 + 1))));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
-            ->willReturnMap([
-                ['series1', $persistentToken],
-            ]);
+            ->with('series1')
+            ->willReturn($persistentToken);
 
-        $tokenProvider->expects($this->never())->method('updateToken')->with('series1');
+        $this->tokenProvider->expects($this->never())->method('updateToken')->with('series1');
 
         $this->expectException(AuthenticationException::class);
         $this->expectExceptionMessage('The cookie has expired.');
 
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie(new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue', false));
+        $this->handler->consumeRememberMeCookie(new RememberMeDetails('wouter', 360, 'series1:tokenvalue'));
     }
 
     public function testBase64EncodedTokens()
@@ -244,21 +242,19 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('-10 min'));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
-            ->willReturnMap([
-                ['series1', $persistentToken],
-            ])
+            ->with('series1')
+            ->willReturn($persistentToken)
         ;
 
-        $tokenProvider->expects($this->once())->method('updateToken')->with('series1');
+        $this->tokenProvider->expects($this->once())->method('updateToken')->with('series1');
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue', false);
+        $rememberMeDetails = new RememberMeDetails('wouter', 360, 'series1:tokenvalue');
         $cookieData = explode(RememberMeDetails::COOKIE_DELIMITER, $rememberMeDetails->toString());
         $cookieData[0] = '';
         $rememberMeDetails = RememberMeDetails::fromRawCookie(base64_encode(implode(RememberMeDetails::COOKIE_DELIMITER, $cookieData)));
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie($rememberMeDetails);
+        $this->handler->consumeRememberMeCookie($rememberMeDetails);
     }
 
     public function testBase64EncodedTokensLegacyFormat()
@@ -269,18 +265,16 @@ class PersistentRememberMeHandlerTest extends TestCase
             $persistentToken = new PersistentToken('wouter', 'series1', 'tokenvalue', new \DateTimeImmutable('-10 min'));
         }
 
-        $tokenProvider = $this->createMock(TokenProviderInterface::class);
-        $tokenProvider
+        $this->tokenProvider->expects($this->any())
             ->method('loadTokenBySeries')
-            ->willReturnMap([
-                ['series1', $persistentToken],
-            ])
+            ->with('series1')
+            ->willReturn($persistentToken)
         ;
 
-        $tokenProvider->expects($this->once())->method('updateToken')->with('series1');
+        $this->tokenProvider->expects($this->once())->method('updateToken')->with('series1');
 
-        $rememberMeDetails = new RememberMeDetails(InMemoryUser::class, 'wouter', 360, 'series1:tokenvalue', false);
-        $rememberMeDetails = RememberMeDetails::fromRawCookie(base64_encode($rememberMeDetails->toString()));
-        (new PersistentRememberMeHandler($tokenProvider, $this->userProvider, $this->requestStack, []))->consumeRememberMeCookie($rememberMeDetails);
+        $rememberMeDetails = new RememberMeDetails('wouter', 360, 'series1:tokenvalue');
+        $rememberMeDetails = RememberMeDetails::fromRawCookie(base64_encode(strtr(InMemoryUser::class, '\\', '.').$rememberMeDetails->toString()));
+        $this->handler->consumeRememberMeCookie($rememberMeDetails);
     }
 }
