@@ -33,8 +33,6 @@ use Symfony\Component\Serializer\Mapping\ClassMetadataInterface;
  */
 class AttributeLoader implements LoaderInterface
 {
-    use AccessorCollisionResolverTrait;
-
     private const KNOWN_ATTRIBUTES = [
         DiscriminatorMap::class,
         Groups::class,
@@ -46,14 +44,12 @@ class AttributeLoader implements LoaderInterface
     ];
 
     /**
-     * @param bool|null                           $allowAnyClass Null is allowed for BC with Symfony <= 6
      * @param array<class-string, class-string[]> $mappedClasses
      */
     public function __construct(
-        private ?bool $allowAnyClass = true,
+        private bool $allowAnyClass = true,
         private array $mappedClasses = [],
     ) {
-        $this->allowAnyClass ??= true;
     }
 
     /**
@@ -140,21 +136,14 @@ class AttributeLoader implements LoaderInterface
             if ($method->getDeclaringClass()->name !== $className) {
                 continue;
             }
-            $name = $method->name;
 
-            if (0 === stripos($name, 'get') && $method->getNumberOfRequiredParameters()) {
+            if (0 === stripos($method->name, 'get') && $method->getNumberOfRequiredParameters()) {
                 continue; /*  matches the BC behavior in `Symfony\Component\Serializer\Normalizer\ObjectNormalizer::extractAttributes` */
             }
 
-            $attributeName = $this->getAttributeNameFromAccessor($reflectionClass, $method, true);
-            $accessorOrMutator = null !== $attributeName;
-            $hasProperty = $this->hasPropertyForAccessor($method->getDeclaringClass(), $name);
-            $attributeMetadata = null;
-
-            if ($hasProperty || $accessorOrMutator) {
-                if (null === $attributeName || 's' !== $name[0] && $hasProperty && $this->hasAttributeNameCollision($reflectionClass, $attributeName, $name)) {
-                    $attributeName = $name;
-                }
+            $accessorOrMutator = preg_match('/^(get|is|has|set|can)(.+)$/i', $method->name, $matches);
+            if ($accessorOrMutator && !ctype_lower($matches[2][0])) {
+                $attributeName = lcfirst($matches[2]);
 
                 if (isset($attributesMetadata[$attributeName])) {
                     $attributeMetadata = $attributesMetadata[$attributeName];
@@ -166,38 +155,38 @@ class AttributeLoader implements LoaderInterface
 
             foreach ($this->loadAttributes($method) as $attribute) {
                 if ($attribute instanceof Groups) {
-                    if (!$attributeMetadata) {
-                        throw new MappingException(\sprintf('Groups on "%s::%s()" cannot be added. Groups can only be added on methods beginning with "get", "is", "has", "can" or "set".', $className, $method->name));
+                    if (!$accessorOrMutator) {
+                        throw new MappingException(\sprintf('Groups on "%s::%s()" cannot be added. Groups can only be added on methods beginning with "get", "is", "has" or "set".', $className, $method->name));
                     }
 
                     foreach ($attribute->groups as $group) {
                         $attributeMetadata->addGroup($group);
                     }
                 } elseif ($attribute instanceof MaxDepth) {
-                    if (!$attributeMetadata) {
-                        throw new MappingException(\sprintf('MaxDepth on "%s::%s()" cannot be added. MaxDepth can only be added on methods beginning with "get", "is", "has", "can" or "set".', $className, $method->name));
+                    if (!$accessorOrMutator) {
+                        throw new MappingException(\sprintf('MaxDepth on "%s::%s()" cannot be added. MaxDepth can only be added on methods beginning with "get", "is", "has" or "set".', $className, $method->name));
                     }
 
                     $attributeMetadata->setMaxDepth($attribute->maxDepth);
                 } elseif ($attribute instanceof SerializedName) {
-                    if (!$attributeMetadata) {
-                        throw new MappingException(\sprintf('SerializedName on "%s::%s()" cannot be added. SerializedName can only be added on methods beginning with "get", "is", "has", "can" or "set".', $className, $method->name));
+                    if (!$accessorOrMutator) {
+                        throw new MappingException(\sprintf('SerializedName on "%s::%s()" cannot be added. SerializedName can only be added on methods beginning with "get", "is", "has" or "set".', $className, $method->name));
                     }
 
                     $attributeMetadata->setSerializedName($attribute->serializedName);
                 } elseif ($attribute instanceof SerializedPath) {
-                    if (!$attributeMetadata) {
-                        throw new MappingException(\sprintf('SerializedPath on "%s::%s()" cannot be added. SerializedPath can only be added on methods beginning with "get", "is", "has", "can" or "set".', $className, $method->name));
+                    if (!$accessorOrMutator) {
+                        throw new MappingException(\sprintf('SerializedPath on "%s::%s()" cannot be added. SerializedPath can only be added on methods beginning with "get", "is", "has" or "set".', $className, $method->name));
                     }
 
                     $attributeMetadata->setSerializedPath($attribute->serializedPath);
                 } elseif ($attribute instanceof Ignore) {
-                    if ($attributeMetadata) {
+                    if ($accessorOrMutator) {
                         $attributeMetadata->setIgnore(true);
                     }
                 } elseif ($attribute instanceof Context) {
-                    if (!$attributeMetadata) {
-                        throw new MappingException(\sprintf('Context on "%s::%s()" cannot be added. Context can only be added on methods beginning with "get", "is", "has", "can" or "set".', $className, $method->name));
+                    if (!$accessorOrMutator) {
+                        throw new MappingException(\sprintf('Context on "%s::%s()" cannot be added. Context can only be added on methods beginning with "get", "is", "has" or "set".', $className, $method->name));
                     }
 
                     $this->setAttributeContextsForGroups($attribute, $attributeMetadata);
