@@ -12,23 +12,14 @@
 namespace Symfony\Component\Serializer\Tests\Normalizer;
 
 use PHPStan\PhpDocParser\Parser\PhpDocParser;
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
-use PHPUnit\Framework\Attributes\RequiresMethod;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\PropertyAccess\Exception\InvalidTypeException;
 use Symfony\Component\PropertyAccess\PropertyAccessorBuilder;
-use Symfony\Component\PropertyAccess\PropertyAccessorInterface;
 use Symfony\Component\PropertyInfo\Extractor\PhpDocExtractor;
 use Symfony\Component\PropertyInfo\Extractor\PhpStanExtractor;
 use Symfony\Component\PropertyInfo\Extractor\ReflectionExtractor;
 use Symfony\Component\PropertyInfo\PropertyInfoExtractor;
-use Symfony\Component\PropertyInfo\PropertyInfoExtractorInterface;
-use Symfony\Component\PropertyInfo\PropertyTypeExtractorInterface;
-use Symfony\Component\PropertyInfo\Type as LegacyType;
-use Symfony\Component\Serializer\Attribute\Groups;
 use Symfony\Component\Serializer\Attribute\Ignore;
-use Symfony\Component\Serializer\Exception\ExtraAttributesException;
 use Symfony\Component\Serializer\Exception\LogicException;
 use Symfony\Component\Serializer\Exception\NotNormalizableValueException;
 use Symfony\Component\Serializer\Exception\RuntimeException;
@@ -38,19 +29,17 @@ use Symfony\Component\Serializer\Mapping\Factory\ClassMetadataFactory;
 use Symfony\Component\Serializer\Mapping\Factory\ClassMetadataFactoryInterface;
 use Symfony\Component\Serializer\Mapping\Loader\AttributeLoader;
 use Symfony\Component\Serializer\Mapping\Loader\YamlFileLoader;
-use Symfony\Component\Serializer\NameConverter\AdvancedNameConverterInterface;
 use Symfony\Component\Serializer\NameConverter\CamelCaseToSnakeCaseNameConverter;
 use Symfony\Component\Serializer\NameConverter\MetadataAwareNameConverter;
+use Symfony\Component\Serializer\NameConverter\NameConverterInterface;
 use Symfony\Component\Serializer\Normalizer\AbstractNormalizer;
 use Symfony\Component\Serializer\Normalizer\ArrayDenormalizer;
 use Symfony\Component\Serializer\Normalizer\DateTimeNormalizer;
-use Symfony\Component\Serializer\Normalizer\DenormalizerInterface;
 use Symfony\Component\Serializer\Normalizer\NormalizerInterface;
 use Symfony\Component\Serializer\Normalizer\ObjectNormalizer;
 use Symfony\Component\Serializer\Serializer;
 use Symfony\Component\Serializer\SerializerInterface;
 use Symfony\Component\Serializer\Tests\Fixtures\Attributes\GroupDummy;
-use Symfony\Component\Serializer\Tests\Fixtures\Attributes\GroupDummyWithIsPrefixedProperty;
 use Symfony\Component\Serializer\Tests\Fixtures\CircularReferenceDummy;
 use Symfony\Component\Serializer\Tests\Fixtures\DummyPrivatePropertyWithoutGetter;
 use Symfony\Component\Serializer\Tests\Fixtures\DummyWithUnion;
@@ -60,7 +49,6 @@ use Symfony\Component\Serializer\Tests\Fixtures\Php74DummyPrivate;
 use Symfony\Component\Serializer\Tests\Fixtures\Php80Dummy;
 use Symfony\Component\Serializer\Tests\Fixtures\SiblingHolder;
 use Symfony\Component\Serializer\Tests\Fixtures\StdClassNormalizer;
-use Symfony\Component\Serializer\Tests\Fixtures\VoidNeverReturnTypeDummy;
 use Symfony\Component\Serializer\Tests\Normalizer\Features\AttributesTestTrait;
 use Symfony\Component\Serializer\Tests\Normalizer\Features\CacheableObjectAttributesTestTrait;
 use Symfony\Component\Serializer\Tests\Normalizer\Features\CallbacksTestTrait;
@@ -195,29 +183,6 @@ class ObjectNormalizerTest extends TestCase
         );
     }
 
-    public function testNormalizeWithDisabledMagicMethodsExtractionInContext()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $propertyInfoExtractor = $this->createMock(PropertyInfoExtractorInterface::class);
-        $propertyInfoExtractor
-            ->expects($this->once())
-            ->method('isReadable')
-            ->with(ObjectWithGroupedMagicGetPrivateProperty::class, 'foo', ['enable_magic_methods_extraction' => 0])
-            ->willReturn(false);
-        $propertyAccessor = $this->createMock(PropertyAccessorInterface::class);
-        $propertyAccessor
-            ->expects($this->once())
-            ->method('isReadable')
-            ->with($this->isInstanceOf(ObjectWithGroupedMagicGetPrivateProperty::class), 'foo')
-            ->willReturn(false);
-        $normalizer = new ObjectNormalizer($classMetadataFactory, null, $propertyAccessor, null, null, null, [], $propertyInfoExtractor);
-
-        $this->assertSame([], $normalizer->normalize(new ObjectWithGroupedMagicGetPrivateProperty(), null, [
-            'groups' => ['read'],
-            'enable_magic_methods_extraction' => 0,
-        ]));
-    }
-
     public function testNormalizeObjectWithUninitializedPrivateProperties()
     {
         $obj = new Php74DummyPrivate();
@@ -329,7 +294,7 @@ class ObjectNormalizerTest extends TestCase
 
     public function testConstructorWithObjectDenormalizeUsingPropertyInfoExtractor()
     {
-        $serializer = $this->createStub(ObjectSerializerNormalizer::class);
+        $serializer = $this->createMock(ObjectSerializerNormalizer::class);
         $normalizer = new ObjectNormalizer(null, null, null, null, null, null, [], new PropertyInfoExtractor());
         $normalizer->setSerializer($serializer);
 
@@ -343,134 +308,6 @@ class ObjectNormalizerTest extends TestCase
         $this->assertEquals('bar', $obj->bar);
     }
 
-    #[RequiresMethod(Type::class, 'list')]
-    public function testConstructorParameterTypeIsUsedWhenPropertyTypeExtractorReturnsDifferentType()
-    {
-        $propertyInfoExtractor = new class implements PropertyInfoExtractorInterface {
-            public function getType(string $class, string $property, array $context = []): ?Type
-            {
-                if (SerializerConstructorTypeConversionDummy::class === $class && 'attributes' === $property) {
-                    return Type::list(Type::string());
-                }
-
-                return null;
-            }
-
-            public function getTypes(string $class, string $property, array $context = []): ?array
-            {
-                return null;
-            }
-
-            public function getProperties(string $class, array $context = []): ?array
-            {
-                return null;
-            }
-
-            public function isReadable(string $class, string $property, array $context = []): ?bool
-            {
-                return null;
-            }
-
-            public function isWritable(string $class, string $property, array $context = []): ?bool
-            {
-                return !(SerializerConstructorTypeConversionDummy::class === $class && 'attributes' === $property);
-            }
-
-            public function getShortDescription(string $class, string $property, array $context = []): ?string
-            {
-                return null;
-            }
-
-            public function getLongDescription(string $class, string $property, array $context = []): ?string
-            {
-                return null;
-            }
-        };
-
-        $normalizer = new ObjectNormalizer(null, null, null, $propertyInfoExtractor, null, null, [], $propertyInfoExtractor);
-        $serializer = new Serializer([$normalizer]);
-        $normalizer->setSerializer($serializer);
-
-        $obj = $normalizer->denormalize(
-            ['attributes' => 'displayName,userName'],
-            SerializerConstructorTypeConversionDummy::class,
-            'csv',
-            [DenormalizerInterface::COLLECT_DENORMALIZATION_ERRORS => true]
-        );
-
-        $this->assertInstanceOf(SerializerConstructorTypeConversionDummy::class, $obj);
-        $this->assertFalse($obj->isAttributeAllowed('displayName'));
-        $this->assertFalse($obj->isAttributeAllowed('userName'));
-    }
-
-    #[Group('legacy')]
-    #[IgnoreDeprecations]
-    public function testConstructorParameterTypeIsUsedWhenLegacyPropertyTypeExtractorReturnsDifferentType()
-    {
-        $propertyTypeExtractor = new class implements PropertyTypeExtractorInterface {
-            public function getTypes(string $class, string $property, array $context = []): ?array
-            {
-                if (SerializerConstructorTypeConversionDummy::class === $class && 'attributes' === $property) {
-                    return [new LegacyType(LegacyType::BUILTIN_TYPE_ARRAY, false, null, true, new LegacyType(LegacyType::BUILTIN_TYPE_INT), new LegacyType(LegacyType::BUILTIN_TYPE_STRING))];
-                }
-
-                return null;
-            }
-        };
-
-        $propertyInfoExtractor = new class implements PropertyInfoExtractorInterface {
-            public function getType(string $class, string $property, array $context = []): ?Type
-            {
-                return null;
-            }
-
-            public function getTypes(string $class, string $property, array $context = []): ?array
-            {
-                return null;
-            }
-
-            public function getProperties(string $class, array $context = []): ?array
-            {
-                return null;
-            }
-
-            public function isReadable(string $class, string $property, array $context = []): ?bool
-            {
-                return null;
-            }
-
-            public function isWritable(string $class, string $property, array $context = []): ?bool
-            {
-                return !(SerializerConstructorTypeConversionDummy::class === $class && 'attributes' === $property);
-            }
-
-            public function getShortDescription(string $class, string $property, array $context = []): ?string
-            {
-                return null;
-            }
-
-            public function getLongDescription(string $class, string $property, array $context = []): ?string
-            {
-                return null;
-            }
-        };
-
-        $normalizer = new ObjectNormalizer(null, null, null, $propertyTypeExtractor, null, null, [], $propertyInfoExtractor);
-        $serializer = new Serializer([$normalizer]);
-        $normalizer->setSerializer($serializer);
-
-        $obj = $normalizer->denormalize(
-            ['attributes' => 'displayName,userName'],
-            SerializerConstructorTypeConversionDummy::class,
-            'csv',
-            [DenormalizerInterface::COLLECT_DENORMALIZATION_ERRORS => true]
-        );
-
-        $this->assertInstanceOf(SerializerConstructorTypeConversionDummy::class, $obj);
-        $this->assertFalse($obj->isAttributeAllowed('displayName'));
-        $this->assertFalse($obj->isAttributeAllowed('userName'));
-    }
-
     public function testConstructorWithObjectTypeHintDenormalize()
     {
         $data = [
@@ -539,12 +376,7 @@ class ObjectNormalizerTest extends TestCase
         $normalizer = new ObjectNormalizer(new ClassMetadataFactory(new AttributeLoader()), null, null, new PropertyInfoExtractor([], [new ReflectionExtractor()]));
 
         $this->expectException(NotNormalizableValueException::class);
-
-        if (class_exists(Type::class) && method_exists(PropertyInfoExtractor::class, 'getType')) {
-            $this->expectExceptionMessage('The type of the "value" attribute for class "Symfony\Component\Serializer\Tests\Fixtures\DummyWithUnion" must be one of "float", "int" ("string" given).');
-        } else {
-            $this->expectExceptionMessage('The type of the "value" attribute for class "Symfony\Component\Serializer\Tests\Fixtures\DummyWithUnion" must be one of "int", "float" ("string" given).');
-        }
+        $this->expectExceptionMessage('The type of the "value" attribute for class "Symfony\Component\Serializer\Tests\Fixtures\DummyWithUnion" must be one of "float", "int" ("string" given).');
 
         $normalizer->denormalize($data, DummyWithUnion::class, 'xml', [
             AbstractNormalizer::ALLOW_EXTRA_ATTRIBUTES => false,
@@ -855,7 +687,7 @@ class ObjectNormalizerTest extends TestCase
 
     public function testUnableToNormalizeObjectAttribute()
     {
-        $serializer = $this->createStub(SerializerInterface::class);
+        $serializer = $this->createMock(SerializerInterface::class);
         $this->normalizer->setSerializer($serializer);
 
         $obj = new ObjectDummy();
@@ -886,13 +718,6 @@ class ObjectNormalizerTest extends TestCase
         $this->assertEquals(['foo' => 'K'], $this->normalizer->normalize(new ObjectWithStaticPropertiesAndMethods()));
     }
 
-    public function testNormalizeStaticWithGroups()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $this->createNormalizer([], $classMetadataFactory);
-        $this->assertEquals(['baz' => 'L'], $this->normalizer->normalize(new ObjectWithStaticMethodWithGroups(), null, [AbstractNormalizer::GROUPS => ['test']]));
-    }
-
     public function testNormalizeUpperCaseAttributes()
     {
         $this->assertEquals(['Foo' => 'Foo', 'Bar' => 'BarBar'], $this->normalizer->normalize(new ObjectWithUpperCaseAttributeNames()));
@@ -952,7 +777,7 @@ class ObjectNormalizerTest extends TestCase
 
     public function testDoesntHaveIssuesWithUnionConstTypes()
     {
-        if (!class_exists(PhpStanExtractor::class) || !class_exists(PhpDocParser::class)) {
+        if (!class_exists(PhpDocParser::class)) {
             $this->markTestSkipped('phpstan/phpdoc-parser required for this test');
         }
 
@@ -995,9 +820,9 @@ class ObjectNormalizerTest extends TestCase
         $this->assertFalse($object->canBeFalseOrString);
     }
 
-    public function testAdvancedNameConverter()
+    public function testNameConverterProperties()
     {
-        $nameConverter = new class implements AdvancedNameConverterInterface {
+        $nameConverter = new class implements NameConverterInterface {
             public function normalize(string $propertyName, ?string $class = null, ?string $format = null, array $context = []): string
             {
                 return \sprintf('%s-%s-%s-%s', $propertyName, $class, $format, $context['foo']);
@@ -1309,40 +1134,8 @@ class ObjectNormalizerTest extends TestCase
 
         $this->assertSame([
             'foo' => 'foo',
-        ], $normalized);
-    }
-
-    public function testNormalizeObjectWithMethodSameNameAsProperty()
-    {
-        $normalizer = new ObjectNormalizer(new ClassMetadataFactory(new AttributeLoader()));
-
-        $object = new ObjectWithMethodSameNameThanProperty(true);
-
-        $this->assertSame(['shouldDoThing' => true], $normalizer->normalize($object));
-        $this->assertSame(['shouldDoThing' => true], $normalizer->normalize($object, null, ['groups' => 'foo']));
-        $this->assertSame([], $normalizer->normalize($object, null, ['groups' => 'bar']));
-    }
-
-    public function testIgnoreAttributeOnMethodWithSameNameAsProperty()
-    {
-        $normalizer = new ObjectNormalizer(new ClassMetadataFactory(new AttributeLoader()));
-
-        $object = new ObjectWithIgnoredMethodSameNameAsProperty('should_be_ignored', 'should_be_serialized');
-
-        $this->assertSame(['visible' => 'should_be_serialized'], $normalizer->normalize($object));
-    }
-
-    public function testIgnoreAttributeOnMethodWithSameNameAsPropertyWithGroups()
-    {
-        $normalizer = new ObjectNormalizer(new ClassMetadataFactory(new AttributeLoader()));
-
-        $object = new ObjectWithIgnoredMethodSameNameAsPropertyWithGroups('ignored', 'visible_default', 'visible_group');
-
-        // without groups - should include both visible properties
-        $this->assertSame(['visibleDefault' => 'visible_default', 'visibleGroup' => 'visible_group'], $normalizer->normalize($object));
-
-        // with groups - should only include group-specific property, ignored method should never appear
-        $this->assertSame(['visibleGroup' => 'visible_group'], $normalizer->normalize($object, null, ['groups' => ['group1']]));
+        ],
+            $normalized);
     }
 
     /**
@@ -1382,61 +1175,6 @@ class ObjectNormalizerTest extends TestCase
         ], $normalizedSwappedHasserIsser);
     }
 
-    public function testIsserPrefersBaseNameWhenNoCollision()
-    {
-        $normalizer = new ObjectNormalizer();
-
-        $object = new ObjectWithIsPrefixedPropertyOnly(true);
-
-        $this->assertSame(['published' => true], $normalizer->normalize($object));
-    }
-
-    public function testIsserKeepsPrefixWhenBaseNameCollides()
-    {
-        $normalizer = new ObjectNormalizer();
-
-        $object = new ObjectWithIsPrefixedPropertyAndPublishedGetter(true, 'live');
-
-        $this->assertEquals([
-            'published' => 'live',
-            'isPublished' => true,
-        ], $normalizer->normalize($object));
-    }
-
-    public function testIsserKeepsPrefixWhenPublicPropertyCollidesWithoutGetter()
-    {
-        $normalizer = new ObjectNormalizer();
-
-        $object = new ObjectWithIsserAndPublicPropertyNoGetter(true, 'live');
-
-        // Both should appear: isPublished keeps prefix because $published property exists
-        $this->assertEquals([
-            'isPublished' => true,
-            'published' => 'live',
-        ], $normalizer->normalize($object));
-    }
-
-    public function testIsserWithPublicPropertyCollision()
-    {
-        $normalizer = new ObjectNormalizer();
-
-        $object = new ObjectWithPublicPublishedPropertyAndIsser('live');
-
-        // The isser takes precedence over the public property - this documents existing behavior
-        $this->assertSame(['published' => true], $normalizer->normalize($object));
-    }
-
-    public function testIsserWithPrivatePropertyNoMethodNamedProperty()
-    {
-        $normalizer = new ObjectNormalizer();
-
-        $object = new ObjectWithPrivatePublishedAndIsser(true);
-
-        // isPublished() should normalize to 'published', not 'isPublished'
-        // because there's no $isPublished property that would cause a collision
-        $this->assertSame(['published' => true], $normalizer->normalize($object));
-    }
-
     public function testDiscriminatorWithAllowExtraAttributesFalse()
     {
         // Discriminator type property should be allowed with allow_extra_attributes=false
@@ -1453,101 +1191,6 @@ class ObjectNormalizerTest extends TestCase
 
         $this->assertInstanceOf(DiscriminatorDummyTypeA::class, $obj);
     }
-
-    public function testNameConverterWithWrongCaseAndAllowExtraAttributesFalse()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $normalizer = new ObjectNormalizer($classMetadataFactory, new CamelCaseToSnakeCaseNameConverter());
-
-        $result = $normalizer->denormalize(
-            ['some_camel_case_property' => 1],
-            NameConverterTestDummy::class,
-            null,
-            [AbstractNormalizer::ALLOW_EXTRA_ATTRIBUTES => false]
-        );
-        $this->assertSame(1, $result->someCamelCaseProperty);
-
-        $this->expectException(ExtraAttributesException::class);
-        $this->expectExceptionMessage('someCamelCaseProperty');
-        $normalizer->denormalize(
-            ['someCamelCaseProperty' => 1],
-            NameConverterTestDummy::class,
-            null,
-            [AbstractNormalizer::ALLOW_EXTRA_ATTRIBUTES => false]
-        );
-    }
-
-    public function testNameConverterWithWrongCaseAndAllowExtraAttributesTrue()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $normalizer = new ObjectNormalizer($classMetadataFactory, new CamelCaseToSnakeCaseNameConverter());
-
-        $result = $normalizer->denormalize(
-            ['someCamelCaseProperty' => 999],
-            NameConverterTestDummy::class,
-            null,
-            [AbstractNormalizer::ALLOW_EXTRA_ATTRIBUTES => true]
-        );
-        $this->assertSame(0, $result->someCamelCaseProperty);
-
-        $result = $normalizer->denormalize(
-            ['some_camel_case_property' => 42],
-            NameConverterTestDummy::class,
-            null,
-            [AbstractNormalizer::ALLOW_EXTRA_ATTRIBUTES => true]
-        );
-        $this->assertSame(42, $result->someCamelCaseProperty);
-    }
-
-    public function testNormalizeObjectWithGroupsAndIsPrefixedProperty()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $normalizer = new ObjectNormalizer($classMetadataFactory);
-        $serializer = new Serializer([$normalizer]);
-        $normalizer->setSerializer($serializer);
-
-        $object = new GroupDummyWithIsPrefixedProperty();
-
-        $normalizedWithoutGroups = $normalizer->normalize($object);
-        $this->assertArrayHasKey('something', $normalizedWithoutGroups);
-
-        $normalizedWithGroups = $normalizer->normalize($object, null, [AbstractNormalizer::GROUPS => ['test']]);
-        $this->assertArrayHasKey('something', $normalizedWithGroups);
-    }
-
-    public function testNormalizeObjectWithGroupsAndIsPrefixedPropertyWithCollision()
-    {
-        $classMetadataFactory = new ClassMetadataFactory(new AttributeLoader());
-        $normalizer = new ObjectNormalizer($classMetadataFactory);
-        $serializer = new Serializer([$normalizer]);
-        $normalizer->setSerializer($serializer);
-
-        $object = new GroupDummyWithIsPrefixedPropertyAndPublishedGetter();
-
-        $normalizedWithGroups = $normalizer->normalize($object, null, [AbstractNormalizer::GROUPS => ['test']]);
-
-        $this->assertArrayHasKey('isPublished', $normalizedWithGroups);
-        $this->assertArrayNotHasKey('published', $normalizedWithGroups);
-    }
-
-    public function testSkipVoidNeverReturnTypeAccessors()
-    {
-        $obj = new VoidNeverReturnTypeDummy();
-        $normalized = $this->normalizer->normalize($obj);
-        $this->assertArrayHasKey('normalProperty', $normalized);
-        $this->assertArrayNotHasKey('voidProperty', $normalized);
-        $this->assertArrayNotHasKey('neverProperty', $normalized);
-        $this->assertEquals('value', $normalized['normalProperty']);
-    }
-
-    public function testMetadataIsAppliedToTheRightValue()
-    {
-        $obj = new ObjectWithMetadata();
-        $normalizer = new ObjectNormalizer(new ClassMetadataFactory(new AttributeLoader()));
-        $normalized = $normalizer->normalize($obj);
-
-        $this->assertSame(['name' => 'John', 'foo' => 42, 'hello' => 'Hello i am John'], $normalized);
-    }
 }
 
 class ProxyObjectDummy extends ObjectDummy
@@ -1655,15 +1298,6 @@ class ObjectWithStaticPropertiesAndMethods
     }
 }
 
-class ObjectWithStaticMethodWithGroups
-{
-    #[Groups('test')]
-    public static function getBaz()
-    {
-        return 'L';
-    }
-}
-
 class ObjectTypeHinted
 {
     public function setFoo(array $f)
@@ -1738,17 +1372,6 @@ class LazyObjectInner extends ObjectInner
     }
 }
 
-class ObjectWithGroupedMagicGetPrivateProperty
-{
-    #[Groups(['read'])]
-    private string $foo = 'foo';
-
-    public function __get($name)
-    {
-        return 'foo';
-    }
-}
-
 class DummyWithConstructorObject
 {
     private $id;
@@ -2037,223 +1660,3 @@ class ObjectWithPropertyIsserAndHasser
         return 'hasFoo';
     }
 }
-
-class ObjectWithIsPrefixedPropertyOnly
-{
-    public function __construct(
-        private bool $isPublished,
-    ) {
-    }
-
-    public function isPublished(): bool
-    {
-        return $this->isPublished;
-    }
-}
-
-class ObjectWithIsPrefixedPropertyAndPublishedGetter
-{
-    public function __construct(
-        private bool $isPublished,
-        private string $published,
-    ) {
-    }
-
-    public function getPublished(): string
-    {
-        return $this->published;
-    }
-
-    public function isPublished(): bool
-    {
-        return $this->isPublished;
-    }
-}
-
-class GroupDummyWithIsPrefixedPropertyAndPublishedGetter
-{
-    private bool $isPublished = true;
-    private string $published = 'live';
-
-    #[Groups(['test'])]
-    public function isPublished(): bool
-    {
-        return $this->isPublished;
-    }
-
-    public function getPublished(): string
-    {
-        return $this->published;
-    }
-}
-
-class ObjectWithPublicPublishedPropertyAndIsser
-{
-    public string $published;
-
-    public function __construct(string $published)
-    {
-        $this->published = $published;
-    }
-
-    public function isPublished(): bool
-    {
-        return '' !== $this->published;
-    }
-}
-
-class ObjectWithPrivatePublishedAndIsser
-{
-    public function __construct(
-        private bool $published,
-    ) {
-    }
-
-    public function isPublished(): bool
-    {
-        return $this->published;
-    }
-}
-
-class ObjectWithIsserAndPublicPropertyNoGetter
-{
-    public string $published;
-
-    public function __construct(
-        private bool $isPublished,
-        string $published,
-    ) {
-        $this->published = $published;
-    }
-
-    public function isPublished(): bool
-    {
-        return $this->isPublished;
-    }
-}
-
-class ObjectWithMethodSameNameThanProperty
-{
-    public function __construct(
-        private $shouldDoThing,
-    ) {
-    }
-
-    #[Groups(['Default', 'foo'])]
-    public function shouldDoThing()
-    {
-        return $this->shouldDoThing;
-    }
-}
-
-class ObjectWithIgnoredMethodSameNameAsProperty
-{
-    public string $visible;
-
-    private $ignored;
-
-    public function __construct(string $ignored, string $visible)
-    {
-        $this->ignored = $ignored;
-        $this->visible = $visible;
-    }
-
-    #[Ignore]
-    public function ignored()
-    {
-        return $this->ignored;
-    }
-}
-
-class ObjectWithIgnoredMethodSameNameAsPropertyWithGroups
-{
-    public string $visibleDefault;
-    public string $visibleGroup;
-
-    private $ignored;
-
-    public function __construct(string $ignored, string $visibleDefault, string $visibleGroup)
-    {
-        $this->ignored = $ignored;
-        $this->visibleDefault = $visibleDefault;
-        $this->visibleGroup = $visibleGroup;
-    }
-
-    #[Ignore]
-    public function ignored()
-    {
-        return $this->ignored;
-    }
-
-    #[Groups(['group1'])]
-    public function visibleGroup()
-    {
-        return $this->visibleGroup;
-    }
-}
-
-class NameConverterTestDummy
-{
-    public function __construct(
-        public readonly int $someCamelCaseProperty = 0,
-    ) {
-    }
-}
-
-class NameConverterTestDummyMultiple
-{
-    public function __construct(
-        public readonly int $someCamelCaseProperty = 0,
-        public readonly int $anotherProperty = 0,
-    ) {
-    }
-}
-
-class SerializerConstructorTypeConversionDummy
-{
-    /** @var list<string> */
-    private array $attributes;
-
-    public function __construct(string $attributes = '')
-    {
-        $this->attributes = $attributes ? explode(',', $attributes) : [];
-    }
-
-    public function isAttributeAllowed(string $attribute): bool
-    {
-        return !\in_array($attribute, $this->attributes, true);
-    }
-}
-
-class ObjectWithMetadata
-{
-    private int $foo;
-    private string $name;
-
-    public function __construct()
-    {
-        $this->foo = 42;
-        $this->name = 'John';
-    }
-
-    public function getName(): string
-    {
-        return $this->name;
-    }
-
-    public function getFoo(): int
-    {
-        return $this->foo;
-    }
-
-    #[Ignore]
-    public function isEqualTo(self $test): bool
-    {
-        return $this->name === $test->getName();
-    }
-
-    public function getHello(): string
-    {
-        return 'Hello i am '.$this->getName();
-    }
-}
