@@ -200,11 +200,10 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
         ], 'fr'));
 
         $provider = $this->createMock(ProviderInterface::class);
-        $provider
+        $provider->expects($this->any())
             ->method('read')
-            ->willReturnMap([
-                [$domains, $locales, $providerReadTranslatorBag],
-            ]);
+            ->with($domains, $locales)
+            ->willReturn($providerReadTranslatorBag);
 
         // Create local bag, with a missing message.
         $localTranslatorBag = new TranslatorBag();
@@ -223,11 +222,10 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
         $providerReadTranslatorBag->addCatalogue($arrayLoader->load(['note' => 'NOTE'], 'en'));
         $providerReadTranslatorBag->addCatalogue($arrayLoader->load(['note' => 'NOTE'], 'fr'));
 
-        $provider
+        $provider->expects($this->any())
             ->method('read')
-            ->willReturnMap([
-                [$domains, $locales, $providerReadTranslatorBag],
-            ]);
+            ->with($domains, $locales)
+            ->willReturn($providerReadTranslatorBag);
 
         $provider->expects($this->once())
             ->method('write')
@@ -264,11 +262,10 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
         ], 'fr'));
 
         $provider = $this->createMock(ProviderInterface::class);
-        $provider
+        $provider->expects($this->any())
             ->method('read')
-            ->willReturnMap([
-                [$domains, $locales, $providerReadTranslatorBag],
-            ]);
+            ->with($domains, $locales)
+            ->willReturn($providerReadTranslatorBag);
 
         // Create local bag, with a missing message, an updated one and a new one.
         $localTranslatorBag = new TranslatorBag();
@@ -287,11 +284,10 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
         $providerReadTranslatorBag->addCatalogue($arrayLoader->load(['note' => 'NOTE'], 'en'));
         $providerReadTranslatorBag->addCatalogue($arrayLoader->load(['note' => 'NOTE'], 'fr'));
 
-        $provider
+        $provider->expects($this->any())
             ->method('read')
-            ->willReturnMap([
-                [$domains, $locales, $providerReadTranslatorBag],
-            ]);
+            ->with($domains, $locales)
+            ->willReturn($providerReadTranslatorBag);
 
         $translationBagToWrite = $localTranslatorBag->diff($providerReadTranslatorBag);
         $translationBagToWrite->addBag($localTranslatorBag->intersect($providerReadTranslatorBag));
@@ -366,11 +362,7 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
         );
 
         $application = new Application();
-        if (method_exists($application, 'addCommand')) {
-            $application->addCommand($command);
-        } else {
-            $application->add($command);
-        }
+        $application->addCommand($command);
         $tester = new CommandTester($application->find('translation:push'));
 
         $tester->execute(['--locales' => ['en', 'fr']]);
@@ -382,12 +374,7 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
     public function testComplete(array $input, array $expectedSuggestions)
     {
         $application = new Application();
-        $command = $this->createCommand($this->createStub(ProviderInterface::class), ['en', 'fr', 'it'], ['messages', 'validators'], ['loco', 'crowdin', 'lokalise']);
-        if (method_exists($application, 'addCommand')) {
-            $application->addCommand($command);
-        } else {
-            $application->add($command);
-        }
+        $application->addCommand($this->createCommand($this->createMock(ProviderInterface::class), ['en', 'fr', 'it'], ['messages', 'validators'], ['loco', 'crowdin', 'lokalise']));
 
         $tester = new CommandCompletionTester($application->get('translation:push'));
         $suggestions = $tester->complete($input);
@@ -416,11 +403,7 @@ class TranslationPushCommandTest extends TranslationProviderTestCase
     {
         $command = $this->createCommand($provider, $locales, $domains);
         $application = new Application();
-        if (method_exists($application, 'addCommand')) {
-            $application->addCommand($command);
-        } else {
-            $application->add($command);
-        }
+        $application->addCommand($command);
 
         return new CommandTester($application->find('translation:push'));
     }
