@@ -11,7 +11,6 @@
 
 namespace Symfony\Component\Validator\Constraints;
 
-use Symfony\Component\Validator\Attribute\HasNamedArguments;
 use Symfony\Component\Validator\Constraint;
 use Symfony\Component\Validator\Exception\ConstraintDefinitionException;
 use Symfony\Component\Validator\Exception\InvalidArgumentException;
@@ -111,7 +110,6 @@ class Ip extends Constraint
      * @param self::V4*|self::V6*|self::ALL*|null $version The IP version to validate (defaults to {@see self::V4})
      * @param string[]|null                       $groups
      */
-    #[HasNamedArguments]
     public function __construct(
         ?array $options = null,
         ?string $version = null,
@@ -120,15 +118,15 @@ class Ip extends Constraint
         ?array $groups = null,
         mixed $payload = null,
     ) {
-        if (\is_array($options)) {
-            trigger_deprecation('symfony/validator', '7.3', 'Passing an array of options to configure the "%s" constraint is deprecated, use named arguments instead.', static::class);
+        if (null !== $options) {
+            throw new InvalidArgumentException(\sprintf('Passing an array of options to configure the "%s" constraint is no longer supported.', static::class));
         }
 
-        parent::__construct($options, $groups, $payload);
+        parent::__construct(null, $groups, $payload);
 
         $this->version = $version ?? $this->version;
         $this->message = $message ?? $this->message;
-        $this->normalizer = $normalizer ?? $this->normalizer;
+        $this->normalizer = $normalizer;
 
         if (!\in_array($this->version, static::VERSIONS, true)) {
             throw new ConstraintDefinitionException(\sprintf('The option "version" must be one of "%s".', implode('", "', static::VERSIONS)));
