@@ -30,8 +30,6 @@ use Symfony\Component\Validator\GroupSequenceProviderInterface;
  * @see GroupSequence
  * @see GroupSequenceProviderInterface
  * @see TraversalStrategy
- *
- * @method string|null getGroupProvider()
  */
 interface ClassMetadataInterface extends MetadataInterface
 {
@@ -66,6 +64,8 @@ interface ClassMetadataInterface extends MetadataInterface
      */
     public function isGroupSequenceProvider(): bool;
 
+    public function getGroupProvider(): ?string;
+
     /**
      * Check if there's any metadata attached to the given named property.
      *
