@@ -11,8 +11,6 @@
 
 namespace Symfony\Component\Validator\Tests\Constraints;
 
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use Symfony\Component\Validator\Constraints\IsFalse;
 use Symfony\Component\Validator\Constraints\IsFalseValidator;
 use Symfony\Component\Validator\Test\ConstraintValidatorTestCase;
@@ -47,20 +45,4 @@ class IsFalseValidatorTest extends ConstraintValidatorTestCase
             ->setCode(IsFalse::NOT_FALSE_ERROR)
             ->assertRaised();
     }
-
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testTrueIsInvalidDoctrineStyle()
-    {
-        $constraint = new IsFalse([
-            'message' => 'myMessage',
-        ]);
-
-        $this->validator->validate(true, $constraint);
-
-        $this->buildViolation('myMessage')
-            ->setParameter('{{ value }}', 'true')
-            ->setCode(IsFalse::NOT_FALSE_ERROR)
-            ->assertRaised();
-    }
 }
