@@ -11,10 +11,6 @@
 
 namespace Symfony\Component\Validator\Tests\Constraints;
 
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
-use Symfony\Component\HttpClient\MockHttpClient;
-use Symfony\Component\HttpClient\Response\MockResponse;
 use Symfony\Component\Validator\Constraints\Luhn;
 use Symfony\Component\Validator\Constraints\NotCompromisedPassword;
 use Symfony\Component\Validator\Constraints\NotCompromisedPasswordValidator;
@@ -22,7 +18,9 @@ use Symfony\Component\Validator\ConstraintValidatorInterface;
 use Symfony\Component\Validator\Exception\UnexpectedTypeException;
 use Symfony\Component\Validator\Test\ConstraintValidatorTestCase;
 use Symfony\Contracts\HttpClient\Exception\ExceptionInterface;
+use Symfony\Contracts\HttpClient\Exception\ServerExceptionInterface;
 use Symfony\Contracts\HttpClient\HttpClientInterface;
+use Symfony\Contracts\HttpClient\ResponseInterface;
 
 /**
  * @author Kévin Dunglas <dunglas@gmail.com>
@@ -104,15 +102,6 @@ class NotCompromisedPasswordValidatorTest extends ConstraintValidatorTestCase
         $this->assertNoViolation();
     }
 
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testThresholdNotReachedDoctrineStyle()
-    {
-        $this->validator->validate(self::PASSWORD_LEAKED, new NotCompromisedPassword(['threshold' => 10]));
-
-        $this->assertNoViolation();
-    }
-
     public function testValidPassword()
     {
         $this->validator->validate(self::PASSWORD_NOT_LEAKED, new NotCompromisedPassword());
@@ -206,6 +195,7 @@ class NotCompromisedPasswordValidatorTest extends ConstraintValidatorTestCase
     public function testApiError()
     {
         $this->expectException(ExceptionInterface::class);
+        $this->expectExceptionMessage('Problem contacting the Have I been Pwned API.');
         $this->validator->validate(self::PASSWORD_TRIGGERING_AN_ERROR, new NotCompromisedPassword());
     }
 
@@ -216,31 +206,46 @@ class NotCompromisedPasswordValidatorTest extends ConstraintValidatorTestCase
         $this->validator->validate(self::PASSWORD_TRIGGERING_AN_ERROR, new NotCompromisedPassword(skipOnError: true));
     }
 
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testApiErrorSkippedDoctrineStyle()
-    {
-        $this->expectNotToPerformAssertions();
-
-        $this->validator->validate(self::PASSWORD_TRIGGERING_AN_ERROR, new NotCompromisedPassword(['skipOnError' => true]));
-    }
-
     private function createHttpClientStub(?string $returnValue = null): HttpClientInterface
     {
-        return new MockHttpClient(function ($method, $url) use ($returnValue) {
-            if (self::PASSWORD_TRIGGERING_AN_ERROR_RANGE_URL !== $url) {
-                return new MockResponse($returnValue ?? implode("\r\n", self::RETURN));
+        $httpClientStub = $this->createMock(HttpClientInterface::class);
+        $httpClientStub->method('request')->willReturnCallback(
+            function (string $method, string $url) use ($returnValue): ResponseInterface {
+                if (self::PASSWORD_TRIGGERING_AN_ERROR_RANGE_URL === $url) {
+                    throw new class('Problem contacting the Have I been Pwned API.') extends \Exception implements ServerExceptionInterface {
+                        public function getResponse(): ResponseInterface
+                        {
+                            throw new \RuntimeException('Not implemented');
+                        }
+                    };
+                }
+
+                $responseStub = $this->createMock(ResponseInterface::class);
+                $responseStub
+                    ->method('getContent')
+                    ->willReturn($returnValue ?? implode("\r\n", self::RETURN));
+
+                return $responseStub;
             }
-        });
+        );
+
+        return $httpClientStub;
     }
 
     private function createHttpClientStubCustomEndpoint($expectedEndpoint): HttpClientInterface
     {
-        return new MockHttpClient(function ($method, $url) use ($expectedEndpoint) {
-            $this->assertSame('GET', $method);
-            $this->assertSame($expectedEndpoint, $url);
+        $httpClientStub = $this->createMock(HttpClientInterface::class);
+        $httpClientStub->method('request')->with('GET', $expectedEndpoint)->willReturnCallback(
+            function (string $method, string $url): ResponseInterface {
+                $responseStub = $this->createMock(ResponseInterface::class);
+                $responseStub
+                    ->method('getContent')
+                    ->willReturn(implode("\r\n", self::RETURN));
 
-            return new MockResponse(implode("\r\n", self::RETURN));
-        });
+                return $responseStub;
+            }
+        );
+
+        return $httpClientStub;
     }
 }
