@@ -12,8 +12,6 @@
 namespace Symfony\Component\Validator\Tests\Constraints;
 
 use PHPUnit\Framework\Attributes\DataProvider;
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Validator\Constraints\Timezone;
 use Symfony\Component\Validator\Exception\ConstraintDefinitionException;
@@ -85,15 +83,6 @@ class TimezoneTest extends TestCase
         self::assertSame(['my_group'], $cConstraint->groups);
         self::assertSame('some attached data', $cConstraint->payload);
     }
-
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
-    public function testDoctrineStyle()
-    {
-        $constraint = new Timezone(['zone' => \DateTimeZone::ALL]);
-
-        $this->assertSame(\DateTimeZone::ALL, $constraint->zone);
-    }
 }
 
 class TimezoneDummy
