@@ -19,7 +19,7 @@ class CustomArrayObject implements \ArrayAccess, \IteratorAggregate, \Countable
 {
     private $array;
 
-    public function __construct(array $array = null)
+    public function __construct(?array $array = null)
     {
         $this->array = $array ?: [];
     }
