@@ -11,17 +11,15 @@
 
 namespace Symfony\Component\Validator\Tests\Mapping\Loader\Fixtures;
 
-use Symfony\Component\Validator\Attribute\HasNamedArguments;
 use Symfony\Component\Validator\Constraint;
 
 class ConstraintWithNamedArguments extends Constraint
 {
     public $choices;
 
-    #[HasNamedArguments]
     public function __construct(array|string|null $choices = [], ?array $groups = null)
     {
-        parent::__construct([], $groups);
+        parent::__construct(null, $groups);
 
         $this->choices = $choices;
     }
