@@ -39,7 +39,7 @@ class PropertyInfoLoaderTest extends TestCase
 {
     public function testLoadClassMetadata()
     {
-        $propertyListExtractor = $this->createStub(PropertyListExtractorInterface::class);
+        $propertyListExtractor = $this->createMock(PropertyListExtractorInterface::class);
         $propertyListExtractor
             ->method('getProperties')
             ->willReturn([
@@ -228,7 +228,7 @@ class PropertyInfoLoaderTest extends TestCase
     #[DataProvider('regexpProvider')]
     public function testClassValidator(bool $expected, ?string $classValidatorRegexp = null)
     {
-        $propertyListExtractor = $this->createStub(PropertyListExtractorInterface::class);
+        $propertyListExtractor = $this->createMock(PropertyListExtractorInterface::class);
         $propertyListExtractor
             ->method('getProperties')
             ->willReturn(['string'])
@@ -267,7 +267,7 @@ class PropertyInfoLoaderTest extends TestCase
     public function testClassNoAutoMapping(?PropertyTypeExtractorInterface $propertyListExtractor = null)
     {
         if (null === $propertyListExtractor) {
-            $propertyListExtractor = $this->createStub(PropertyListExtractorInterface::class);
+            $propertyListExtractor = $this->createMock(PropertyListExtractorInterface::class);
             $propertyListExtractor
                 ->method('getProperties')
                 ->willReturn(['string', 'autoMappingExplicitlyEnabled'])
