@@ -33,10 +33,10 @@ interface RequestParserInterface
     /**
      * @param Request|null $request The original request that was received by the webhook controller
      */
-    public function createSuccessfulResponse(/* ?Request $request = null */): Response;
+    public function createSuccessfulResponse(?Request $request = null): Response;
 
     /**
      * @param Request|null $request The original request that was received by the webhook controller
      */
-    public function createRejectedResponse(string $reason/* , ?Request $request = null */): Response;
+    public function createRejectedResponse(string $reason, ?Request $request = null): Response;
 }
