@@ -21,9 +21,7 @@ use Symfony\Component\Workflow\Exception\InvalidDefinitionException;
 interface DefinitionValidatorInterface
 {
     /**
-     * @return void
-     *
      * @throws InvalidDefinitionException on invalid definition
      */
-    public function validate(Definition $definition, string $name);
+    public function validate(Definition $definition, string $name): void;
 }
