@@ -12,8 +12,6 @@
 namespace Symfony\Component\Yaml\Tests;
 
 use PHPUnit\Framework\Attributes\DataProvider;
-use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnoreDeprecations;
 use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\Yaml\Exception\ParseException;
@@ -1044,11 +1042,9 @@ class ParserTest extends TestCase
         return $tests;
     }
 
-    #[IgnoreDeprecations]
-    #[Group('legacy')]
     public function testNullAsDuplicatedData()
     {
-        $this->expectUserDeprecationMessage('Since symfony/yaml 7.2: Duplicate key "child" detected on line 4 whilst parsing YAML. Silent handling of duplicate mapping keys in YAML is deprecated and will throw a ParseException in 8.0.');
+        $this->expectException(ParseException::class);
 
         $yaml = <<<EOD
             parent:
